-- Additional FTP accounts
CREATE TABLE IF NOT EXISTS `ftp_users` (
  `id` INT UNSIGNED AUTO_INCREMENT PRIMARY KEY,
  `dom_id` INT UNSIGNED NOT NULL,
  `sys_user_id` INT UNSIGNED NOT NULL,
  INDEX (dom_id),
  UNIQUE (sys_user_id)
) ENGINE=InnoDB;

-- Add additional FTP accounts actions
REPLACE INTO actions (name, descr, enabled) VALUES ('ftpuser_create', 'Create FTP User', 'true');
REPLACE INTO actions (name, descr, enabled) VALUES ('ftpuser_update', 'Update FTP User', 'true');
REPLACE INTO actions (name, descr, enabled) VALUES ('ftpuser_delete', 'Delete FTP User', 'true');

-- Add additional FTP accounts permission and limit
REPLACE INTO TmplData (tmpl_id, element, value)
  SELECT t.id, 'manage_subftp', 'true' FROM Templates t LEFT OUTER JOIN TmplData td ON (t.id = td.tmpl_id AND td.element = 'manage_subftp')
  WHERE t.name IN ('Default Reseller', 'Default Client') AND td.tmpl_id IS NULL;

REPLACE INTO TmplData (tmpl_id, element, value)
  SELECT t.id, 'max_subftp_users', '-1' FROM Templates t LEFT OUTER JOIN TmplData td ON (t.id = td.tmpl_id AND td.element = 'max_subftp_users')
  WHERE t.name IN ('Default Reseller', 'Default Client', 'Default Domain') AND td.tmpl_id IS NULL;

-- Add FTP Accounts button
REPLACE INTO DashboardPresetConfig (preset_id, ord, uri, parent_id, type)
  SELECT dpc.preset_id, dpc.ord, '/plesk/client@/domain@/hosting/ftp-users/', dpc.parent_id, 'button'
  FROM DashboardPresetConfig dpc LEFT OUTER JOIN DashboardPresetConfig dpc1
    ON (dpc.preset_id = dpc1.preset_id AND dpc.parent_id = dpc1.parent_id AND dpc1.uri='/plesk/client@/domain@/hosting/ftp-users/')
  WHERE dpc.uri='/plesk/client@/domain@/hosting/anonymous-ftp/' AND dpc1.id IS NULL;

-- Configuration status
CREATE TABLE IF NOT EXISTS Configurations (
    `id`            INT UNSIGNED AUTO_INCREMENT PRIMARY KEY,
    `name`          VARCHAR(255) character set ascii COLLATE ascii_bin NOT NULL,
    `file`          BLOB NOT NULL,
    `version`       VARCHAR(255) character set ascii COLLATE ascii_bin NOT NULL,
    `objectType`    VARCHAR(255) character set ascii COLLATE ascii_bin NOT NULL,
    `objectId`      VARCHAR(255) character set ascii COLLATE ascii_bin,
    `status`        enum('error', 'generation', 'ok') NOT NULL default 'error',
    `description`   BLOB DEFAULT NULL
) ENGINE=InnoDB;

-- Subscriptions
CREATE TABLE IF NOT EXISTS Subscriptions (
    id              INT UNSIGNED AUTO_INCREMENT PRIMARY KEY,
    object_id       INT UNSIGNED NOT NULL,
    object_type     ENUM('client', 'domain') NOT NULL,
    locked          ENUM('true', 'false') NOT NULL DEFAULT 'false',
    synchronized    ENUM('true', 'false') NOT NULL DEFAULT 'true',
                    UNIQUE (object_id, object_type)
) ENGINE=InnoDB;

CREATE TABLE IF NOT EXISTS PlansSubscriptions (
    subscription_id INT UNSIGNED NOT NULL,
    plan_id         INT UNSIGNED NOT NULL,
    quantity        INT UNSIGNED NOT NULL DEFAULT 1,
                    PRIMARY KEY (subscription_id, plan_id)
) ENGINE=InnoDB;

REPLACE INTO DashboardPresetConfig (preset_id, ord, uri, parent_id, type)
  SELECT dpc.preset_id, dpc.ord, '/plesk/client@/domain@/subscription/', dpc.parent_id, 'button'
  FROM DashboardPreset dp, DashboardPresetConfig dpc LEFT JOIN DashboardPresetConfig dpc1
    ON (dpc.preset_id = dpc1.preset_id AND dpc.parent_id = dpc1.parent_id AND dpc1.uri='/plesk/client@/domain@/subscription/')
  WHERE dp.type = 'domain' AND dpc.uri = '/plesk/client@/domain@/domain-user-interface/' AND dpc1.id IS NULL;

REPLACE INTO DashboardPresetConfig (preset_id, ord, uri, parent_id, type)
  SELECT dpc.preset_id, dpc.ord, '/plesk/client@/subscription/', dpc.parent_id, 'button'
  FROM DashboardPreset dp, DashboardPresetConfig dpc LEFT JOIN DashboardPresetConfig dpc1
    ON (dpc.preset_id = dpc1.preset_id AND dpc.parent_id = dpc1.parent_id AND dpc1.uri='/plesk/client@/subscription/')
  WHERE dp.type = 'client' AND dpc.uri = '/plesk/client@/billing-details/' AND dpc1.id IS NULL;

REPLACE INTO DashboardPresetConfig (preset_id, ord, uri, parent_id, type)
  SELECT dpc.preset_id, dpc.ord, '/plesk/reseller@/subscription/', dpc.parent_id, 'button'
  FROM DashboardPreset dp, DashboardPresetConfig dpc LEFT JOIN DashboardPresetConfig dpc1
    ON (dpc.preset_id = dpc1.preset_id AND dpc.parent_id = dpc1.parent_id AND dpc1.uri='/plesk/reseller@/subscription/')
  WHERE dp.type = 'client' AND dpc.uri = '/plesk/reseller@/billing-details/' AND dpc1.id IS NULL;

-- default parameters for clients
REPLACE INTO cl_param (cl_id, param, val)
  SELECT p1.cl_id, 'OveruseSuspend', 'true'
  FROM cl_param p1 LEFT JOIN cl_param p2 ON p1.cl_id = p2.cl_id AND p2.param = 'OveruseSuspend'
  WHERE p1.param = 'OveruseBlock' AND p1.val = 'true' AND p2.val IS NULL;

-- default parameters for domains
REPLACE INTO dom_param (dom_id, param, val)
  SELECT p1.dom_id, 'OveruseSuspend', 'true'
  FROM dom_param p1 LEFT JOIN dom_param p2 ON p1.dom_id = p2.dom_id AND p2.param = 'OveruseSuspend'
  WHERE p1.param = 'OveruseBlock' AND p1.val = 'true' AND p2.val IS NULL;

-- default parameters for plans
REPLACE INTO TmplData (tmpl_id, element, value)
  SELECT p1.tmpl_id, 'overuse_suspend', 'true'
  FROM TmplData p1 LEFT JOIN TmplData p2 ON p1.tmpl_id = p2.tmpl_id AND p2.element = 'overuse_suspend'
  WHERE p1.element = 'overuse_block' AND p1.value = 'true' AND p2.value IS NULL;

-- classic UI mode
REPLACE INTO misc (param, val) VALUES('classic_panel', 'true');