#!/bin/sh
#
# Copyright (c) 1999-2008 Parallels
# All rights reserved
#

#
# Plesk script
#


# Migration manager tables will be managed by plesk
migrate_pmm_management_db_into_core_1011()
{
	if ! db_test_table "PMM" || ! db_test_table "PMMDefault"; then
		$mysql < ${PRODUCT_BOOTSTRAPPER_DIR}/db/pmm_db.sql
		[ "$?" = "0" ] || die "install PMM tables during upgrade"
	fi
}

#admin

set_admin_params()
{

	ADMIN_ROOT=$PRODUCT_ROOT_D/admin

	UTILS_DIR=$ADMIN_ROOT/bin

	admin_user="${product}adm"
	admin_UID=8444
	admin_group="${product}adm"
	admin_GID=8444

	admin_httpsd_conf="$ADMIN_ROOT/conf/httpsd.conf"
	ADMIN_CERT="$ADMIN_ROOT/conf/httpsd.pem"

	admin_pid_file=$ADMIN_ROOT/logs/httpsd.pid
	admin_lock_file=$ADMIN_ROOT/logs/httpsd.lock

	define_start_script
}

lock_keyupdate()
{
	export PLESK_KEYUPDATE_DISABLED=installation
}

## @@constructor set_admin_params
## @@constructor lock_keyupdate

set_admin_perms()
{
   	#remove stale file
	rm -f "$ADMIN_ROOT/htdocs/index.php3"

#	if [ "X$machine" != "Xlinux" -o "X$linux_distr" = "Xdebian" ]; then
#		set_admin_additional_perms
#	fi


	available_certificates=`ls -1 $ADMIN_ROOT/conf/*.pem* 2>/dev/null`
	if [ "X${available_certificates}" != "X" ]; then
		for i in ${available_certificates}; do
			chown 0:0 $i || die
			chmod 400 $i || die
		done
	fi

	[ -d $ADMIN_ROOT/man ] &&
	set_ac 0 $admin_group 755 "$ADMIN_ROOT/man/*" &&
	for i in `find $ADMIN_ROOT/man -type d -print`; do
		set_ac root $admin_group 755 "$i"
		set_ac root $admin_group 644 "$i/*"
	done

	[ -d ${DUMP_D} ] &&
		set_ac $admin_user $admin_group 755 ${DUMP_D}

	#set locales permissions
	for dir in htdocs plib; do
		chmod -R 644 "$ADMIN_ROOT/$dir/locales"
		find "$ADMIN_ROOT/$dir/locales" -type d -exec chmod 755 {} \;
	done

	if [ "X$DEMO_VERSION" = "Xyes" ]; then
		set_ac root $admin_group 775 "$ADMIN_ROOT/htdocs/images/custom_buttons"
	else
		set_ac root $admin_group 4110 "$ADMIN_ROOT/sbin/wrapper"
		set_ac root $admin_group 4110 "$ADMIN_ROOT/sbin/mod_wrapper"
	fi
}

install_admin()
{
	p_echo

	p_echo "===> Installing Admin Server"

	# set default permissions on $ADMIN_ROOT and his contents
	set_admin_perms

	# installation
	cd "$PRODUCT_ROOT_D" || die

	get_pid $ADMIN_ROOT/bin/httpsd true root
	req_pid=$common_var
	if [ $req_pid -gt 1 ]; then
		inten="stop running Admin server"
		echo_try $inten
		kill_pids $ADMIN_ROOT/bin/httpsd root
		if [ -f "$admin_lock_file.*" ]; then
			rm -f "$admin_lock_file.*" >> $product_log 2>&1
		fi
		if [ -f "$admin_pid_file" ]; then
			rm -f "$admin_pid_file"
		fi
		suc
	fi


	if [ ! -s "$ADMIN_CERT" ] ;then
		inten="copy default SSL Certificate for admin server"
		echo_try $inten
		get_certificate "$ADMIN_CERT" || die $inten
		set_ac 0 0 0400 "$ADMIN_CERT"
		suc
	fi

	if [ "X$DEMO_VERSION" = "Xyes" ]; then
		chown 0:psaadm $ADMIN_CERT || die
		chmod 440 $ADMIN_CERT || die
	else
		chown 0:0 $ADMIN_CERT || die
		chmod 400 $ADMIN_CERT || die
	fi
}

get_certificate()
{
	local dst="$1"
	local src="${certificate_file}"
# Check or generate new default certificate
	[ -s "$src" ] || generate_default_certificate
 	set_ac 0 0 0400 "${src}"
	cp -fp $src $dst
}

generate_default_certificate()
{
	# Currently I have no will to accurately rewrite the stuff below
	# so I just add support for (optional) file parameter. Actually
	# one need to accurately handle temporary files, directory creation
	# etc. Probably next time...
	local cert_file

	cert_file="${certificate_file}"
	if [ -s "$cert_file" ]; then
		p_echo "default certificate already exists"
		return
	fi

	# This var also can safely be made local. It's not used outside
	local OPENSSL_CNF is_temp_cnf rc

	OPENSSL_CNF=${PRODUCT_ROOT_D}/admin/conf/openssl.cnf
	is_temp_cnf=0

	if [ ! -f "${OPENSSL_CNF}" ]; then
		# Well, base psa package isn't yet installed. 
		# let's form a temporary config file
		OPENSSL_CNF=$(mktemp /tmp/openssl.cnf.XXXXXX)
		[ $? != 0 ] && die "Unable to create temporary file"
		cat >>${OPENSSL_CNF} <<EOF
[ req ]
attributes=req_attributes
distinguished_name=req_distinguished_name

[ req_attributes ]
challengePassword               = A challenge password
unstructuredName                = An optional company name

[ req_distinguished_name ]
countryName             = Country Name
stateOrProvinceName     = State or Province Name
localityName            = Locality Name
organizationName        = Organisation Name
organizationalUnitName  = Organization Unit Name
commonName              = Common Name
emailAddress            = Email Address
EOF
		is_temp_cnf=1
	fi

	echo "US
Virginia
Herndon
Parallels
Parallels Panel
Parallels Panel
info@parallels.com


" | openssl req -x509 -nodes -days 365 -newkey rsa:2048 	-config ${OPENSSL_CNF} -set_serial `date +%s` -keyout "${cert_file}_" 	-out "${cert_file}_" >> $product_log 2>&1

	# preserve exit code
	rc=$?

	if [ $rc -eq 0 ]; then
		cat "${cert_file}_" | sed -e 's/^\(-----END.*\)/\1/' > $cert_file
		set_ac 0 0 0400 "${cert_file}"
	fi
	# cleanup temporary files
	rm -f "${cert_file}_" ||:
	if [ "x$is_temp_cnf" = "x1" ]; then
		rm -f ${OPENSSL_CNF} ||:
	fi
	return $rc
}
set_apache_params()
{
	apache_user="wwwrun"
	apache_UID=80
	apache_group="www"
	apache_GID=80

	user_apxs="/usr/sbin/apxs2"

	set_apache_params_linux

	apache_service="$apache_service_name"

	apache_httpd_conf="$HTTPD_CONF_D/httpd.conf"
	apache_httpd_conf2="$HTTPD_CONF_D/httpd2.conf"
	apache_httpd_conf_in="$HTTPD_CONF_D/httpd.conf.in"

	apache_httpd_include="$HTTPD_INCLUDE_D/zz010_psa_httpd.conf"

	APACHE_CERT="$HTTPD_CONF_D/httpd.pem"
	APACHE_ROOT="/usr"

	min_suexec_UID=10000
	max_suexec_UID=16000
	min_suexec_GID=$min_suexec_UID
	max_suexec_GID=$max_suexec_UID

	suexec_storage=/usr/local/psa/suexec
	suexec=/usr/sbin/suexec2
	suexec_dir=/usr/sbin
	suexec_file=suexec2

	rpm_httpd_bin=/usr/sbin/httpd
}

set_apache_params_linux()
{
	apache_pid_file="$APACHE_ROOT/logs/httpd.pid"
	apache_lock_file="$APACHE_ROOT/logs/httpd.lock"
	product_lock_file="$HTTPD_CONF_D/cnf.lock"
	apache_service_name="apache2"

	apache_modules_d="/usr/lib/apache2"
}

fix_apache_path()
{
    fix_apache_path_linux
}

fix_apache_path_linux()
{
    :
}

# mode: shell-script

remove_tmp_state()
{
	if [ -d "/tmp/.state" ]; then
		rm -Rf "/tmp/.state" >> $product_log 2>&1
	fi
}

set_apache_accounts()
{
    p_echo " Checking for the system groups and users necessary for Apache..."

    case "$machine" in
      Darwin)
        group_op "$apache_group" "$apache_GID" false
        user_op "$apache_user" "$apache_UID" "$apache_group" "Apache server" "$dummy_home" "$dummy_shell" false
      ;;
      *)
        group_op "$apache_group" "$apache_GID" false
        user_op "$apache_user" "$apache_UID" "$apache_group" "Apache server" "$dummy_home" "$dummy_shell" false
      ;;
    esac
}

set_ssl_certs()
{
    # Upgrader should not touch SSL Certificate
    if [ "X$do_upgrade" != "X1" -o "X$std_to_pkg" = "X1" ]; then
	if [ ! -f "$APACHE_CERT" ]; then
		inten="copy default SSL Certificate for Apache"
		echo_try $inten
		cp -fp "$certificate_file" "$APACHE_CERT" || die $inten
		chown 0:0 "$APACHE_CERT" || die "chown $APACHE_CERT"
		chmod 400 "$APACHE_CERT" || die "chmod $APACHE_CERT"
		suc
	fi

	if [ "$machine" = "BSD" ]; then 
	    case $apache_suffix in
		apache22)
			ssl_conf="$HTTPD_CONF_D/extra/httpd-ssl.conf"

			#uncomment Include http-ssl
			if [ -f "$apache_httpd_conf" ]; then
			    mv -f $apache_httpd_conf ${apache_httpd_conf}.default
			    cat ${apache_httpd_conf}.default | awk -F '#' '
				/Include .*httpd-ssl\.conf/ {print $2; next} 
				{print;}
			    ' > $apache_httpd_conf
			fi
		;;
		apache2)
			ssl_conf="$HTTPD_CONF_D/ssl.conf"
		;;
		*)
			warn "Unable to find config file for ssl extras"
			return 0  
		;;
	    esac
	 
	    if [ -f "$ssl_conf" -a ! -z "$ssl_conf" ]; then
		mv $ssl_conf ${ssl_conf}.default
	 
		cat ${ssl_conf}.default | 		perl -e '@lines=<STDIN>;
		    $flag=0;
		    foreach $tmp (@lines) {
			if ($tmp =~ /^<VirtualHost.*>/) {$flag=1; next;}
			if ($tmp =~ /^<\/VirtualHost.*>/) {$flag=0; next; }
			unless ($flag) { print $tmp; }   
		}' > $ssl_conf
	    fi
	fi
    fi
}

apache_optim()
{
	if [ "X$DEMO_VERSION" = "Xyes" ]; then
		return 0;
	fi

	case "$machine" in

		linux)
			#p_echo "===> Optimization Apache server"
			info_cpu=`cat /proc/cpuinfo |grep 'model name'|awk '{print $4}' -`
			info_mod=`cat /proc/cpuinfo |grep 'model name'|awk '{print $5}' -`
			info_num=`cat /proc/cpuinfo |grep 'processor'|awk '{print $3}' -`

			case "$info_num" in

			0)
				case "$info_cpu" in

				Celeron | 				05/06 )
    				sed -e "s/MaxClients[[:space:]]*640/MaxClients 256/g"     					< $apache_httpd_conf > $apache_httpd_conf.tmp
					mv -f $apache_httpd_conf.tmp $apache_httpd_conf
					;;
				*)
					;;
				esac
				;;

			*)
				sed -e "s/MaxClients[[:space:]]*640/MaxClients 1024/g" 			    	< $apache_httpd_conf > $apache_httpd_conf.tmp
				mv -f $apache_httpd_conf.tmp $apache_httpd_conf
				;;

			esac
			;;

		*)
			;;
    esac
}

apache_conf_add_dirindex()
{
        index_str="^[[:space:]]*DirectoryIndex.*[[:space:]]$1\\(\$\\|[[:space:]]\\)"
        if ! grep -q "$index_str" "$2"; then
                case "$3" in
                        after) sed -e "s|^[[:space:]]*DirectoryIndex.*\$|& $1|" ;;
                        before) sed -e "s|^\\([[:space:]]*DirectoryIndex[[:space:]]*\\)\\(.*\\)|\\1$1 \\2|" ;;
                        *) false ;;
                esac < "$2" > "$2.tmp" || die "insert $1 in DirectoryIndex directive into $2 file"
                mv -f "$2.tmp" "$2" || die "replace initial $2 file"
        fi
}

apache_conf_add_type_shtml()
{
    local config="$1"

    add_string 'AddType[[:space:]]*text/html[[:space:]]*\.shtml' 		"AddType text/html .shtml" "$config"

}

apache_conf_add_type_php()
{
    local config="$1"
    add_string 'AddType[[:space:]]*application/x-httpd-php[[:space:]]*\.php' 		"AddType application/x-httpd-php .php" "$config"
		
    add_string 'AddType[[:space:]]*application/x-httpd-php-source[[:space:]]*\.phps' 		"AddType application/x-httpd-php-source .phps" "$config"
}

apache_conf_add_listen_443()
{
    local config="$1"

    sed -i -e "/^Listen[[:space:]]*443/d" "$config"
    add_string '[[:space:]]*Listen[[:space:]]*443' 		"Listen 443" "$config"
}

apache_conf_comment_AddDefaultCharset()
{
	local config="$1"

	sed -e "s/^\(AddDefaultCharset\)/#\1/g" 		< $config > $config.tmp
	mv -f $config.tmp $config

}

apache_insert_include()
{
	local target_conf="$1"
	local include_str="Include[[:space:]]*conf/zz010_psa_httpd.conf"
	if ! grep -q "$include_str" $target_conf; then
		include_str="Include[[:space:]]*${apache_httpd_include}"
		if ! grep -q "$include_str" $target_conf; then
			include_str="*.conf"
			if ! grep -q "$include_str" $target_conf; then
				echo "" >> $target_conf
				echo "Include ${apache_httpd_include}" >> $target_conf 					|| die "insert include directive into $target_conf file"
			fi
		fi
	fi
}

apache_remove_include()
{
	local target_conf="$1"
	#remove old string
	local include_str="Include[[:space:]]*(/etc.*)?/httpd.include"
	grep -v -E "$include_str" $target_conf > $target_conf.tmp
	mv -f $target_conf.tmp $target_conf
	[ -f "$HTTPD_CONF_D/httpd.include.new" ] && rm -f "$HTTPD_CONF_D/httpd.include.new"
	[ -f "$HTTPD_CONF_D/httpd.include" ] && mv -f "$HTTPD_CONF_D/httpd.include" "$HTTPD_CONF_D/httpd.include_old_plesk_config"
	#remove new string
	local include_str="Include[[:space:]]*conf/zz010_psa_httpd.conf"
	grep -v "$include_str" $target_conf > $target_conf.tmp
	mv -f $target_conf.tmp $target_conf
}

apache_conf_addon()
{
	local target_conf
	if [ -f $apache_httpd_conf2 ]; then
		target_conf="$apache_httpd_conf2"
	else
		target_conf="$apache_httpd_conf"
	fi

	apache_conf_add_dirindex index.shtml $target_conf after
	apache_conf_add_dirindex index.cfm $target_conf after
	apache_conf_add_dirindex index.php $target_conf after
	apache_conf_add_dirindex index.htm $target_conf after

	apache_conf_add_type_shtml $target_conf
	apache_conf_add_type_php $target_conf

	apache_conf_comment_AddDefaultCharset $target_conf

	apache_insert_include $target_conf
}

apache2_conf_addon()
{
	local target_conf
	if [ -f $apache_httpd_conf2 ]; then
		target_conf="$apache_httpd_conf2"
	else
		target_conf="$apache_httpd_conf"
	fi

	add_string 'GracefulShutDownTimeout[[:space:]]*[0-9]*' 		"GracefulShutDownTimeout 3" $target_conf

	add_string 'AddOutputFilter[[:space:]]*INCLUDES[[:space:]]*\.shtml' 		"AddOutputFilter INCLUDES .shtml" $target_conf

	apache_remove_include $target_conf
	insert_load_module_logio $target_conf

	# This must be the last statement in the function
	apache_conf_addon
}

apache_platform_dependent()
{
	# for Mandrake
		apache_commonhttpd_conf="$HTTPD_CONF_D/commonhttpd.conf"
		if [ -f $apache_commonhttpd_conf ]; then
			apache_conf_add_dirindex index.shtml $apache_commonhttpd_conf after
			apache_conf_add_dirindex index.cfm $apache_commonhttpd_conf after
		fi

	# for SuSE
		apache_listen_conf="$HTTPD_CONF_D/listen.conf"
		if [ -f $apache_listen_conf ]; then
			apache_conf_add_listen_443 $apache_listen_conf
		fi

		apache_mime_default="$HTTPD_CONF_D/mod_mime-defaults.conf"
		if [ -f $apache_mime_default ]; then
			apache_conf_comment_AddDefaultCharset $apache_mime_default
			add_string 'AddOutputFilter[[:space:]]*INCLUDES[[:space:]]*\.shtml' 				"AddOutputFilter INCLUDES .shtml" $apache_mime_default
		fi

	# for Debian
		apache_listen_conf="$HTTPD_CONF_D/ports.conf"
		if [ -f $apache_listen_conf ]; then
			apache_conf_add_listen_443 $apache_listen_conf
		fi
		dir_index_conf="$HTTPD_CONF_D/mods-enabled/dir.conf"
		if [ -f $dir_index_conf ]; then
			apache_conf_add_dirindex at_domains_index.html $dir_index_conf before
			apache_conf_add_dirindex index.shtml $dir_index_conf after
			apache_conf_add_dirindex index.cfm $dir_index_conf after
			apache_conf_add_dirindex index.php $dir_index_conf after
			apache_conf_add_dirindex index.htm $dir_index_conf after
		fi

	# Add mod_ssl in Debian
	add_apache_module ssl

	# Add mod_python for FreeBSD
	if [ "X$machine" = "XBSD" ]; then
		add_apache_module python
	fi

}

install_apache()
{
	if [ "X$DEMO_VERSION" = "Xyes" ]; then
		return 0;
	fi

	p_echo
	p_echo "===> Installing Apache Server"

	fix_apache_path
	pleskrc apache stop

	# insert NameVirtualHost IP into the MySQL database, if no

	if [ 0${do_upgrade} -eq 0 ]; then
		inten="insert default PTR to the MySQL database"
		echo_try $inten
		
		if [ "X${fullhost}" = "X" -o "X${ipaddress}" = "X" ]; then
			die "fullhost or ipaddress not defined"
		fi
		
		query="
			REPLACE INTO dns_zone SET
				name='${fullhost}',
				displayName='${fullhost}';
			SELECT LAST_INSERT_ID();"
		default_dns_zone_id=`echo ${query} | $mysql`
		query="
			REPLACE INTO misc SET
				param='default_dns_zone_id',
				val='${default_dns_zone_id}';"
		echo $query | $mysql || die $inten
		local ip_addr
		for ip_addr in ${ipaddress};do
			db_do "REPLACE dns_recs SET dns_zone_id='${default_dns_zone_id}', 					type='PTR', host='$ip_addr', val='${fullhost}.', 					displayHost='$ip_addr', displayVal='${fullhost}.', 					opt='24'"
		done
	fi

	pnnl_echo " Copying apache files... "

	if [ -f "$apache_httpd_conf_in" -a ! -f "$apache_httpd_conf2" ]; then
		if [ -f "$apache_httpd_conf" ]; then
			mk_backup $apache_httpd_conf cp f
		fi
		if [ ! -f "$apache_httpd_conf" ]; then
			cp "$apache_httpd_conf_in" "$apache_httpd_conf" || die "copy httpd.conf file"
			sed -e "s|wwwrun|$apache_user|g" 				-e "s|www|$apache_group|g" 				-e "s|/srv/www/vhosts|$HTTPD_VHOSTS_D|g" 				-e "s|/usr|$APACHE_ROOT|g" 				< "$apache_httpd_conf_in" > "$apache_httpd_conf" || die
			apache_optim
		fi
	fi

	apache2_conf_addon

	# Insert things for other linux platforms
	apache_platform_dependent

	echo "ServerName $fullhost" > $apache_httpd_include 		|| die "initialize $apache_httpd_include file"

	suc

	set_ssl_certs
	
	touch /etc/apache2/sysconfig.d/include.conf || :

	# Upgrade cannot handle this situation correctly because of old database
	if [ "X${do_upgrade}" != "X1" ]; then
	    inten="reconfigure Apache"
	    echo_try $inten
	    $PRODUCT_ROOT_D/admin/sbin/httpdmng --reconfigure-all  >> $product_log 2>&1 && suc || warn "$inten. Please rerurn $PRODUCT_ROOT_D/admin/sbin/httpdmng --reconfigure-all manually"
	fi

	add_manpath "$APACHE_ROOT/man"

	move_sitebuilder_conf

}

insert_load_module_logio()
{
	local sysconfig_apache2='/etc/sysconfig/apache2'
        local modules_d=`basename $apache_modules_d`

	if [ -f "$sysconfig_apache2" ]; then
		# If $sysconfig_apache2 exists, then we are on SLES,
		# and the module has been added by the stub in psa.spec.
		true
	elif [ -d "${HTTPD_CONF_D}/mods-available" -a -d "${HTTPD_CONF_D}/mods-enabled" ]; then
		# Debian
		if [ -f "${HTTPD_CONF_D}/mods-available/logio.load" ]; then
			ln -sf "${HTTPD_CONF_D}/mods-available/logio.load" 				"${HTTPD_CONF_D}/mods-enabled/logio.load"
		fi # Otherwise, the logio module is built into Apache
	else
		if [ "$conceived_os_vendor" != "RedHat" ]; then
			add_apache_module logio
		fi # RedHat 9 and RHAS 3 don't have mod_logio.so, we ignore this
	fi
}

module_exists()
{
	local dir
	[ -n "$1" ] || return 1
	test -n "$2" && test -e "${apache_modules_d}/$2" && return
	test -e "${apache_modules_d}/mod_$1.so" && return
	if [ -n "${additional_apache_modules_d}" ]; then
		for dir in $additional_apache_modules_d; do 
			if [ -f "${dir}/mod_$1.so"  ] ; then return ; fi
			if [ -n "$2" -a -f "${dir}/$2" ] ; then return ; fi
		done
	fi
	return 1
}

# Run before it
#        read_conf
#        # set_common_params
#        set_apache_params
add_apache_module()
{
	local module_name="$1"
	local module_soname="$2" # optional
	local config="$3" # optional

	if ! module_exists $module_name "$module_soname"; then
		# TODO : fix message error
		p_echo "Shared object mod_${module_name}.so not found in ${apache_modules_d}...skipped."
		return
	fi

		if [ -x /usr/sbin/a2enmod ]; then
			/usr/sbin/a2enmod $module_name
		else
			warn "a2enmod utilily not found! Module $module_name was NOT enabled."
		fi
}

true apache_status_linux_debian apache_stop_BSD

apache_status_linux_debian()
{
	get_pid "/usr/sbin/apache2" false
	local pid=$common_var
	if test "$pid" -ne 1; then
# running
		return 0
	fi
	return 1
}

apache_stop_BSD()
{
	local apache_script

	if [ "$std_to_pkg" -ne 0 ]; then
		apache_script="$PRODUCT_ROOT_D/rc.d/httpd"
	else
		apache_script="$PRODUCT_RC_D/$apache_service_name"
	fi

	$apache_script stop 2>/dev/null
}
set_suexec_perms()
{
	set_ac root ${apache_group} 4510 $suexec
}

install_suexec()
{
	[ -f "$suexec_storage/$PRODNAME-$suexec_file" ] || return 0

	p_echo "===> Installing $suexec replacement"
	if [ -x "/usr/sbin/dpkg-divert" ]; then
		dpkg-divert --package psa --add --rename 					$suexec  >> $product_log 
	else
		local inten="backup original $suexec"
		echo_try $inten
		if [ -f $suexec ]; then
			rm -f $suexec.$product_suffo
			cp -fp $suexec $suexec.$product_suffo
			rm -f $suexec
		else
			warn "$inten"
			echo "Original suexec ($suexec) not found" >> $product_log
		fi
		suc
	fi
	cp -pfv	$suexec_storage/$PRODNAME-$suexec_file $suexec >>$product_log

	set_suexec_perms

	case $machine in
	    BSD*)
		which httpd || die "Unable to find apache server"	
		$HTTPD_BIN -V | grep -q SUEXEC_BIN
		if [ "$?" -ne "0" ]; then 
		    add_apache_module "suexec"
		fi
	    ;;
	    *)
		    add_apache_module "suexec"
	    ;;
	esac
}


create_php_ini_1011()
{
	echo_try "Create per-vhost php.ini for php over cgi/fastcgi"
	sw_engine_pleskrun $PRODUCT_ROOT_D/admin/plib/scripts/php_ini_update_1011.php && suc || warn "fail\nCannot create per-vhost php.ini for php over cgi/fastcgi.Please run $PRODUCT_ROOT_D/admin/plib/scripts/php_ini_update_1011.php.php manually."
}
api_rpc_create_persistent_tables()
{
	inten="create persistent database storage"
	echo_try $inten
	$mysql < $PRODUCT_BOOTSTRAPPER_DIR/db/api-rpc/api-rpc_db.sql

	if [ "X$?" = "X0" ]; then
		suc
	else
		warn "database initialization"
	fi
}

#
# Upgrade triggers should be clever enough to recognize necessity of upgrade
#
upgrade_api_75()
{
	if db_test_table secret_keys; then
		# secret_keys was created - at least 8.0 version
		return
	fi

	$mysql < $PRODUCT_BOOTSTRAPPER_DIR/db/api-rpc/api-rpc_db_upgrade_750.sql
}

upgrade_api_800()
{
	if db_test_column_enum_value exp_event event_type exceeded; then
		# 'exceeded' was added in 8.0.1
		return
	fi

	$mysql < $PRODUCT_BOOTSTRAPPER_DIR/db/api-rpc/api-rpc_db_upgrade_800.sql
}

upgrade_api_801()
{
	if db_test_column_enum_value exp_event obj_class domain_alias; then
		# domain_alias was added in 8.0.1 update
		return
	fi

	$mysql < $PRODUCT_BOOTSTRAPPER_DIR/db/api-rpc/api-rpc_db_upgrade_801.sql
}

upgrade_api_830()
{
  $mysql < $PRODUCT_BOOTSTRAPPER_DIR/db/api-rpc/api-rpc_db_upgrade_830.sql
}

upgrade_api_840()
{
  $mysql < $PRODUCT_BOOTSTRAPPER_DIR/db/api-rpc/api-rpc_db_upgrade_840.sql
}

upgrade_api_860()
{
  $mysql < $PRODUCT_BOOTSTRAPPER_DIR/db/api-rpc/api-rpc_db_upgrade_860.sql
}

#
# End of upgrade triggers
#

api_rpc_upgrade_persistent_tables()
{
	inten="upgrade persistent database storage"
	echo_try $inten

	# As we don't know previous version of the package (for all packaging systems)
	# all available database upgrade scripts should be executed.
	upgrade_api_75 && 	upgrade_api_800 && 	upgrade_api_801 &&     upgrade_api_830 &&     upgrade_api_840 &&     upgrade_api_860

	if [ "X$?" = "X0" ]; then
		suc
	else
		warn "database upgrade"
	fi
}
apsc_import_data_1011()
{
	sw_engine_pleskrun $PRODUCT_ROOT_D/admin/plib/scripts/aps-controller-data-import.php 2>>"$product_log"
	[ "$?" -eq 0 ] || 		warn "cannot import data to APS controller database. Please rerun $PRODUCT_ROOT_D/admin/plib/scripts/aps-controller-data-import.php manually"
}

#-*- vim:syntax=sh

repeat_until_succeeds()
{
	local repeat_func="$1"
	local modify_func="$2"
	local max_times="$3"

	for i in `seq 1 "$max_times"`; do
		eval "$repeat_func" && return 0 || eval "$modify_func"
	done
	return 1
}

apsc_try_create_db()
{
	local mysql_db_name="mysql"
	echo "CREATE DATABASE $apsc_db_name" | mysql >> "$product_log" 2>&1
}

apsc_modify_db_name()
{
	apsc_db_name="${apsc_db_name_base}_`get_random_string 4 'a-z0-9'`"
}

apsc_try_create_db_user()
{
	local mysql_db_name="mysql"
	echo "CREATE USER '$apsc_db_user'@'localhost' IDENTIFIED BY '$apsc_db_passwd'" | mysql >> "$product_log" 2>&1 && 	echo "GRANT ALL PRIVILEGES ON $apsc_db_name.* TO '$apsc_db_user'@'localhost'" | mysql >> "$product_log" 2>&1
}

apsc_modify_db_user()
{
	apsc_db_user="${apsc_db_user_base}_`get_random_string 4 'a-z0-9'`"
}

apsc_init_db()
{
	local mysql_db_name="$apsc_db_name"
	local mysql_user="--user=$apsc_db_user"
	local mysql_passwd="--password=$apsc_db_passwd"
	local sql_dump_file="$PRODUCT_BOOTSTRAPPER_DIR/db/apsc_mysql_db.sql"

	[ -r "$sql_dump_file" ] || return 1
	mysql < "$sql_dump_file" >> "$product_log" 2>&1
}

apsc_remove_db()
{
	[ -n "$apsc_db_name" ] || return
	local mysql_db_name="mysql"
	echo "DROP DATABASE $apsc_db_name" | mysql >> "$product_log" 2>&1
}

apsc_remove_db_user()
{
	[ -n "$apsc_db_user" ] || return
	local mysql_db_name="mysql"
	echo "DROP USER '$apsc_db_user'@'localhost'" | mysql >> "$product_log" 2>&1
}

set_apsc_params()
{
	odbc_config_bin="/usr/bin/odbc_config" # present at least on CentOS 5
	if [ -x "$odbc_config_bin" ]; then
		odbc_dsn_conf=`$odbc_config_bin --odbcini 2>> "$product_log"`
		odbc_drivers_conf=`$odbc_config_bin --odbcinstini 2>> "$product_log"`
	fi
	if [ -z "$odbc_dsn_conf" ]; then
		odbc_dsn_conf="/etc/odbc.ini"
	fi
	if [ -z "$odbc_drivers_conf" ]; then
		odbc_drivers_conf="/etc/odbcinst.ini"
	fi

	odbc_isql_bin="/usr/bin/isql"
	odbc_iusql_bin="/usr/bin/iusql"

	odbc_mysql_driver="/usr/lib/libmyodbc5.so"
	odbc_isql_bin=

	apsc_driver_library="/usr/lib/libmysqlserver.so.2"
}

apsc_sanity_check_binaries()
{
	# To easily detect breakage on new OSes
	[ -f "$odbc_mysql_driver" ] || die "find MySQL ODBC driver"
	[ -f "$apsc_driver_library" ] || die "find MySQL platform driver library"
}

read_apsc_connection_param_db()
{
	local param="$1"
	db_select "SELECT val FROM misc WHERE param like 'aps_$param'"
	echo "$db_select_output"
}

save_apsc_connection_params_db()
{
	db_do "REPLACE INTO misc (param, val) VALUES 				('aps_database', '$apsc_db_name'), 				('aps_login', '$apsc_db_user'), 				('aps_password', '$apsc_db_passwd'), 				('aps_host', 'localhost'), 				('aps_port', '3306')"
}

save_apsc_connection_params_conf()
{
	conf_setval "$prod_conf_t" APS_DB_DRIVER_LIBRARY "$apsc_driver_library"
}

save_apsc_connection_params()
{
	save_apsc_connection_params_conf || die "store driver library path for APS controller db connection"
	save_apsc_connection_params_db || die "store APS controller db connection parameters into product db"
}

check_ini_section_exists()
{
	local section="$1"
	local file="$2"
	grep -q "\[$section\]" "$file" >/dev/null 2>&1
}

check_odbc_driver_exists()
{
	# We could use odbcinst here, but it wouldn't save us much trouble
	local driver="$1"
	check_ini_section_exists "$driver" "$odbc_drivers_conf"
}

check_odbc_dsn_exists()
{
	local dsn="$1"
	check_ini_section_exists "$dsn" "$odbc_dsn_conf"
}

remove_ini_section()
{
	local section="$1"
	local file="$2"
	[ -r "$file" ] || return 0
	awk "/\[.*\]/ { del = 0 } /\[$section\]/ { del = 1 } ( del != 1 ) { print }" "$file" > "$file.new" && 	mv -f "$file.new" "$file"
}

remove_odbc_driver()
{
	local driver="$1"
	remove_ini_section "$driver" "$odbc_drivers_conf"
}

remove_odbc_dsn()
{
	local dsn="$1"
	remove_ini_section "$dsn" "$odbc_dsn_conf"
}

apsc_try_create_odbc_driver()
{
	check_odbc_driver_exists "$apsc_odbc_driver_name" && return 1

	local odbc_mysql_driver64=
	if echo "$odbc_mysql_driver" | grep -q lib64 2>/dev/null ; then
		odbc_mysql_driver64="$odbc_mysql_driver"
	fi

	cp -f "$odbc_drivers_conf" "$odbc_drivers_conf.new" && 	cat <<EOF >> "$odbc_drivers_conf.new" && mv -f "$odbc_drivers_conf.new" "$odbc_drivers_conf"
[$apsc_odbc_driver_name]
Description = MySQL driver for Plesk
Driver      = $odbc_mysql_driver
Setup       = 
FileUsage   = 1
Driver64    = $odbc_mysql_driver64
Setup64     = 
UsageCount  = 1

EOF
	local rc="$?"
	[ "$rc" -eq 0 ] || rm -f "$odbc_drivers_conf.new"
	return "$rc"
}

apsc_try_create_odbc_dsn()
{
	check_odbc_dsn_exists "$apsc_dsn_name" && return 1

	cp -f "$odbc_dsn_conf" "$odbc_dsn_conf.new" && 	cat <<EOF >> "$odbc_dsn_conf.new" && mv -f "$odbc_dsn_conf.new" "$odbc_dsn_conf"
[$apsc_dsn_name]
Description = MySQL APS controller database (temporary DSN)
Driver      = $apsc_odbc_driver_name
SERVER      = localhost
USER        = $apsc_db_user
PASSWORD    = $apsc_db_passwd
PORT        = 3306
DATABASE    = $apsc_db_name

EOF
	local rc="$?"
	[ "$rc" -eq 0 ] || rm -f "$odbc_dsn_conf.new"
	return "$rc"
}

apsc_modify_odbc_driver()
{
	# just remove the one that bothers us
	remove_odbc_driver "$apsc_odbc_driver_name"
}

apsc_modify_odbc_dsn()
{
	apsc_dsn_name="${apsc_dsn_name_base}_`get_random_string 4 'a-z0-9'`"
}

check_apsc_installed()
{
	local db_name=`read_apsc_connection_param_db "database"`

	[ -n "$db_name" ] || return 1
	db_test_database "$db_name"
}

odbc_test_connection_using_dsn()
{
	local dsn="$1"
	local isql_bin="$2"
	[ -n "$isql_bin" ] || return 1
	p_echo "Attempting to check APS db connection via ODBC, using $isql_bin (empty output is good)"
	if [ ! -x "$isql_bin" ]; then
		p_echo " Executable $isql_bin was not found, skipped."
		return 1
	fi

	echo "" | $isql_bin -b "$dsn" >> "$product_log" 2>&1
	local rc="$?"

	[ "$rc" -eq 0 ] || p_echo " Failed, rc = $rc."
	return $rc
}

odbc_test_connection()
{
	if [ ! -x "$odbc_isql_bin" -a ! -x "$odbc_iusql_bin" ]; then
		warn "isql utilities were not found. APS db accessibility check was skipped."
		return 0
	fi

	local apsc_dsn_name_base="apsc"
	local apsc_dsn_name="$apsc_dsn_name_base"

	[ -r "$odbc_dsn_conf" ] || die "find ODBC config"
	repeat_until_succeeds apsc_try_create_odbc_dsn apsc_modify_odbc_dsn 50 || die "create ODBC DSN"

	odbc_test_connection_using_dsn "$apsc_dsn_name" "$odbc_isql_bin" || 	odbc_test_connection_using_dsn "$apsc_dsn_name" "$odbc_iusql_bin"
	local rc="$?"

	remove_odbc_dsn "$apsc_dsn_name"

	return $rc
}

upgrade_apsc()
{
	:
}

install_apsc()
{
	set_apsc_params

	if check_apsc_installed; then
		inten="upgrade APS controller database"
		echo_try "$inten"
		upgrade_apsc && 		suc || warn "$inten"
	else
		inten="set up APS controller database"
		echo_try "$inten"

		apsc_db_name_base="apsc"
		apsc_db_name="$apsc_db_name_base"
		apsc_db_user_base="apsc"
		apsc_db_user="$apsc_db_user_base"
		apsc_db_passwd=`get_random_string 12 'A-Za-z0-9_'`

		repeat_until_succeeds apsc_try_create_db      apsc_modify_db_name 50 && 		repeat_until_succeeds apsc_try_create_db_user apsc_modify_db_user 50 && 		apsc_init_db || die "create database for APS controller"

		apsc_odbc_driver_name="MySQL"

		[ -r "$odbc_drivers_conf" ] || die "find ODBC drivers config"
		apsc_sanity_check_binaries
		repeat_until_succeeds apsc_try_create_odbc_driver apsc_modify_odbc_driver 50 || die "create ODBC driver configuration"

		if odbc_test_connection ; then
			save_apsc_connection_params

			suc
		else
			p_echo "Failed to establish test connection. Cleaning up."

			remove_odbc_driver "$apsc_odbc_driver_name"
			apsc_remove_db_user
			apsc_remove_db

			die "establish test connection to APS database via ODBC"
		fi
	fi
}


#awstats

set_awstats_params()
{
	AWSTATS_ROOT_D="$PRODUCT_ROOT_D/awstats"
}

upgrade_awstats_82()
{
	# domains with physical hosting and 'awstats' statistics
	query="SELECT d.id FROM domains d, hosting h WHERE d.id=h.dom_id AND d.htype='vrt_hst' AND h.webstat='awstats';"

	for dom_id in `echo "$query" | ${mysql}`; do   

		query1="select name from domains where id='$dom_id';"
		dom_name=`echo "$query1" | ${mysql}`

		for dir in webstat anon_ftpstat ftpstat webstat-ssl ; do
			cd $HTTPD_VHOSTS_D/$dom_name/statistics/$dir
			year_month=`date +%Y-%m`
			if [ ! -d $year_month ]; then
				mkdir -p $year_month
				mv * $year_month >/dev/null 2>&1
				ln -sf $year_month current
			fi
		done

		inten="set awstats configs on virtual host $dom_name"
		"$UTILS_DIR"/webstatmng --set-configs --stat-prog=awstats --domain-name=${dom_name} 				>> "$product_log" 2>&1 				|| report_problem "$inten" "Probably set awstats configs on '$dom_name' is broken"
	done

}

upgrade_awstats_84()
{
	local f
	echo_try "fix awstats domain configs"

# Get DirData="/<VHOSTS_D>/<domain_name>/statistics/<stat_type>/current" from 
# evry awstats-enabled dowain statistics; strip '/current' and copy data to
# new location
	for f in $PRODUCT_ROOT_D/etc/awstats/*.conf;do
		local datadir=`cat $f | perl -n -e 'next if(/^;/);  print $5 if(/^(\s*)DirData(\s*)=(\s*)("*)(.*?)("|\s|;)/);'`
		[ -n "$datadir" ] || continue
		[ "`basename $datadir`" = "current" ] || continue

		local tmp_file=`mktemp /tmp/aws-confXXXXXX`
		cat $f | awk -v datadir="`dirname $datadir`" '
		{
			if ($0 ~ /^[ \t]*DirData[ \t]*=/) {
				printf("DirData=%s\n", datadir);
			} else {
				print $0;
			}
		}' >$tmp_file && mv -f $tmp_file $f >> $product_log 2>&1
		if [ "$?" -ne "0" ];then
			warn "Unable to fix $f"
			continue
		fi
   		rm -f $tmp_file 
		cp -fv $datadir/*.txt `dirname $datadir` >> $product_log 2>&1
	done
}
# Backup manager tables will be managed by plesk

migrate_backup_management_db_into_core_1011()
{
# Remove backupmng from root crontab. Will be moved to system /etc/cron.d
	remove_from_crontab "$PRODUCT_ROOT_D/admin/sbin/backupmng"

	if ! db_test_table "BackupsScheduled"; then
# Perform installation of backup manager schema
		$mysql < ${PRODUCT_BOOTSTRAPPER_DIR}/db/pbm_db.sql
		[ "$?" = "0" ] || die "install backup manager tables during upgrade"
	else
# Perform upgrade of backup manager schema
		upgrade_pbm_80
		upgrade_pbm_801
		upgrade_pbm_900
	fi
# preserve number of simultaneously running backups
	db_select "SELECT val FROM misc WHERE param='max_bu_proc_number'"
	[ -n "$db_select_output" ] || 		db_do "INSERT INTO misc VALUES('max_bu_proc_number', 10)"

# remove BackupsRunning
	db_fix_drop_table "BackupsRunning"
}

upgrade_pbm_80()
{
	if db_test_column BackupsScheduled repository; then
		# repository appeared in 8.1
		return
	fi

	$mysql < ${PRODUCT_BOOTSTRAPPER_DIR}/db/pbm_db_upgrade_80.sql
}

upgrade_pbm_801()
{
	if db_test_column BackupsScheduled split_size; then
		# split_size appeared in 8.1
		return
	fi

	$mysql < ${PRODUCT_BOOTSTRAPPER_DIR}/db/pbm_db_upgrade_801.sql
}

upgrade_pbm_900()
{
	if db_test_column_enum_value BackupsScheduled obj_type reseller; then
		# resseller type appeared in 9.0
		return
	fi

	$mysql < ${PRODUCT_BOOTSTRAPPER_DIR}/db/pbm_db_upgrade_900.sql
}

pbm_create_certificate()
{
	local inten="generate certificate for backup signing"

	[ -x "$PRODUCT_ROOT_D/admin/sbin/backup_sign" ] || return 0

	if db_select "select val from misc where param='bu_cert_id'" && [ -n "$db_select_output"  ]; then
#	Nothing to be done
		return
	fi

	echo_try $inten

	if $PRODUCT_ROOT_D/admin/sbin/backup_sign generate >> $product_log 2>&1; then
		warn "backup certificate generation"
		return 1
	fi

	suc
}
move_sitebuilder_conf()
{
	if [ ! -f "$HTTPD_INCLUDE_D/zz011_sitebuilder.conf" -a -f "$HTTPD_INCLUDE_D/sitebuilder.conf" ]; then
		mv -f "$HTTPD_INCLUDE_D/sitebuilder.conf" "$HTTPD_INCLUDE_D/zz011_sitebuilder.conf"
	fi

	if [ ! -f "$HTTPD_INCLUDE_D/zz011_sitebuilder.conf" -a -f "$HTTPD_CONF_D/sitebuilder.conf" ]; then
		mv -f "$HTTPD_CONF_D/sitebuilder.conf" "$HTTPD_INCLUDE_D/zz011_sitebuilder.conf"
	fi
}
#!/bin/sh

chroot_warning_prgtype()
{
	local prg type
	prg="$1"
	type="$2"

	p_echo "$prg: $type"
	p_echo "probably it will not work in chrooted accounts"
	warn "register $prg in chrooted environment"
}

install_chroot_program()
{
	local inten prg cp_update filetype libdir libdir64
	inten="register $1 in chroot"
	prg="$1"
	libdir="$2"
	libdir64="$3"

	filetype=`file -ib "$prg"`

	case "$filetype" in
	application/x-executable*statically' 'linked*) 	;;
	application/x-shellscript*|text/x-shellscript*) ;;
	application/x-executable*|application/x-sharedlib*)
		# sometimes 'file' say the executable is a shared library
		# newer OSes also say just "executable" without distibguishind between static and dynamic
		ldd "$prg" | awk '/not found/ { print; exit 1; }
						/not a dynamic executable/ { exit 0; }
						NR=4 && $1 !~ /^\// && $2=="=>" && $4 ~ /\(0x[[:xdigit:]]*\)/ {
							  if ($3 ~ /\/lib64\//) {
								dir = DIR64;
							  } else {
								dir = DIR;
							  }
							  if (system("cp -v -p " CP_UPDATE " " $3 " " dir "/" $1)!=0)
								{ exit 1; }
							}
					' DIR="$libdir" DIR64="$libdir64" CP_UPDATE="$cp_update" >> "$product_log" 2>&1 || report_problem "$inten"
		;;
	application/octet-strea*)
		;;
	*)
		chroot_warning_prgtype "$prg" "$filetype"
		;;
	esac
}

install_chroot_base()
{
	local libdir libdir64

	CHROOT_ROOT_D="$HTTPD_VHOSTS_D/chroot"
	CHROOT_PROGRAMS="bash cat cp grep head id less ln ls mkdir more 			mv pwd rm rmdir sash sh tail touch du vi true false scp groups"
	if [ -z "chrootmng_executable" ] ; then
		chrootmng_executable="$PRODUCT_ROOT_D/admin/sbin/chrootmng"
	fi
	os=`uname -s`
	case "$os" in
		Linux)
			cp_update=-u
			libdir="$CHROOT_ROOT_D/lib"
			libdir64="$CHROOT_ROOT_D/lib64"
			;;
		FreeBSD)
			cp_update=-n
			libdir="$CHROOT_ROOT_D/usr/lib"
			;;
		*) die "unknown system $os" ;;
	esac
	copy="cp -v -p $cp_update"
	echo_try "install chrooted environment"

# see http://plesk-process.parallels.com/TargetProcess2/Project/Planning/UserStory/View.aspx?UserStoryID=70752&list=STATE_62904_ctl00_mainArea_us_userStoryGridCOMPLETE&ProjectID=62904
#	if test -d "$CHROOT_ROOT_D/etc"; then
#		"$chrootmng_executable" #				--remove --target=all --source="$CHROOT_ROOT_D" >>"$product_log" 2>&1 #			|| report_problem "cleanup chrooted environments on existing domains"
#	fi

	mkdir -m 755 -p "$CHROOT_ROOT_D"
	chown 0:0 "$CHROOT_ROOT_D"

	mkdir -m 755 -p "$CHROOT_ROOT_D/bin"
	mkdir -m 755 -p "$CHROOT_ROOT_D/dev"
	mkdir -m 755 -p "$CHROOT_ROOT_D/lib"
	[ -d /lib64 ] && mkdir -m 755 -p "$CHROOT_ROOT_D/lib64"
	mkdir -m 755 -p "$CHROOT_ROOT_D/usr"
	mkdir -m 755 -p "$CHROOT_ROOT_D/usr/lib"
	[ -d /usr/libexec ] && mkdir -m 755 -p "$CHROOT_ROOT_D/usr/libexec"
	[ -d /libexec ] && mkdir -m 755 -p "$CHROOT_ROOT_D/libexec"
	mkdir -m 755 -p "$CHROOT_ROOT_D/etc"
	mkdir -m 1777 -p "$CHROOT_ROOT_D/tmp"
	mkdir -m 755 -p "$CHROOT_ROOT_D/var"
	mkdir -m 1777 -p "$CHROOT_ROOT_D/var/tmp"

	case "$os" in
	Linux)
		mknod -m 666 "$CHROOT_ROOT_D/dev/null" c 1 3
		chown root:root "$CHROOT_ROOT_D/dev/null"
		;;
	FreeBSD)
		mknod "$CHROOT_ROOT_D/dev/null" c 1 3 root:wheel
		chmod 666 "$CHROOT_ROOT_D/dev/null"
		;;
	*) die "unknown system $os" ;;
	esac

	cd "$CHROOT_ROOT_D/bin"
	for f in $CHROOT_PROGRAMS; do
		path=`which "$f" 2>>"$product_log"`
		found=$?
		if test $found -eq 0 -a -x "$path"; then
			cp -v -p "$path" "$f" >> "$product_log" 2>&1
			install_chroot_program "$f" "$libdir" "$libdir64"
		fi
	done

	echo_try "install sftp-server binary into chroot environment"

	sftp_path="$(awk '/^Subsystem[[:space:]]sftp.*$/ {print $3}' < /etc/ssh/sshd_config)"
	sftp_dir="${sftp_path%/*}"

	if [ -z "$sftp_dir" ]; then
		echo "Warning: sftp-server binary not found" >> "$product_log"
		echo "+ sftp connections will not be available for chrooted accounts" >> "$product_log"
		warn "installation of sftp-server binary into chroot environment"
	else
		mkdir -p "$CHROOT_ROOT_D$sftp_dir" >> "$product_log" 2>&1
		cp -v -p "$sftp_path" "$CHROOT_ROOT_D$sftp_path" >> "$product_log" 2>&1
		suc
		install_chroot_program "$CHROOT_ROOT_D$sftp_path" "$libdir" "$libdir64"
	fi

	case "$os" in
	Linux)
		$copy /lib/ld-linux* /lib/libnss_*.so.2  "$CHROOT_ROOT_D/lib" >> "$product_log" 2>&1
		if [ -d /lib64 ]; then
			$copy /lib64/ld-linux* /lib64/libnss_*.so.2  "$CHROOT_ROOT_D/lib64" >> "$product_log" 2>&1
		fi
		;;
	FreeBSD)
		$copy /usr/libexec/ld-elf.so.* "$CHROOT_ROOT_D/usr/libexec" >> "$product_log" 2>&1
		$copy /libexec/ld-elf.so.* "$CHROOT_ROOT_D/libexec" >> "$product_log" 2>&1
		mkdir -m 755 -p "$CHROOT_ROOT_D/usr/share"
		mkdir -m 755 -p "$CHROOT_ROOT_D/usr/share/misc"
		cp -v -p /etc/termcap "$CHROOT_ROOT_D/usr/share/misc/termcap" >> "$product_log" 2>&1
		;;
	esac

	if test -r /etc/termcap; then
		cp -v -p /etc/termcap "$CHROOT_ROOT_D/etc/termcap" >> "$product_log" 2>&1
	fi
	touch "$CHROOT_ROOT_D/etc/passwd"
	touch "$CHROOT_ROOT_D/etc/group"

	if test -d "$PRODUCT_ROOT_D/chroot"; then
		cd "$PRODUCT_ROOT_D/chroot"

		for f in *; do
			tar cpf - -C "$f" . | tar xpf - -C "$CHROOT_ROOT_D" || report_problem "copy $f to chroot parttern"
			find $d -type f -perm +111 | while read p; do
				install_chroot_program "$p" "$libdir" "$libdir64"
			done
		done
	fi

	# noschg flag does not allow hardlinking security
	if test "$os" = "FreeBSD"; then
		chflags -R noschg "$CHROOT_ROOT_D"
	fi

# see http://plesk-process.parallels.com/TargetProcess2/Project/Planning/UserStory/View.aspx?UserStoryID=70752&list=STATE_62904_ctl00_mainArea_us_userStoryGridCOMPLETE&ProjectID=62904
#	"$chrootmng_executable" #			--create --target=all --source="$CHROOT_ROOT_D" --safe >>"$product_log" 2>&1 #		|| report_problem "distribute chrooted environments on existing domains"

	suc

	selinux_relabel_dir -F "$CHROOT_ROOT_D"
}

set_chrootsh_perms()
{
	chgrp psacln $PRODUCT_ROOT_D/bin/chrootsh
	chmod 4750 $PRODUCT_ROOT_D/bin/chrootsh
}

# import certificate into database when installing
import_default_certificate()
{
	db_select "SELECT val FROM misc WHERE param = 'default_certificate_id'"

	local default_certificate_id="$db_select_output"

	if [ -z "$default_certificate_id" ]; then
# Update misc table if needed
		echo_try "import default certificate"
		import_certificate "$certificate_file"  "default certificate"

		db_do "REPLACE INTO misc set param='default_certificate_id', val='$last_certificate_id'"
		default_certificate_id="$last_certificate_id"
		suc
	fi

	db_select "SELECT val FROM misc WHERE param = 'cert_rep_id'"
	local admin_repository_id="$db_select_output"

	if [ -z "$admin_repository_id" ]; then
		echo_try "push default certificate into repository"
		db_select "REPLACE INTO Repository SET component_id='${default_certificate_id}';SELECT LAST_INSERT_ID();"
		admin_repository_id="$db_select_output"
		db_do "REPLACE INTO misc set param='cert_rep_id', val='${admin_repository_id}'"
	else
#	simple certificate insertion to repository
		db_do "REPLACE INTO Repository SET rep_id='${admin_repository_id}', component_id='${default_certificate_id}'"
	fi
}

# import certificate from a file to certificates table
# $1 - certoificate file path
# $2 - short description of certificate
# last_certificate_id variable will contain its identifier
import_certificate()
{
	local certificate_file certificate_comment inten

	certificate_file=$1
	certificate_comment=$2

	cert_pub_val=`cat ${certificate_file} |
		awk 'BEGIN { state=0 }
		{
			if (state == 0) {
				if (index($0, "-BEGIN CERTIFICATE-") != 0) state = 1;
			};
			if (state == 1) {
				print $0;
				if (index($0, "-END CERTIFICATE-") != 0) state = 2;
			}
		}' |
		perl -n -e 's/([^ A-Za-z0-9])/"%" . sprintf("%02X", unpack("C", $1))/ge; s/ /\+/g; print $_;'`

	cert_priv_val=`cat ${certificate_file} |
		awk 'BEGIN { state=0 }
		{
			if (state == 0) {
				if ((index($0, "-BEGIN ") != 0) &&
					(index($0, " PRIVATE KEY-") != 0)) state = 1;
			};

			if (state == 1) {
				print $0;
				if ((index($0, "-END ") != 0) &&
					(index($0, " PRIVATE KEY-") != 0)) state = 2;
			}
		}' |
		perl -n -e 's/([^ A-Za-z0-9])/"%" . sprintf("%02X", unpack("C", $1))/ge; s/ /\+/g; print $_;'`

	if [ ! -d "${PRODUCT_ROOT_D}"/var/certificates ]; then
		inten="creating directory for certificates"
		mkdir -p "${PRODUCT_ROOT_D}"/var/certificates || die ${inten}
		chown root:0 "${PRODUCT_ROOT_D}"/var/certificates || die ${inten}
		chmod 500 "${PRODUCT_ROOT_D}"/var/certificates || die ${inten}
	fi

	# copy certificate file to file repository
	newcertfile=`mktemp "${PRODUCT_ROOT_D}"/var/certificates/certXXXXXXX`

	cp "${certificate_file}" "${newcertfile}"  || die "place certificate to its directory"
	chown root:0 "${newcertfile}"
	chmod 400 "${newcertfile}"

	newcertfile=`basename ${newcertfile}`
	db_select "INSERT INTO certificates (pvt_key, cert, name, ca_cert, csr, cert_file, ca_file)
		VALUES ('${cert_priv_val}', '${cert_pub_val}', '${certificate_comment}', '', '',
			'${newcertfile}', '');
		SELECT LAST_INSERT_ID()"

	last_certificate_id="$db_select_output"
}

install_rbash()
{
	p_echo

	p_echo "===> Installing rbash"

	p_echo " Checking that $rbash_shell registered as login shell..."
	egrep "^$rbash_shell" /etc/shells >> $product_log 2>&1
	case $? in
		0)	p_echo " $rbash_shell is already registered as login shell"
			;;
		*)	
			if [ -f $bash_shell ]; then
				ln -sf $bash_shell $rbash_shell
				inten="add $rbash_shell to /etc/shells"
				echo_try $inten
				echo "$rbash_shell" >> /etc/shells && suc || die $inten
			fi
			;;
	esac
	p_echo
}
get_old_domain()
{
    if [ "X$domain" = "X" ]; then
		get_config_parameters
    fi
}

stop_before_upgrade()
{
	$START_SH stop 2>/dev/null || /usr/bin/killall -9 httpsd >> $product_log 2>&1
}
update_components_table()
{
	if [ "X${do_upgrade}" != "X1" ]; then
		return
	fi

	local inten="update Components"
	echo_try "$inten"

	db_do --inten "$inten" "DELETE FROM ServiceNodeProperties WHERE name LIKE 'server.packages.%'"
	suc

	packagemng_set_dirty_flag
}


#courier-imap

set_courier_imap_params()
{
	IMAPD_CERT="/usr/share/courier-imap/imapd.pem"
	POP3D_CERT="/usr/share/courier-imap/pop3d.pem"

	courier_service="courier-imap"
}

install_cron_somely()
{
    install_cron_somely_perform
}

set_cron_params()
{
    CRON_SOMELY_DIR_PREFIX=/etc/psa/plesk-cron
}

install_cron_somely_perform()
{
	set_cron_params

	daily_minute=`get_random_number 60`
	weekly_minute=`get_random_number 60`
	monthly_minute=`get_random_number 60`
	daily_hour=`get_random_number 6`
	weekly_hour=`get_random_number 7`
	monthly_hour=`get_random_number 7`

	# monthly must be after daily
	if [ $monthly_hour -lt $daily_hour ]; then
		swap=$daily_hour
		daily_hour=$monthly_hour
		monthly_hour=$swap
	elif [ $monthly_hour -eq $daily_hour ]; then
		monthly_hour=$(($monthly_hour + 1))
	fi

	install_cron_somely_entry "$daily_minute $daily_hour * * *" daily
	install_cron_somely_entry "$weekly_minute $weekly_hour * * 7" weekly
	install_cron_somely_entry "$monthly_minute $monthly_hour 1 * *" monthly
}

install_cron_somely_entry()
{
	run_parts="$PRODUCT_ROOT_D/bin/run-parts.sh"
	add_to_crontab "$1 $run_parts $CRON_SOMELY_DIR_PREFIX.$2" 		"$run_parts" "$CRON_SOMELY_DIR_PREFIX.$2" "root" "add $2 task"
}

add_to_crontab()
{
	local cron_string egrep_programm egrep_additional inten

	cron_string=$1
	egrep_programm=$2
	egrep_additional=$3
	user=$4
	inten=$5
	
	if [ "X$DEMO_VERSION" = "Xyes" ]; then 
		return 0;
	fi

	p_echo
	p_echo "===> Updating crontab..."
	
	$crontab -l 2>/dev/null > /tmp/crontab.${product}
	egrep "$egrep_programm" /tmp/crontab.${product} | egrep "$egrep_additional" | egrep -v "^#" > /dev/null 2>&1
	case "$?" in
		0)
			p_echo "$inten is already performed by cron"
			;;
		1)
			echo_try $inten
			echo "$1" >> /tmp/crontab.${product} || die $inten
			$crontab /tmp/crontab.${product} && suc || die $inten
			;;
		*)
			err
			;;
	esac

	rm -f /tmp/crontab.${product} || die
}

remove_from_crontab()
{
	program=$1

	echo_try "remove $program from crontab"

	cron_file=`mktemp /tmp/cronXXXXXX`
	$crontab -l 2>/dev/null | egrep -v "^[^#].*$program" > $cron_file
	$crontab $cron_file

	rm -f $cron_file
	suc
}
fix_crontab_109()
{
    remove_from_crontab "ttsmailparse.php"
}

remove_cron_somely_80()
{
    remove_from_crontab "$PRODUCT_ROOT_D/admin/sbin/statistics"
    remove_from_crontab "$PRODUCT_ROOT_D/bin/mysqldump.sh"
    remove_from_crontab "$PRODUCT_ROOT_D/admin/plib/report/autoreport.php"
}

fix_crontab_810()
{
    remove_from_crontab "$PRODUCT_ROOT_D/psa/run-parts.sh"
}

insert_fullhostname()
{
#	replace FullHostName
	inten="insert Hostname to the MySQL database"
	echo_try $inten

	query="select val from misc where param='FullHostName'"
	tmp="`echo \"$query\" | mysql`"

	if [ "X$tmp" = "X" ]; then
		query="replace into misc (param,val) values('FullHostName','$fullhost')"
		echo $query | mysql && suc || die $inten
	fi

	suc
}

setup_support_url()
{
	local support_url

	support_url="$1"
	db_do "REPLACE INTO misc (param,val) values('support_url', '$support_url')"
}


update_mysql4_permissions()
{
	local query major_version

	# determine mysql version (for 4.x there is additional set of permissions/privileges)
	query="USE mysql; SHOW VARIABLES LIKE 'version';"
	major_version=`echo "${query}" | mysql | sed -e 's/^version[ \t]\([0-9]*\)\..*$/\1/'`

	if [ "X$major_version" != "X4" ]; then
		# don't need to update permissions
		return
	fi

	inten="update administrators permissions for MySQL 4"
	echo_try $inten

	query="	USE mysql;
			UPDATE user SET Super_priv='Y', Create_tmp_table_priv='Y', Lock_tables_priv='Y', Execute_priv='Y', Repl_slave_priv='Y', Repl_client_priv='Y' WHERE User='admin';
			FLUSH PRIVILEGES;"
	echo $query | mysql || warn "$inten"

	suc
}

# add_db_changes [--fix] version
# Runs ${PRODNAME}_db_upgrade_${version}.sql
# (with --fix, runs ${PRODNAME}_db_upgrade_${version}_fix.sql)
add_db_changes()
{
	if [ "$db_fix_check_stage" = "yes" ]; then
		return
	fi

	local inten upgrade_db_sql fix
	fix=""
	eval `sh_get_args '--fix) fix="_fix";;'`
	inten="upgrade SQL database from $1"
	upgrade_db_sql="$PRODUCT_BOOTSTRAPPER_DIR/db/${PRODNAME}_db_upgrade_${1}${fix}.sql"
	mysql < $upgrade_db_sql >> "$product_log" 2>&1 || die "$inten"
}

# db_fix_add_column [--init def_value] table column type
# Adds a column of the specified type to the table, optionally
# initializing it with def_value, which is an SQL expression. If the
# column already exists, does nothing
db_fix_add_column()
{
	local def_value=""
	eval `sh_get_args '--init) def_value="$2"; shift;;'`
	local table="$1"
	local column="$2"
	local type="$3"

	if [ "$db_fix_check_stage" = "yes" ]; then
		if ! db_test "DESC $table" "\$1 == \"$column\""; then
			if [ -z "$db_added_columns" ]; then
				db_added_columns="$table.$column"
			else
				db_added_columns="$db_added_columns|$table.$column"
			fi
		fi
		return
	fi

	local query="ALTER TABLE \`$table\` ADD \`$column\` $type"
	if [ -n "$def_value" ]; then
		query="$query; UPDATE \`$table\` SET \`$column\`=$def_value"
	fi
	db_do_if_not "DESC $table" "\$1 == \"$column\"" "$query"
}

# db_fix_change_column [--init def_value] table column type
# Changes a column of the specified type to the table, optionally
# initializing it with def_value, which is an SQL expression.
# Changes a column from the table if it exists
db_fix_change_column()
{
	if [ "$db_fix_check_stage" = "yes" ]; then
		return
	fi

	local def_value=""
	eval `sh_get_args '--init) def_value="$2"; shift;;'`
	local table="$1"
	local old_column="$2"
	local new_column="$3"
	local type="$4"

	local query="ALTER TABLE \`$table\` CHANGE \`$old_column\` \`$new_column\` $type"
	if [ -n "$def_value" ]; then
		query="$query; UPDATE \`$table\` SET \`$new_column\`=$def_value"
	fi
	db_do_if "DESC \`$table\`" "\$1 == \"$old_column\"" "$query"
}

# db_fix_del_column table column
# Deletes a column from the table if it exists
db_fix_del_column()
{
	if [ "$db_fix_check_stage" = "yes" ]; then
		return
	fi

	local table="$1"
	local column="$2"

	db_do_if "DESC \`$table\`" "\$1 == \"$column\"" "ALTER TABLE \`$table\` DROP \`$column\`"
}

# db_fix_add_key table column [column ...]
# Adds a non-unique [compound] key on the specified columns of the
# table. If the key already exists, or there is another key that
# substitutes this one, nothing is done. Existing keys that are
# substituted by the new one are dropped
db_fix_add_key()
{
	if [ "$db_fix_check_stage" = "yes" ]; then
		return
	fi

	local table="$1"
	local columns="$2"
	shift 2
	local i
	for i; do
		columns="$columns,\`$i\`"
	done
	local type name icolumns
	local found=no
	db_get_keys "$table" | (
		while read type name icolumns; do
			case "$icolumns" in
				"$columns"|"$columns",*)
					found=yes
					break
					;;
			esac
			case "$columns" in
				"$icolumns",*)
					if [ "$type" = "KEY" ]; then
						db_do "ALTER TABLE \`$table\` DROP KEY \`$name\`"
					fi
					;;
			esac
		done
		if [ "$found" = no ]; then
			db_do "ALTER TABLE \`$table\` ADD KEY ($columns)"
		fi
		exit 0
	)
	local status="$?"
	if [ "$status" -ne 0 ]; then
		exit "$status"
	fi
}

# db_fix_drop_table table_name
db_fix_drop_table()
{
	local table_name
	table_name="$1"

	db_do "DROP TABLE IF EXISTS \`$table_name\`"
}

# db_test test_query awk_script
# Runs test_query and processes it with awk_script. If the output is
# not empty, return 0, otherwise return 1. Hint: supply '1' for
# awk_script to test just for the presence of any output.
db_test()
{
	local any_db=
	eval `sh_get_args '--any-db) any_db=yes;;'`

	local test_query="$1"
	local awk_script="$2"

	if [ -n "$any_db" ]; then
		local output="`mysql_raw_anydb -e \"$test_query\" 2>>\"$product_log\"`"
	else
		local output="`mysql_raw -e \"$test_query\" 2>>\"$product_log\"`"
	fi
	local status=$?
	if [ "$status" -ne 0 ]; then
		p_echo "$output"
		die "run the following SQL query: $1"
	fi

	echo -n "$output" | awk -F '\t' -- "$awk_script" | test `wc -l` -ne 0
}

# db_do [--inten <inten>] query
# Runs query. If it fails, die
# the inten string describes the query reason (to make finding the bug simpler)
db_do()
{
	local desc="execute SQL query"
	eval `sh_get_args '--inten) desc=" (to $2)"; shift;;'`
	if [ "$db_fix_check_stage" = "yes" ]; then
		return
	fi

	local query="$1"

	mysql -e "$query" >>"$product_log" 2>&1 || die "$desc, the query was: $query"
}

# db_select <query>
# runs <query> via mysql_raw
# writes output to db_select_output
# if query fails, output errors and return 1
db_select()
{
	local desc="execute SQL query"
	local query="$1"
	local output="`mysql_raw -e \"$query\" 2>>\"$product_log\"`"
	local status="$?"
	if [ "$status" -ne "0" ]; then
		p_echo "$output"
		die "run the following SQL query: $query"
	fi

	db_select_output="$output"
	return 0
}

# db_do_if test_query awk_script query
# If db_test test_query awk_script returns zero (true), run the query.
# If any query fails, die
db_do_if()
{
	if [ "$db_fix_check_stage" = "yes" ]; then
		return
	fi

	local test_query="$1"
	local awk_script="$2"
	local query="$3"

	if db_test "$test_query" "$awk_script"; then
		db_do "$query"
	fi
}

# db_do_if_not test_query awk_script query
# If db_test test_query awk_script returns nonzero (false), run the
# query. If any query fails, die
db_do_if_not()
{
	if [ "$db_fix_check_stage" = "yes" ]; then
		return
	fi

	local test_query="$1"
	local awk_script="$2"
	local query="$3"

	if ! db_test "$test_query" "$awk_script"; then
		db_do "$query"
	fi
}

# db_get_keys table
# Outputs the list of keys for a table, one on a row, in the following format:
# name type columns
# Where type is one of PRIMARY, UNIQUE, and KEY, name is always
# PRIMARY for primary keys, and columns is a comma-separated list of
# columns without embedded spaces. All backtick characters are removed
db_get_keys()
{
	local table="$1"
	local query="SHOW CREATE TABLE \`$table\`"
	local output="`mysql_raw -e "$query"`"
	local status=$?
	if [ "$status" -ne 0 ]; then
		p_echo "$output"
		die "run the following SQL query: $1"
	fi

	echo "$output" | awk '
		$1 == "PRIMARY"	{ print "PRIMARY", "PRIMARY", $3 }
		$1 == "UNIQUE"	{ print "UNIQUE", $3, $4 }
		$1 == "KEY"		{ print "KEY", $2, $3 }' | 		sed -e 's/[`()]//g' -e 's/,[[:space:]]*$//g'
}

# db_test_database database
# Returns 0 if the database exists
db_test_database()
{
	local database="$1"

	local mysql_db_name="mysql"
	db_test "SHOW DATABASES" "\$1 == \"$database\""
}

# db_test_table table
# Returns 0 if the table exists
db_test_table()
{
	local table="$1"

	db_test "SHOW TABLES LIKE '$table'" 1
}

# db_test_column table column
# Returns 0 if table.column exists
db_test_column()
{
	local table="$1"
	local column="$2"

	db_test "DESC \`$table\`" "\$1 == \"$column\""
}

# db_test_column_enum_value <table> <column> <value awaited in enum>
# Returns O if table.column contains value in enum description
db_test_column_enum_value()
{
	local table="$1"
	local column="$2"
	local value="$3"

	db_test "DESC \`$table\` \`$column\`" "/[\'\"]$value[\'\"]/ { print 1 }"
}

db_create_default_templates()
{
	sw_engine_pleskrun $PRODUCT_ROOT_D/admin/plib/scripts/create_default_templates.php 2>>"$product_log"
	[ "$?" -eq 0 ] || 		warn "default tempaltes cannot be created"
}

db_update_notifications()
{
	sw_engine_pleskrun $PRODUCT_ROOT_D/admin/plib/scripts/update_notifications.php 2>>"$product_log"
	[ "$?" -eq 0 ] || 		warn "cannot update notifications. Please rerun $PRODUCT_ROOT_D/admin/plib/scripts/update_notifications.php manually"
}

db_update_plesk10()
{
	sw_engine_pleskrun $PRODUCT_ROOT_D/admin/plib/scripts/db-update-plesk10.php 2>>"$product_log"
	[ "$?" -eq 0 ] || 		warn "cannot update db. Please rerun $PRODUCT_ROOT_D/admin/plib/scripts/db-update-plesk10.php manually"
}

smb_install_db()
{
	$PRODUCT_ROOT_D/admin/smb/application/utils/dbupgrade >>"$product_log" 2>&1
	[ "$?" -eq 0 ] || 		die "SMB database not created"

}


db_upgrade_ip_addresses_1010()
{
    db_fix_add_column IP_Addresses main "ENUM('true', 'false') NOT NULL DEFAULT 'false'"
    db_fix_add_column IP_Addresses status "BIGINT UNSIGNED NOT NULL DEFAULT 0"
}

fix_ip_addresses_1010()
{
    echo_try "Set missing main property to IP addresses"
    sw_engine_pleskrun $PRODUCT_ROOT_D/admin/plib/scripts/upgrade_ip_addresses_1010.php && suc || warn "fail\nCannot update IP addresses information. Please run $PRODUCT_ROOT_D/admin/plib/scripts/upgrade_ip_addresses_1010.php manually."
}

db_upgrade_dns_recs_t_1010()
{
    db_do_if_not         "SELECT id FROM dns_recs_t WHERE type='AAAA' AND host='ns.<domain>.'" 1         "REPLACE INTO dns_recs_t(displayHost, host, type, displayVal, val, time_stamp) VALUES('ns.<domain>.', 'ns.<domain>.', 'AAAA', '<ipv6>', '<ipv6>', NOW());"

    db_do_if_not         "SELECT id FROM dns_recs_t WHERE type='AAAA' AND host='<domain>.'" 1         "REPLACE INTO dns_recs_t(displayHost, host, type, displayVal, val, time_stamp) VALUES('<domain>.', '<domain>.', 'AAAA', '<ipv6>', '<ipv6>', NOW()+1);"

    db_do_if_not         "SELECT id FROM dns_recs_t WHERE type='AAAA' AND host='webmail.<domain>.'" 1         "REPLACE INTO dns_recs_t(displayHost, host, type, displayVal, val, time_stamp) VALUES('webmail.<domain>.', 'webmail.<domain>.', 'AAAA', '<ipv6>', '<ipv6>', NOW()+2);"

    db_do_if_not         "SELECT id FROM dns_recs_t WHERE type='AAAA' AND host='mail.<domain>.'" 1         "REPLACE INTO dns_recs_t(displayHost, host, type, displayVal, val, time_stamp) VALUES('mail.<domain>.', 'mail.<domain>.', 'AAAA', '<ipv6>', '<ipv6>', NOW()+3);"

    db_do_if_not         "SELECT id FROM dns_recs_t WHERE type='A' AND host='ipv4.<domain>.'" 1         "REPLACE INTO dns_recs_t(displayHost, host, type, displayVal, val, time_stamp) VALUES('ipv4.<domain>.', 'ipv4.<domain>.', 'A', '<ip>', '<ip>', NOW()+4);"

    db_do_if_not         "SELECT id FROM dns_recs_t WHERE type='AAAA' AND host='ipv6.<domain>.'" 1         "REPLACE INTO dns_recs_t(displayHost, host, type, displayVal, val, time_stamp) VALUES('ipv6.<domain>.', 'ipv6.<domain>.', 'AAAA', '<ipv6>', '<ipv6>', NOW()+5);"
}

db_upgrade_domain_services_1010()
{
     db_fix_add_column DomainServices ipCollectionId "INT UNSIGNED"
}

db_upgrade_web_domain_services_1010()
{
    echo_try "Create web domain services"
    sw_engine_pleskrun $PRODUCT_ROOT_D/admin/plib/scripts/upgrade_web_domain_services_1010.php && suc || warn "fail\nCannot update web domain services information. Please run $PRODUCT_ROOT_D/admin/plib/scripts/upgrade_web_domain_services_1010.php manually."
#TODO: drop of ip_address_id column from psa.hosting and psa.forwarding tables
}

db_upgrade_hosting_1010()
{
     db_fix_add_column hosting certificate_id "INT UNSIGNED DEFAULT 0"
}

db_upgrade_subdomains_1010()
{
     db_fix_add_column subdomains certificate_id "INT UNSIGNED DEFAULT 0"
}

db_upgrade_check_local_sso_is_used()
{
	# if sso is not installed locally - it is remote
	[ -f /etc/sso/sso_config.ini ] || return 1

	# if sso_server hostname matches full hostname of this machine - it is local
	db_select "SELECT val FROM misc WHERE param like 'sso_server'"
	local sso_hostname=`echo "$db_select_output" | sed -ne 's|.*://\([^:/]*\).*|\1|p'`
	[ -n "$sso_hostname" ] || return 1
	[ -n "$fullhost" ] || {
		warn "Failed to determine whether SSO is local (full hostname not defined), assuming remote."
		return 1
	}
	if [ "$sso_hostname" = "$fullhost" ]; then
		return 0
	fi

	# check whether sso_server hostname resolves to one of our ip addresses
	local ipv4_sso_addrs=""
	local ipv6_sso_addrs=""
	local host_query=""
	host_query=`host -t A "$sso_hostname" 2>/dev/null`
	if [ "$?" -eq 0 ]; then
		ipv4_sso_addrs=`echo "$host_query" | awk '{ print $NF }'`
	fi
	host_query=`host -t AAAA "$sso_hostname" 2>/dev/null`
	if [ "$?" -eq 0 ]; then
		ipv6_sso_addrs=`echo "$host_query" | awk '{ print $NF }'`
	fi

	local sso_addrs_list=`echo $ipv4_sso_addrs $ipv6_sso_addrs $sso_hostname | 						  sed -e 's|\([^ ]*\)|"\1",|g' | 						  sed -e 's|^[ ,]*\(.*\)|\1|' | sed -e 's|\(.*\)[ ,]$|\1|'`
	if [ -z "$sso_addrs_list" ]; then
		sso_addrs_list="null"
	fi
	db_select "SELECT ip_address FROM IP_Addresses WHERE ip_address in ($sso_addrs_list)"
	if [ -n "$db_select_output" ]; then
		return 0
	fi

	# if it does not - sso is most probably remote
	return 1
}

db_upgrade_sso_port_1010()
{
	db_upgrade_check_local_sso_is_used || return
	db_do "UPDATE misc SET val=REPLACE(val, ':11443', ':8443') WHERE param like 'sso%'";
	db_do "UPDATE misc SET val=REPLACE(val, ':11444', ':8443') WHERE param like 'sso%'";
}

db_optimize_configurations_table_1010()
{
    db_do "ALTER TABLE Configurations CHANGE objectId objectId INT UNSIGNED";
    db_do_if_not "SHOW INDEX FROM Configurations" "\$3 == \"objectTypeAndId_index\"" "CREATE INDEX objectTypeAndId_index ON Configurations (objectType, objectId)"
}

db_cleanup_exp_event_1010()
{
	db_test_table "exp_event" || return
	db_do "DELETE FROM exp_event WHERE obj_class=''"
}

db_upgrade_backups_scheduled_1011()
{
    db_fix_add_column BackupsScheduled content_type "ENUM('backup_content_all_at_domain', 'backup_content_vhost_only', 'backup_content_mail_only') DEFAULT 'backup_content_all_at_domain'"
}

db_upgrade_exp_event_obj_class_1011()
{
    db_fix_change_column "exp_event" "obj_class" "obj_class" "VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL"
}

db_upgrade_ssobranding_port_1011()
{
	db_upgrade_check_local_sso_is_used || return
	db_do "UPDATE SSOBranding SET idp_url=REPLACE(idp_url, ':11444', ':8443')"
}

db_upgrade_filesharing_1011()
{
	echo_try "Update filesharing data"
	sw_engine_pleskrun $PRODUCT_ROOT_D/admin/plib/scripts/upgrade_filesharing_1011.php && suc || warn "fail\nCannot update filesharing information. Please run $PRODUCT_ROOT_D/admin/plib/scripts/upgrade_filesharing_1011.php manually."
}

db_upgrade_resp_attach_1012()
{
    db_fix_change_column "resp_attach" "filename" "filename" "VARCHAR(245) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL"
}

db_upgrade_permissions_1012()
{
	echo_try "Setting default values of new permissions in subscriptions and service plans"
	sw_engine_pleskrun $PRODUCT_ROOT_D/admin/plib/scripts/upgrade_permissions_1012.php && suc || warn "fail\nCannot set default values of new permissions in subscriptions and service plans. Please run $PRODUCT_ROOT_D/admin/plib/scripts/upgrade_permissions_1012.php manually."
}

db_upgrade_add_simple_plan_1012()
{
	echo_try "create simple service plan"
	sw_engine_pleskrun $PRODUCT_ROOT_D/admin/plib/scripts/create_default_simple_template.php && suc || warn "fail\nCannot create simple service plan. Please run $PRODUCT_ROOT_D/admin/plib/scripts/create_default_simple_template.php manually."
}

db_upgrade_dns_reverse_ptr_ipv6_1012()
{
	db_do_if_not "SHOW INDEX FROM dns_recs" "\$3 == \"host\"" "CREATE INDEX host ON dns_recs (host)"

	db_do_if_not 		"SELECT id FROM dns_recs_t WHERE type='PTR' AND host='<ipv6>'" 1 		"REPLACE INTO dns_recs_t(displayHost, host, type, displayVal, val, opt, time_stamp) VALUES('<ipv6>', '<ipv6>', 'PTR', '<domain>.', '<domain>.', 64, NOW())"
}

db_upgrade_php_settings_1012()
{
	echo_try "Update existing PHP settings information in service plans and hostings"
	sw_engine_pleskrun $PRODUCT_ROOT_D/admin/plib/scripts/upgrade_php_settings_1012.php && suc || warn "fail\nCannot convert PHP settings. Please run $PRODUCT_ROOT_D/admin/plib/scripts/upgrade_php_settings_1012.php manually."
}

db_upgrade_mail_domain_services_1012()
{
	echo_try "Upgrade mail domain services"
	sw_engine_pleskrun $PRODUCT_ROOT_D/admin/plib/scripts/upgrade_mail_domain_services_1012.php && suc || warn "fail\nCannot upgrade mail domain services. Please run $PRODUCT_ROOT_D/admin/plib/scripts/upgrade_mail_domain_services_1012.php manually."
}

db_upgrade_dns_wwwprefix_1012()
{
	echo_try "update www records for domain aliases"
	sw_engine_pleskrun $PRODUCT_ROOT_D/admin/plib/scripts/upgrade_dns_1012.php && suc || warn "fail\nnCannot upgrade dns for domain aliases. Please run $PRODUCT_ROOT_D/admin/plib/scripts/upgrade_dns_1012.php manually."
}

db_upgrade_upgrade_history_1012()
{
	db_fix_change_column "upgrade_history" "db_version" "db_version" "VARCHAR(50) CHARACTER SET ascii COLLATE ascii_bin NOT NULL"
}
db_add_ftp_sys_users()
{
    db_fix_add_column sys_users mapped_to "INT UNSIGNED"
    db_do_if_not "SHOW INDEX FROM sys_users" "\$3 == \"mapped_to\"" "ALTER TABLE sys_users ADD INDEX (mapped_to)"
}

db_add_plans_schema()
{
    db_fix_add_column "clients" "vendor_id" "INT UNSIGNED"
    db_do "UPDATE clients SET vendor_id = parent_id WHERE ISNULL(vendor_id) AND !ISNULL(parent_id)"

    db_fix_add_column "domains" "vendor_id" "INT UNSIGNED"
    db_do "UPDATE domains SET vendor_id = cl_id WHERE ISNULL(vendor_id)"

    db_fix_del_column "Templates" "note_id"

    db_fix_add_column "Templates" "owner_id" "INT UNSIGNED"
    db_fix_add_column "Templates" "type" "ENUM('reseller', 'client', 'domain', 'domain_addon')"
    db_fix_add_column "Templates" "uuid" "VARCHAR(36)"
}

db_add_plans_data()
{
    script="$PRODUCT_ROOT_D/admin/plib/scripts/upgrade_plans.php"
    if [ -f "$script" ]; then
        sw_engine_pleskrun "$script" >> "$product_log" 2>&1
    fi

    db_do_if_not "SHOW INDEX FROM clients" "\$3 == \"vendor_id\"" "ALTER TABLE clients ADD INDEX (vendor_id)"

    db_fix_change_column "domains" "vendor_id" "vendor_id" "INT UNSIGNED NOT NULL"
    db_do_if_not "SHOW INDEX FROM domains" "\$3 == \"vendor_id\"" "ALTER TABLE domains ADD INDEX (vendor_id)"

    db_fix_change_column "Templates" "uuid" "uuid" "VARCHAR(36) NOT NULL"
    db_fix_change_column "Templates" "owner_id" "owner_id" "INT UNSIGNED NOT NULL"
    db_fix_change_column "Templates" "type" "type" "ENUM('reseller', 'client', 'domain', 'domain_addon') NOT NULL"
    db_do_if_not "SHOW INDEX FROM Templates" "\$3 == \"owner_id\"" "ALTER TABLE Templates ADD INDEX (owner_id)"
    db_do_if_not "SHOW INDEX FROM Templates" "\$3 == \"uuid\"" "ALTER TABLE Templates ADD UNIQUE(uuid)"

    script="$PRODUCT_ROOT_D/admin/plib/scripts/upgrade_plans_shared.php"
    if [ -f "$script" ]; then
		sw_engine_pleskrun "$script" >> "$product_log" 2>&1
    fi
}

db_add_webspaces()
{
# Add and populate www_root for domains
	if ! db_test_column "hosting"  "www_root"; then
		db_fix_add_column "hosting" "www_root" "TEXT CHARACTER SET ascii COLLATE ascii_bin NOT NULL"
		db_do 'UPDATE hosting, domains SET hosting.www_root=CONCAT("'$HTTPD_VHOSTS_D'/", domains.name, "/httpdocs") WHERE hosting.dom_id=domains.id'
	fi

# Add and populate www_root for subdomains
	db_fix_add_column "subdomains" "www_root" "TEXT CHARACTER SET ascii COLLATE ascii_bin NOT NULL"
	db_do 'UPDATE subdomains, domains SET subdomains.www_root=CONCAT("'$HTTPD_VHOSTS_D'/", domains.name, "/subdomains/", subdomains.name, "/httpdocs") WHERE subdomains.dom_id=domains.id'

# webspace_id for domains + index. 0 by default
	db_fix_add_column "domains"	"webspace_id" "INT UNSIGNED NOT NULL DEFAULT 0"
	db_do_if_not "SHOW INDEX FROM domains" "\$3 == \"webspace_id\"" "ALTER TABLE domains ADD INDEX (webspace_id)"

# webspace_status, if status !=0 it will be 2
	if ! db_test_column "domains" "webspace_status"; then
		db_fix_add_column "domains" "webspace_status" "BIGINT UNSIGNED NOT NULL DEFAULT 0"
		db_do "UPDATE domains SET webspace_status=status, status=2 WHERE status <> 0"
	fi

# Migrate 'native' users of subdomains to additional-ftp-accounts and drop 'sys_user_type' from subdomains
	if db_test_column "subdomains" "sys_user_type"; then
		sw_engine_pleskrun $PRODUCT_BOOTSTRAPPER_DIR/db/convert_sysusers_107.php "subdomains" && 		db_fix_del_column "subdomains" "sys_user_type" || warn "Cannot convert 'native' subdomain users to additional ftp accounts"
	fi

# Remove uniq(sys_user_id) from hosting
	db_do_if "SHOW INDEX FROM hosting" "\$3 == \"sys_user_id\"" "ALTER TABLE hosting DROP INDEX sys_user_id"

# Map all webuser's sysusers to main domain's ftp system users
# and chown vhost's dir data are owned by webusers
	sw_engine_pleskrun $PRODUCT_BOOTSTRAPPER_DIR/db/convert_sysusers_107.php "webusers" || warn "Cannot map webusers to domain ftp users"

	db_fix_add_column "disk_usage" "www_root" "BIGINT UNSIGNED DEFAULT 0"
}

db_add_domain_permissions()
{
    db_fix_add_column "domains" "permissions_id" "INT UNSIGNED NOT NULL DEFAULT 0"
}

db_migrate_sb_data_107()
{
	if ! db_test_table "SBSites" || ! db_test_table "SBConfig"; then
		return
	fi

	echo_try "save legacy sitebuilder url data"
	sw_engine_pleskrun $PRODUCT_ROOT_D/admin/plib/scripts/save_sb_links.php && suc || warn "migration of legacy sitebuilder url data"
}

db_default_skin_107()
{
	echo_try "register default skin"
	db_do "DELETE from Skins"
	db_do "REPLACE INTO Skins (id, name, place) values (1, 'Default', 'default')"

# Update client, domains, mailnames
	db_do "UPDATE cl_param SET val=1 WHERE param='skin_id'"
	db_do "UPDATE dom_param SET val=1 WHERE param='skin_id'"
	db_do "UPDATE mn_param SET val=1 WHERE param='skin_id'"

# Update misc
	db_do "UPDATE misc SET val=1 WHERE param='admin_skin_id'"
	db_do "UPDATE misc SET val=1 WHERE param='def_skin_id'"

	suc
}

db_unlimited_client_expiration_107()
{
	echo_try "change client/reseller expiration to unlimited"
	db_do "UPDATE Limits SET value=-1 WHERE limit_name='expiration' AND id IN (SELECT limits_id FROM clients WHERE limits_id IS NOT NULL)"
	suc
}

db_clean_up_ip_pool_107()
{
	echo_try "clean up unused ip adresses from client ip pools"
	sw_engine_pleskrun $PRODUCT_ROOT_D/admin/plib/scripts/ip_clean_107.php && suc || warn "fail\nCannot clean up clients ip pools"
}

db_billing_integration_107()
{
	db_fix_drop_table "BillingCache"
	db_fix_add_column "clients" "external_id" "VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT ''"
	db_fix_add_column "domains" "external_id" "VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT ''"
	db_fix_add_column "Templates" "external_id" "VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT ''"
}

db_upgrade_hp_mail_107()
{
	db_fix_add_column "mail" "userId" "INT UNSIGNED NOT NULL DEFAULT 0"
}

db_update_sessions_107()
{
	echo_try "Update sessions"
	db_do "DELETE from sessions"

	db_fix_add_column "sessions" "modified" "INT UNSIGNED"
	db_fix_add_column "sessions" "lifetime" "INT UNSIGNED"
	db_fix_add_column "sessions" "data" "TEXT CHARACTER SET binary"

	suc
}

db_migrate_sa_prefs_107()
{
	echo_try "Update SA preferences"

	if ! db_test_column "spamfilter" "reject_spam"; then
		pnnl_echo "already done"
		return
	fi

	if ! sw_engine_pleskrun $PRODUCT_BOOTSTRAPPER_DIR/db/migrate_sa_prefs_107.php; then
		die "Cannot migrate spamasassin preferences"
	fi

	db_fix_del_column "spamfilter" "reject_spam"
	suc
}
db_change_domain_admins_length_108()
{
	db_fix_change_column "clients" "login" "login" "VARCHAR(255)"
}

db_subscription_limits_default_values_108()
{
        local subscription_id;
        local limit_name="$1";
        local limit_default_value="$2";
        db_select "select d.id from domains d LEFT join Limits l on l.id = d.limits_id AND l.limit_name = '$limit_name' WHERE 0 = d.webspace_id AND l.value IS NULL";
        for subscription_id in $db_select_output; do
            db_do "INSERT INTO Limits (id, limit_name, value) SELECT d.limits_id, '$limit_name', $limit_default_value FROM domains d WHERE d.id=$subscription_id"
            db_select "SELECT d.limits_id FROM domains d WHERE d.id=$subscription_id";
            if [ "X${db_select_output}" = "X0" ]; then
                db_do "UPDATE domains SET limits_id=last_insert_id() WHERE id=$subscription_id";
            fi
        done
}

db_upgrade_clients_idn_109()
{
    db_fix_change_column "clients" "login" "login" "VARCHAR(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL"
}

db_upgrade_subscriptions_109()
{
    db_fix_add_column Subscriptions custom "ENUM('true', 'false') NOT NULL DEFAULT 'false'"
    db_fix_add_column Subscriptions uuid "VARCHAR(36) CHARACTER SET ascii COLLATE ascii_general_ci"
    
    echo_try "Assign missing UUIDs to subscriptions"

# Note, script is named *_108.php, because we change version of core 
# from 10.8.1 to 10.9.0. Renaming script is wrong idea, because it is
# executed on windows side
    sw_engine_pleskrun $PRODUCT_ROOT_D/admin/plib/scripts/upgrade_subscriptions_108.php && suc || warn "fail\nCannot update subscriptions information. Please run $PRODUCT_ROOT_D/admin/plib/scripts/upgrade_subscriptions_108.php manually."
}

db_upgrade_custom_buttons_109()
{
    db_fix_add_column custom_buttons plan_item_name "VARCHAR(255) CHARACTER SET ascii COLLATE ascii_general_ci"
}

db_upgrade_maintenance_mode_109()
{
    db_fix_add_column hosting maintenance_mode "ENUM('false','true') NOT NULL DEFAULT 'false'"
    db_fix_add_column subdomains maintenance_mode "ENUM('false','true') NOT NULL DEFAULT 'false'"
}

db_fix_bf1492_column_types_80()
{
	if db_test "SHOW TABLES" '$1 == "module_bf1942_servers"' 		&& db_test "DESCRIBE module_bf1942_servers" '$1 == "srv_bandwidth"'
	then
		db_do "ALTER TABLE module_bf1942_servers
				MODIFY srv_bandwidth
					ENUM('0', '8', '16', '32', '64', '128', '256', '512')
					NOT NULL
					DEFAULT '0'"
	fi
}

db_fix_set_dns_recursion()
{

 db_do_if_not  "SELECT * FROM misc WHERE param = 'dns_recursion'" 1  "INSERT INTO misc(param, val) VALUES('dns_recursion', 'any')"
}

db_cleanup_zombie_domain_templates_80()
{
	db_select "SELECT tmpl_id FROM clients WHERE tmpl_id IS NOT NULL"

	for tmpl_id in $db_select_output; do
		db_select "SELECT rep.component_id
					FROM Repository rep LEFT JOIN Templates t
									ON t.id = rep.component_id
					WHERE rep.rep_id = $tmpl_id AND t.id IS NULL"
		for component_id in $db_select_output; do
			db_do "DELETE FROM Repository
					WHERE rep_id = $tmpl_id AND component_id = $component_id"
		done
	done
}

db_enable_spamfilter_on_mailnames_80()
{
	local mail_id

	db_select "SELECT m.id FROM mail m, domains d, sa_conf c WHERE m.dom_id = d.id AND CONCAT(m.mail_name, '@', d.name) = c.mailname AND c.flt_enabled IN ('user', 'both')"
	for mail_id in $db_select_output; do
		db_do "UPDATE mail SET spamfilter = 'true' WHERE id = $mail_id"
	done
}

db_drop_obsolete_spamfilter_tables_80()
{
	db_fix_drop_table sa_conf
	db_fix_drop_table sa_list
}

db_set_drweb_management_permissions_80()
{
	local perm_id
	local query

	if ! db_test "SELECT * FROM Permissions WHERE permission='manage_virusfilter'" 1; then
            query="SELECT perm_id FROM mail WHERE perm_id IS NOT NULL"
	    db_select "$query"
    	        for perm_id in $db_select_output; do
    		    db_do_if_not "SELECT * from Permissions WHERE id = $perm_id AND permission = 'manage_drweb'" 1             	            "INSERT Permissions (id, permission, value) VALUES ($perm_id, 'manage_drweb', 'true')"
		done


		for query in 			"SELECT m.perm_id FROM mail m, dom_level_usrs d, Permissions p WHERE m.dom_id = d.dom_id AND d.perm_id = p.id AND p.permission = 'manage_drweb' AND p.value = 'false'" 			"SELECT m.perm_id FROM mail m, domains d, clients c, Permissions p WHERE m.dom_id = d.id AND d.cl_id = c.id AND c.perm_id = p.id AND p.permission = 'manage_drweb' AND p.value = 'false'"
		do
			db_select "$query"
			for perm_id in $db_select_output; do
				db_do "UPDATE Permissions SET value = 'false' WHERE permission = 'manage_drweb' AND id = $perm_id"
			done
		done
	fi	
}

db_max_dom_alias_init_80()
{
	
        local limits_id
        local query

        query="SELECT limits_id FROM clients WHERE limits_id IS NOT NULL"
        db_select "$query"
        for limits_id in $db_select_output; do
            db_do_if_not "SELECT * from Limits WHERE id = $limits_id AND limit_name = 'max_doman_alises'" 1                         "INSERT INTO Limits(id, limit_name, value) VALUES ($limits_id, 'max_doman_alises', -1 )"
        done

        query="SELECT limits_id FROM domains WHERE limits_id IS NOT NULL"
        db_select "$query"
        for limits_id in $db_select_output; do
            db_do_if_not "SELECT * from Limits WHERE id = $limits_id AND limit_name = 'max_doman_alises'" 1                         "INSERT INTO Limits(id, limit_name, value) VALUES ($limits_id, 'max_doman_alises', -1 )"
        done
}

db_replace_make_dumps_permission_80()
{
        local perm_id
	local query
	
	query="SELECT id FROM Permissions where permission = 'make_dumps' AND value = 'true'"
	db_select "$query"
	for perm_id in $db_select_output; do
		db_do "REPLACE INTO Permissions(id, permission, value) VALUES ($perm_id, 'allow_local_backups', 'true')"
		db_do "REPLACE INTO Permissions(id, permission, value) VALUES ($perm_id, 'allow_ftp_backups', 'true')"
	done
	
	query="SELECT id FROM Permissions where permission = 'make_dumps' AND value = 'false'"
	db_select "$query"
	for perm_id in $db_select_output; do
		db_do "REPLACE INTO Permissions(id, permission, value) VALUES ($perm_id, 'allow_local_backups', 'false')"
		db_do "REPLACE INTO Permissions(id, permission, value) VALUES ($perm_id, 'allow_ftp_backups', 'false')"
	done	
	
	db_do "DELETE FROM Permissions WHERE permission = 'make_dumps'"
	
}

db_fastcgi_support_80()
{
	db_fix_add_column hosting fastcgi "ENUM('false','true') NOT NULL DEFAULT 'false'" 
	db_fix_add_column subdomains fastcgi "ENUM('false','true') NOT NULL DEFAULT 'false'"
	db_fix_add_column web_users fastcgi "ENUM('false','true') NOT NULL DEFAULT 'false'"
}

db_migrate_spamfilter_configuration_80()
{
	# Migrate sa_conf and sa_list tables 
	if db_test_table sa_conf && db_test_table sa_list; then
		db_do "INSERT INTO spamfilter (username, preferences, reject_spam) VALUES ('*@*', 'true', 'false')"

		db_do "INSERT INTO spamfilter (username, preferences, reject_spam) 
			SELECT CONCAT(m.mail_name, '@', d.name), 'true', IF(c.spam_action = 'delete', 'true', 'false') 
			FROM mail m INNER JOIN domains d ON m.dom_id = d.id 
			LEFT JOIN sa_conf c ON CONCAT(m.mail_name, '@', d.name) = c.mailname"

		db_do "INSERT INTO spamfilter_preferences (spamfilter_id, preference, value) SELECT sf.id, 'required_score', IFNULL(c.hits_required, '7.00') 
			FROM spamfilter sf LEFT JOIN sa_conf c ON sf.username = '*@*' AND c.mailname = '' OR sf.username = c.mailname"
		db_do "INSERT INTO spamfilter_preferences (spamfilter_id, preference, value) SELECT sf.id, 'rewrite_header', CONCAT('subject ', IFNULL(c.rw_subject_tag, '*****SPAM*****')) 
			FROM spamfilter sf LEFT JOIN sa_conf c ON sf.username = '*@*' AND c.mailname = '' OR sf.username = c.mailname"
		db_do "INSERT INTO spamfilter_preferences (spamfilter_id, preference, value) 
			SELECT sf.id, CONCAT('un', sl.color, 'list_from'), ul.pattern FROM spamfilter sf, sa_list ul, sa_list sl 
			WHERE sf.username = ul.mailname AND ul.pattern = sl.pattern AND ul.color IS NULL AND sl.color IN ('black', 'white') AND sl.mailname = ''"

		db_do "INSERT INTO spamfilter_preferences (spamfilter_id, preference, value) 
			SELECT sf.id, CONCAT(l.color, 'list_from'), l.pattern FROM spamfilter sf, sa_list l 
			WHERE l.color IN ('black', 'white') AND (sf.username = '*@*' AND l.mailname = '' OR sf.username = l.mailname)"

		db_do "REPLACE INTO misc (param, val) SELECT 'spamfilter_enabled', 
			IF(flt_enabled IN ('user', 'serv', 'both'), 'true', 'false') FROM sa_conf WHERE mailname = ''"

		db_do "REPLACE INTO misc (param, val) SELECT 'spamfilter_use_mailuser_prefs', 
			IF(flt_enabled IN ('user', 'both'), 'true', 'false') FROM sa_conf WHERE mailname = ''"

		db_do "REPLACE INTO misc (param, val) VALUES ('spamfilter_max_children', 5)"

		db_do "INSERT Permissions (id, permission, value) SELECT perm_id, 'manage_spamfilter', 'true' FROM clients"
		db_do "INSERT Permissions (id, permission, value) SELECT perm_id, 'manage_spamfilter', 'true' FROM dom_level_usrs"
		db_do "INSERT Permissions (id, permission, value) SELECT perm_id, 'manage_spamfilter', 'true' FROM mail"

		db_do "REPLACE Permissions (id, permission, value) SELECT m.perm_id, 'manage_spamfilter', 'false' FROM mail m, domains d, sa_list l 
			WHERE m.dom_id = d.id AND l.mailname = '' AND l.color = 'gray' AND LOWER(CONCAT(m.mail_name, '@', d.name)) LIKE BINARY(LOWER(REPLACE(REPLACE(l.pattern, '*', '%'), '?', '_')))"
	fi		
}

db_migrate_spamfilter_permissions_80()
{
        local perm_id
        local query

	query="SELECT perm_id FROM clients WHERE perm_id IS NOT NULL"
	db_select "$query"
	for perm_id in $db_select_output; do
            db_do_if_not "SELECT * from Permissions WHERE id = $perm_id AND permission = 'manage_spamfilter'" 1 			"INSERT Permissions (id, permission, value) VALUES ($perm_id, 'manage_spamfilter', 'true')"
        done

        query="SELECT perm_id FROM dom_level_usrs WHERE perm_id IS NOT NULL"
        db_select "$query"
        for perm_id in $db_select_output; do
            db_do_if_not "SELECT * from Permissions WHERE id = $perm_id AND permission = 'manage_spamfilter'" 1                         "INSERT Permissions (id, permission, value) VALUES ($perm_id, 'manage_spamfilter', 'true')"
        done

        query="SELECT perm_id FROM mail WHERE perm_id IS NOT NULL"
        db_select "$query"
        for perm_id in $db_select_output; do
            db_do_if_not "SELECT * from Permissions WHERE id = $perm_id AND permission = 'manage_spamfilter'" 1                         "INSERT Permissions (id, permission, value) VALUES ($perm_id, 'manage_spamfilter', 'true')"
        done

        if db_test_table sa_list; then
		db_do "REPLACE Permissions (id, permission, value) SELECT m.perm_id, 'manage_spamfilter', 'false' FROM mail m, domains d, sa_list l
			WHERE m.dom_id = d.id AND l.mailname = '' AND l.color = 'gray' 
			AND LOWER(CONCAT(m.mail_name, '@', d.name)) LIKE BINARY(LOWER(REPLACE(REPLACE(l.pattern, '*', '%'), '?', '_')))"
	fi

}

upgrade_db_80()
{
	add_db_changes 800
        db_fastcgi_support_80
	db_fix_add_column domainaliases tomcat "ENUM('false', 'true') NOT NULL DEFAULT 'false'"
        db_fix_add_column mail spamfilter "ENUM('false','true') NOT NULL DEFAULT 'false' AFTER autoresponder"
	
	db_migrate_spamfilter_configuration_80
	db_migrate_spamfilter_permissions_80

	db_max_dom_alias_init_80

	db_cleanup_zombie_domain_templates_80
	db_enable_spamfilter_on_mailnames_80
	db_drop_obsolete_spamfilter_tables_80
	db_set_drweb_management_permissions_80
	db_replace_make_dumps_permission_80
}


db_fix_add_miva_support_81()
{
    db_fix_add_column hosting miva                 "ENUM('false','true') NOT NULL DEFAULT 'false' AFTER fastcgi"

    db_fix_add_column subdomains miva                 "ENUM('false','true') NOT NULL DEFAULT 'false'"
}

db_fix_change_antivirus_structure_81()
{
    #Add virusfilter column to mail table
    db_fix_add_column mail virusfilter                  "ENUM('none','incoming', 'outgoing', 'any') NOT NULL DEFAULT 'none' AFTER spamfilter"
		
    #rename DrWeb permission		
    db_do "UPDATE Permissions SET permission='manage_virusfilter'
	    WHERE permission='manage_drweb'"
	    
    #Migrate DrWeb direction param to mail.virusfilter
    db_fix_migrate_drweb_direction_81
    
    #set DrWeb as active virusfilter on server
     db_do_if_not 	 "SELECT * FROM misc WHERE param = 'virusfilter'" 1 	 "INSERT INTO misc(param, val) VALUES('virusfilter', 'drweb')"
    	    
}

db_fix_migrate_drweb_direction_81()
{
    
        local mn_id
        local query

    # from -> outgoing
        query="SELECT mn_id FROM mn_param WHERE param='drweb_direction' AND val='from'"
	db_select "$query"
        for mn_id in $db_select_output; do
            db_do "UPDATE mail SET virusfilter = 'outgoing' WHERE id = $mn_id"
        done
    # to -> incoming
        query="SELECT mn_id FROM mn_param WHERE param='drweb_direction' AND val='to'"
	db_select "$query"
        for mn_id in $db_select_output; do
            db_do "UPDATE mail SET virusfilter = 'incoming' WHERE id = $mn_id"
        done
	
    # any -> any
        query="SELECT mn_id FROM mn_param WHERE param='drweb_direction' AND val='any'"
	db_select "$query"
        for mn_id in $db_select_output; do
            db_do "UPDATE mail SET virusfilter = 'any' WHERE id = $mn_id"
        done		
	
	db_do "DELETE FROM mn_param WHERE param='drweb_direction'"

}

db_fix_set_webstat_management_permissions_81()
{
	local perm_id
	local query

	for query in 		"SELECT c.perm_id FROM clients c LEFT JOIN Permissions p ON c.perm_id = p.id AND p.permission = 'manage_webstat' WHERE p.id IS NULL" 		"SELECT d.perm_id FROM dom_level_usrs d LEFT JOIN Permissions p ON d.perm_id = p.id AND p.permission = 'manage_webstat' WHERE p.id IS NULL"
	do
		db_select "$query"
		for perm_id in $db_select_output; do
			db_do "REPLACE INTO Permissions (id, permission, value) VALUES ($perm_id, 'manage_webstat', 'true')"
		done
	done
}

db_fix_add_dalias_dns_column_81()
{
    #add 'dns' column and set it to true if does not exists
    if ! db_test_column domainaliases dns; then
	db_fix_add_column domainaliases dns             "ENUM('false','true') NOT NULL DEFAULT 'false' AFTER displayName"
	    
	db_do "UPDATE domainaliases SET dns='true'"    
    fi
}

db_fix_remove_make_dumps_permission_81()
{
    db_do "DELETE FROM Permissions WHERE permission = 'make_dumps'"
}

db_fix_update_hosting_services_81()
{
    local column
    for column in             fp fp_ssl fp_enable             ssi php php_safe_mode             cgi perl python fastcgi             miva coldfusion             asp asp_dot_net             ssl at_domains same_ssl
    do
        db_test_column hosting "$column" &&             db_do "UPDATE hosting SET \`$column\` = 'false' WHERE \`$column\` = ''"
    done
}

db_fix_81()
{
    add_db_changes --fix 810
    db_fix_change_antivirus_structure_81
    db_fix_add_miva_support_81
    db_fix_set_webstat_management_permissions_81
    db_fix_add_dalias_dns_column_81
    db_fix_remove_make_dumps_permission_81
	db_fix_update_hosting_services_81
}

db_fix_remove_unique_index_81()
{
# Bug 113259, unique index on CHARACTER SET utf8 COLLATE utf8_general_ci

    db_do_if "SHOW INDEX FROM clients" "\$2 == \"0\" && \$3 == \"pname\"" "ALTER TABLE clients 
	    DROP INDEX \`pname\`; 
	    ALTER TABLE clients ADD INDEX (\`pname\`)"
	    
    db_do_if "SHOW INDEX FROM domains" "\$2 == \"0\" && \$3 == \"displayName\"" "ALTER TABLE domains 
	    DROP INDEX \`displayName\`; 
	    ALTER TABLE domains ADD INDEX (\`displayName\`)"	    
    
    db_do_if "SHOW INDEX FROM subdomains" "\$2 == \"0\" && \$3 == \"dom_id_2\"" "ALTER TABLE subdomains 
	    DROP INDEX \`dom_id_2\`; 
	    ALTER TABLE subdomains ADD INDEX \`dom_id_displayName\` (\`dom_id\`, \`displayName\`)"
	    
    db_do_if "SHOW INDEX FROM mass_mail" "\$2 == \"0\" && \$3 == \"name\"" "ALTER TABLE mass_mail 
	    DROP INDEX \`name\`; 
	    ALTER TABLE mass_mail ADD INDEX (\`name\`)"	    
	    
    db_do_if "SHOW INDEX FROM mail_resp" "\$2 == \"0\" && \$3 == \"mn_id\"" "ALTER TABLE mail_resp 
	    DROP INDEX \`mn_id\`; 
	    ALTER TABLE mail_resp ADD INDEX \`mn_id_resp_name\` (\`mn_id\`, \`resp_name\`)"	    
	    
    db_do_if "SHOW INDEX FROM badmailfrom" "\$2 == \"0\" && \$3 == \"domain\"" "ALTER TABLE badmailfrom 
	    DROP INDEX \`domain\`; 
	    ALTER TABLE badmailfrom ADD INDEX (\`domain\`)"	    
	    
    db_do_if "SHOW INDEX FROM DatabaseServers" "\$2 == \"0\" && \$3 == \"host\"" "ALTER TABLE DatabaseServers 
	    DROP INDEX \`host\`; 
	    ALTER TABLE DatabaseServers ADD INDEX \`host_port\` (\`host\`, \`port\`)"	    
	    
    db_do_if "SHOW INDEX FROM Skins" "\$2 == \"0\" && \$3 == \"name\"" "ALTER TABLE Skins 
	    DROP INDEX \`name\`; 
	    ALTER TABLE Skins ADD INDEX (\`name\`)"	    
	    
   db_do_if "SHOW INDEX FROM spamfilter_preferences" "\$2 == \"0\" && \$3 == \"spamfilter_id\"" "ALTER TABLE spamfilter_preferences 
	    DROP INDEX \`spamfilter_id\`; 
	    ALTER TABLE spamfilter_preferences ADD INDEX \`spamfilter_id\` (\`spamfilter_id\`, \`preference\`, \`value\`)"
	    
    db_do_if "SHOW INDEX FROM DashboardPreset" "\$2 == \"0\" && \$3 == \"name_type\"" "ALTER TABLE DashboardPreset 
	    DROP INDEX \`name_type\`; 
	    ALTER TABLE DashboardPreset ADD INDEX \`name_type\` (\`name\`, \`type\`)"	    
    
}

db_fix_new_siteapps_format_81()
{
    db_fix_add_column SiteAppPackages package_type "INT UNSIGNED NOT NULL DEFAULT 0"
    db_fix_add_column SiteAppPackages params_id "INT UNSIGNED"
    db_fix_add_key SiteAppPackages params_id
    
    db_fix_add_column SiteAppResources res_param_1 "VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin DEFAULT ''"
    db_fix_add_column DatabaseServers server_version "VARCHAR(255) CHARACTER SET BINARY NOT NULL"
    db_do "REPLACE INTO actions (name, descr, enabled) VALUES('siteapp_upgrade', 'Upgrade site application', 'true')"
}

db_fix_sso_81()
{
    db_fix_add_column clients uid "VARCHAR(36) CHARACTER SET ascii COLLATE ascii_bin AFTER sapp_pool_id"
    db_fix_add_column clients ownership "ENUM('true', 'false') NOT NULL DEFAULT 'true' AFTER uid"
    db_fix_add_column dom_level_usrs uid "VARCHAR(36) CHARACTER SET ascii COLLATE ascii_bin AFTER perm_id"
    db_fix_add_column dom_level_usrs ownership "ENUM('true', 'false') NOT NULL DEFAULT 'true' AFTER uid"
}

upgrade_db_81()
{
    db_fix_remove_unique_index_81
    db_fix_new_siteapps_format_81
    db_fix_sso_81
	db_do_if_not 		"SELECT * FROM NewsArticles WHERE class = 'WhatsNew8_2'" 1 		"INSERT INTO NewsArticles(class) VALUES ('WhatsNew8_2')"

}

db_add_guid_actions_82()
{
  db_do_if_not   "SELECT * FROM actions WHERE name= 'client_guid_update'" 1   "INSERT INTO actions(name, descr, enabled) VALUES('client_guid_update','Change Client GUID','true')"

   db_do_if_not    "SELECT * FROM actions WHERE name= 'domain_guid_update'" 1    "INSERT INTO actions(name, descr, enabled) VALUES('domain_guid_update','Change Domain GUID','true')"
}

db_generate_guids_82()
{
  make_guids_script="$PRODUCT_ROOT_D/admin/plib/make_guids.php"
  if [ -f "$make_guids_script" ]; then
    sw_engine_pleskrun "$make_guids_script" >> "$product_log" 2>&1
  fi
}

db_add_guid_columns_82()
{
  db_fix_add_column clients guid     "VARCHAR(36) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '00000000-0000-0000-0000-000000000000'"

  db_fix_add_column domains guid     "VARCHAR(36) CHARACTER SET ascii COLLATE ascii_bin NOT NULL DEFAULT '00000000-0000-0000-0000-000000000000'"
}

db_fix_82()
{
	add_db_changes --fix 820
}

db_add_mod_bw_columns_82()
{
    db_fix_add_column hosting traffic_bandwidth "INT DEFAULT -1"
    db_fix_add_column hosting max_connection "INT DEFAULT -1"
}

db_aps_upgrade_82()
{
    aps_upgrade_script="$PRODUCT_BOOTSTRAPPER_DIR/db/aps-psa830-db-upgrade"
    if [ -f "$aps_upgrade_script" ]; then
	$PRODUCT_ROOT_D/admin/bin/php "$aps_upgrade_script" >> "$product_log" 2>&1
    fi    

}

upgrade_db_82()
{
	#GUIDs
	db_add_guid_actions_82
	db_add_guid_columns_82
#	This cannot work on 9.x. Will be called later
#	db_generate_guids_82
	
	db_add_mod_bw_columns_82
	db_fix_del_column hosting at_domains
	db_fix_change_column dns_recs type type "ENUM('NS','A','CNAME','MX','PTR','TXT', 'SRV', 'master', 'none') NOT NULL DEFAULT 'A'"
	db_fix_change_column dns_recs_t type type "ENUM('NS','A','CNAME','MX','PTR','TXT', 'SRV') NOT NULL DEFAULT 'A'"

	db_aps_upgrade_82
	
	add_db_changes 821
}

db_del_obsoleted_sso_1_0_columns_83()
{
	db_do "DELETE FROM misc WHERE param IN ('admin_sso_uid', 'admin_ownership')"
	db_fix_del_column clients uid
	db_fix_del_column clients ownership
	db_fix_del_column dom_level_usrs uid
	db_fix_del_column dom_level_usrs ownership
}

db_fix_83()
{
	db_del_obsoleted_sso_1_0_columns_83
    add_db_changes 830
}

db_fix_countries_84()
{
	db_do "UPDATE Cards SET country = 'RS' WHERE country='CS'"
	db_do "UPDATE clients SET country = 'RS' WHERE country='CS'"
	db_do "UPDATE misc SET val='RS' WHERE param='admin_country' AND val='CS'"
}


db_fix_soa_serial_84()
{
	db_do_if_not 		"SELECT * from misc WHERE param = 'soa_serial_format'" 1 		"INSERT INTO misc (param, val) VALUES ('soa_serial_format', 'UNIXTIMESTAMP')"

	db_fix_add_column dns_zone serial_format "enum('UNIXTIMESTAMP','YYYYMMDDNN') NOT NULL default 'UNIXTIMESTAMP'"

	db_fix_add_column dns_zone serial "VARCHAR(12) CHARACTER SET ascii COLLATE ascii_bin NOT NULL default '0'"

	# TP 38826 Resurrect serial number by dns_recs.time_stamp
	db_do "UPDATE dns_zone SET serial=UNIX_TIMESTAMP( (SELECT time_stamp FROM dns_recs WHERE dns_zone_id=dns_zone.id LIMIT 1) )"
}

db_fix_84()
{
	db_fix_countries_84
	db_fix_soa_serial_84
	add_db_changes 841
}

upgrade_plesk_in_watchdog_86()
{
	db_do_if "SHOW TABLES LIKE 'module_watchdog_service'" 1 		"UPDATE module_watchdog_service
			 SET start_cmd = '$PRODUCT_RC_D/sw-cp-server start'
			 , stop_cmd = '$PRODUCT_RC_D/sw-cp-server stop'
			 WHERE name = 'plesk_apache' "
}

upgrade_plesk_in_apspool_86()
{

	if db_test_column APSApplicationItems shared && ! db_test_column APSClientApplicationItems broadcast; then
		db_select "SELECT id FROM clients WHERE type = 'admin'"
		local adminId="$db_select_output"

		db_fix_add_column APSClientApplicationItems broadcast "ENUM ('false', 'true') NOT NULL DEFAULT 'false'"

# insert app to admin pool
		db_select "SELECT id from APSApplicationItems"
		local id
		for id in $db_select_output; do
			db_do "INSERT INTO APSClientApplicationItems (client_id, app_item_id, instances_limit, broadcast) VALUES ('$adminId', '$id', '-1' ,'true')"
		done

# update broadcast attribute
		db_select "SELECT id FROM APSApplicationItems WHERE shared = 'false'"
		for id in $db_select_output; do
			db_do "UPDATE APSClientApplicationItems SET broadcast = 'false' WHERE app_item_id = '$id' AND client_id = '$adminId'"
		done

# delete shared column
		db_fix_del_column APSApplicationItems shared
	fi
}

upgrade_plesk_in_domains_86()
{
	db_fix_add_column domains overuse "ENUM ('false', 'true') NOT NULL DEFAULT 'false'"
}

upgrade_plesk_in_clients_86()
{
	db_fix_add_column clients overuse "ENUM ('false', 'true') NOT NULL DEFAULT 'false'"
}

clean_dashboard_86()
{
# Clean clients
	db_do "delete from cl_param where param='preset_id'"
# Clean dom level users
	db_do "delete from dom_param where param='preset_id'"
# Clean DashboardPresetConfig, except custom (mysql 4.0 compatible)
#	db_do "delete from DashboardPresetConfig where preset_id in (select id from DashboardPreset where type <> 'custom')"
	db_select "select id from DashboardPreset where type <> 'custom'"
	for preset_id in $db_select_output; do
		db_do "delete from DashboardPresetConfig where preset_id='$preset_id'"
	done
# Cleean DashboardPreset, except custom
	db_do "delete from DashboardPreset where type <> 'custom'"
}

add_vista_skin()
{
	db_do_if_not "select * from Skins where place='vista'" 1 		"replace into Skins (name, place) values ('Vista', 'vista')"
	db_select "SELECT id FROM Skins WHERE place='vista'"
	local vistaID="$db_select_output"
	[ -n "$vistaID" ] || die "cannot find vista skin id"

	db_select "SELECT id FROM Skins WHERE place IN ('aqua', 'longhorn.aero', 'longhorn.black', 'plesk8.new', 'winxp.new', 'winxp.olivegreen', 'winxp.silver', 'vista')"
	local good_ids=`echo -n $db_select_output | tr '\n' ' ' | tr ' ' ','`

# clients
	db_do "UPDATE cl_param SET val='$vistaID' WHERE param='skin_id' AND val NOT IN ($good_ids)"
# domain level
	db_do "UPDATE dom_param SET val='$vistaID' WHERE param='skin_id' AND val NOT IN ($good_ids)"
# mailusers
	db_do "UPDATE mn_param SET val='$vistaID' WHERE param='skin_id' AND val NOT IN ($good_ids)"
# Update admin/default skins
# admin
	db_do "UPDATE misc SET val='$vistaID' WHERE param='admin_skin_id' AND val NOT IN ($good_ids)"
# default
	db_do "UPDATE misc SET val='$vistaID' WHERE param='def_skin_id' AND val NOT IN ($good_ids)"

# Clean up old skins
	db_do "DELETE from Skins WHERE id NOT IN ($good_ids)"
}

move_admin_into_clients_86()
{
	echo_try "migrate admin params to clients table"
	local ex="$PRODUCT_BOOTSTRAPPER_DIR/db/move_admin_into_clients_86.php"
	sw-engine $ex 1>>"$product_log" 2>&1
	[ "$?" -eq 0 ] || 		warn "cannot migrate admin info. Please rerun '$ex' manually"

}

db_create_default_server_backup()
{
# Creation of default server backup task was removed, because simultaneous
# backups overload hardware node
	:
}

db_create_admin_in_clients_86()
{
	if ! db_test_column clients parent_id; then
		db_fix_add_column clients parent_id "INT UNSIGNED DEFAULT NULL"
		db_fix_add_column clients type "ENUM('client', 'reseller', 'admin') NOT NULL DEFAULT 'client'"
		db_do "REPLACE INTO clients (type, login, cr_date) VALUES ('admin', 'admin', now()); SET @id = LAST_INSERT_ID();UPDATE clients SET parent_id = @id WHERE parent_id IS NULL AND type <> 'admin';"
	fi
}

db_structure_upgrade_86()
{
	db_fix_add_column clients parent_id "INT UNSIGNED DEFAULT NULL"
    db_fix_add_column clients type "ENUM('client', 'reseller', 'admin') NOT NULL DEFAULT 'client'"
    db_fix_add_column IP_Addresses ftps "enum('false','true') NOT NULL DEFAULT 'false'"
    db_fix_add_column mass_mail to_resellers "ENUM('false', 'true') NOT NULL DEFAULT 'false'"
    db_fix_add_column mass_mail to_resellers_mode "ENUM('all', 'select', 'except') NOT NULL DEFAULT 'all'"
    db_fix_add_column Notifications send2reseller "VARCHAR(1) CHARACTER SET ascii COLLATE ascii_bin NOT NULL"

    db_fix_add_column hosting php_handler_type "ENUM('cgi', 'fastcgi', 'module') NOT NULL DEFAULT 'module'"
    db_fix_add_column subdomains php_handler_type "ENUM('cgi', 'fastcgi', 'module') NOT NULL DEFAULT 'module';"
}

db_upgrade_ip_pool_86()
{
if db_test_column IP_Addresses type; then
	db_do "DELETE FROM ip_pool"
	db_do "INSERT INTO ip_pool (id, ip_address_id, type) SELECT c.pool_id, ip.id, ip.type FROM clients c INNER JOIN Repository r ON c.pool_id = r.rep_id INNER JOIN IP_Addresses ip ON r.component_id = ip.id WHERE c.type <> 'admin';"
	db_do "INSERT INTO ip_pool (ip_address_id, type) SELECT id, type FROM IP_Addresses LIMIT 1; SET @pool_id = LAST_INSERT_ID();REPLACE INTO ip_pool (id, ip_address_id, type) SELECT @pool_id, id, type FROM IP_Addresses; UPDATE clients SET pool_id = @pool_id WHERE type='admin';"
	db_fix_del_column "IP_Addresses" "type"
fi
}

db_fix_86()
{
	upgrade_plesk_in_watchdog_86
	db_create_admin_in_clients_86
	db_structure_upgrade_86
    add_db_changes 860
	db_upgrade_ip_pool_86
	move_admin_into_clients_86
	upgrade_plesk_in_apspool_86
	upgrade_plesk_in_domains_86
	upgrade_plesk_in_clients_86
	add_vista_skin
	db_create_default_server_backup
}


db_pmm_dashboard_90()
{
	db_do "UPDATE DashboardPresetConfig SET uri='/plesk/server/migration/' WHERE uri='/plesk/server/pmm/'"
}

db_fix_90()
{
	clean_dashboard_86
    add_db_changes 900
	db_add_gl_filter
	db_install_dashboard_presets
	db_add_spf_to_dns_template
}

db_add_gl_filter()
{
	db_fix_add_column domains gl_filter "ENUM('on', 'off') NOT NULL DEFAULT 'on'"
}
db_add_spf_to_dns_template()
{
	db_do_if_not 		"SELECT id FROM dns_recs_t WHERE val='v=spf1 +a +mx -all'" 1 		"REPLACE INTO dns_recs_t(displayHost, host, type, displayVal, val, time_stamp) VALUES('<domain>.', '<domain>.', 'TXT', 'v=spf1 +a +mx -all', 'v=spf1 +a +mx -all', NOW()+8);"
}
db_update_dashboard_951()
{
	sw_engine_pleskrun $PRODUCT_ROOT_D/admin/plib/scripts/update_dashboard_presets_9_5_1.php 2>>"$product_log"
	[ "$?" -eq 0 ] || 	    warn "Unable to update home page presets, see log for details. Please rerun $PRODUCT_ROOT_D/admin/plib/scripts/update_dashboard_presets_9_5_1.php manually"
}

db_update_exp_event()
{
	db_test_table "exp_event" || return
    
	local query

	query="DELETE FROM exp_event WHERE NOT (event_type='started' OR event_type='stopped'
		OR event_type='created' OR event_type='updated' OR event_type='deleted'
		OR event_type='status_changed' OR event_type='terminated' OR event_type='flushed'
		OR event_type='installed' OR event_type='uninstalled' OR event_type='siteapp_added'
		OR event_type='siteapp_removed' OR event_type='expired' OR event_type='exceeded'
		OR event_type='guid_changed')"

	db_do "$query"

	query="DELETE FROM exp_event WHERE NOT (obj_class='license' OR obj_class='service' 
		OR obj_class='ip_address' OR obj_class='admin_info' OR obj_class='siteapp'
		OR obj_class='session_preferences' OR obj_class='plesk_component' OR obj_class='client'
		OR obj_class='client_limits' OR obj_class='client_status' OR obj_class='client_prefs'
		OR obj_class='client_perms' OR obj_class='client_ip_pool' OR obj_class='client_limit_traffic'
		OR obj_class='client_limit_size' OR obj_class='domain' OR obj_class='domain_limits'
		OR obj_class='domain_user' OR obj_class='domain_alias' OR obj_class='domain_status'
		OR obj_class='phosting' OR obj_class='fhosting' OR obj_class='domain_limit_traffic'
		OR obj_class='domain_limit_size' OR obj_class='db_server' OR obj_class='subdomain'
		OR obj_class='mailname' OR obj_class='webuser' OR obj_class='maillist' 
		OR obj_class='dns_zone' OR obj_class='mailname_antivirus' OR obj_class='mailname_spamfilter'
		OR obj_class='mailname_mailgroup' OR obj_class='mailname_autoresponder' 
		OR obj_class='mailname_attachment' OR obj_class='remote_dns' OR obj_class='dashboard_preset' 
		OR obj_class='dashboard_preset_type' OR obj_class='dashboard_preset_name'
		OR obj_class='domain_perfomance' OR obj_class='template_domain' OR obj_class='template_client'
		OR obj_class='template_admin' OR obj_class='log_rotation' OR obj_class='server_ip'
		OR obj_class='db' OR obj_class='db_user' OR obj_class='reseller' OR obj_class='reseller_limits'
		OR obj_class='reseller_status' OR obj_class='reseller_prefs' OR obj_class='reseller_perms'
		OR obj_class='reseller_ip_pool' OR obj_class='reseller_limit_traffic'
		OR obj_class='reseller_limit_size')"

	db_do "$query"
}

db_upgrade_parent_domain_id_1012()
{
    db_fix_add_column domains parentDomainId "INT UNSIGNED NOT NULL DEFAULT 0"
}

db_upgrade_subdomains_1012()
{
    sw_engine_pleskrun $PRODUCT_ROOT_D/admin/plib/scripts/upgrade_subdomains_1011.php && suc || warn "fail\nupgrade subdomains"
}

db_upgrade_service_nodes_1012()
{
    db_fix_add_column IP_Addresses serviceNodeId "INT UNSIGNED NOT NULL DEFAULT 1"
    db_fix_add_column Configurations serviceNodeId "INT UNSIGNED NOT NULL DEFAULT 1"
    db_fix_add_column sys_users serviceNodeId "INT UNSIGNED NOT NULL DEFAULT 0"
    db_do_if "SHOW INDEX FROM sys_users" "\$2 == \"0\" && \$3 == \"login\"" "
        ALTER TABLE sys_users DROP INDEX \`login\`;
        ALTER TABLE sys_users ADD UNIQUE (\`serviceNodeId\`, \`login\`);
        UPDATE \`sys_users\` set \`serviceNodeId\` = 1 WHERE 0 = \`serviceNodeId\`;
    "
}

db_upgrade_dns_1012()
{
    db_fix_add_column dns_zone syncSoa "enum('true','false','skip') NOT NULL default 'skip'"
    db_fix_add_column dns_zone syncRecords "enum('true','false','skip') NOT NULL default 'skip'"
    db_fix_add_column dns_recs_t uid "VARCHAR(255) CHARACTER SET ascii COLLATE ascii_bin DEFAULT NULL"
    db_do "update dns_zone set syncSoa='true', syncRecords='true' where id not in (select val from misc where param='default_dns_zone_id')"
    sw_engine_pleskrun $PRODUCT_ROOT_D/admin/plib/scripts/upgrade_dns_1011.php && suc || warn "fail\nupgrade dns"
}

#proftpd

set_ftpd_params()
{
	anonftp_user="${product}ftp"
	anonftp_group="${product}ftp"

	PROFTPD_ROOT="$PRODUCT_ROOT_D/ftpd"
	PROFTPD_ETC_D="$PROFTPD_ROOT/etc"
}

set_ftpd_accounts()
{
	p_echo " Checking for the system groups and users necessary for ftp server..."
        group_op "$anonftp_group" "search" false
        user_op "$anonftp_user" "search" "$anonftp_group" "anonftp ${product} user" "$dummy_home" "$dummy_shell" false
}

set_ftpd_perms()
{

	set_ac root 0 555 "$PROFTPD_ROOT/*"
	set_ac root 0 755 "$PROFTPD_ROOT/var"

	set_ac root 0 555 "$PROFTPD_ROOT/bin/*"
	set_ac root 0 444 "$PROFTPD_ROOT/etc/*"
	set_ac root 0 555 "$PROFTPD_ROOT/sbin/*"


	chown -R 0:0 $PROFTPD_ROOT || die "chown -R 0:0 $PROFTPD_ROOT"
	chmod -R 555 $PROFTPD_ROOT/bin || die "chmod -R 555 $PROFTPD_ROOT/bin"
	chmod -R 555 $PROFTPD_ROOT/sbin || die "chmod -R 555 $PROFTPD_ROOT/sbin"
	chmod -R 755 $PROFTPD_ROOT/var || die "chmod -R 555 $PROFTPD_ROOT/var"
	chmod 755 $PROFTPD_ETC_D || die "chmod 755 $PROFTPD_ETC_D"
	chmod 644 $PROFTPD_ETC_D/proftpd.conf || die "chmod 644 $PROFTPD_ETC_D/proftpd.conf"
	echo "" >> $PROFTPD_ETC_D/proftpd.include || die "unable to create $PROFTPD_ETC_D/proftpd.include"
	chmod 644 $PROFTPD_ETC_D/proftpd.include || die "chmod 644 $PROFTPD_ETC_D/proftpd.include"

}

proftpd_super_server_config()
{
	local action="$1"

	case "$superserver" in
	    inetd)
		    ftp_rec="ftp stream tcp nowait root $PROFTPD_ROOT/sbin/proftpd proftpd -c $PROFTPD_ETC_D/proftpd.conf"
		    ;;
	    xinetd)
		    ftp_rec="service ftp
{
	socket_type		= stream
	protocol		= tcp
	wait			= no
	disable			= no
	user			= root
	instances		= UNLIMITED
	server			= $PROFTPD_ROOT/sbin/proftpd
	server_args		= -c $PROFTPD_ETC_D/proftpd.conf
}"
		    ;;
	    *)
		    die "Super server name unknown"
		    ;;
	esac

	super_server_action "$action" ftp "$ftp_rec"
}

setup_ftpd()
{
	add_login_shell "$false_shell"

	p_echo " Checking for ftp home directory for 'clients' group..."

	if [ -f /etc/ftpchroot ]; then
		egrep "^@${clients_group}" /etc/ftpchroot >> $product_log 2>&1
		res=$?
	fi
	
	case "$res" in
		0)	p_echo " '@${clients_group}' is already in the /etc/ftpchroot"
			;;
		*)	inten="add '@${clients_group}' to /etc/ftpchroot"
			echo_try $inten
			echo "@${clients_group}" >> /etc/ftpchroot && suc || die $inten
			;;
	esac
	p_echo
}

install_ftpd()
{
	if [ "X$DEMO_VERSION" = "Xyes" ]; then
		return 0;
	fi

	p_echo
	p_echo
	p_echo "===> Installing ftp server (proftpd)..."
	cd "$PRODUCT_ROOT_D" || die "cd $PRODUCT_ROOT_D"

	set_ftpd_params
	setup_ftpd
	set_ftpd_perms

	case "$machine" in
		linux)
			if [ -d "/etc/pam.d" ]; then
				if [ ! -f "/etc/pam.d/ftp" ]; then
					cp -fp $PRODUCT_ROOT_D/tmp/ftp.pamd /etc/pam.d/ftp
					chown root:0 /etc/pam.d/ftp
					chmod 644 /etc/pam.d/ftp
				fi
			fi
			;;
	    *)
			;;
	esac

	if [ ! -f /etc/ftpusers ]; then
		touch /etc/ftpusers || die "Error creating /etc/ftpusers file"
		IFS_OLD="$IFS"
		IFS=":"
		while { read username nu nu gid nu; }; do
			if [ $gid -le 100 -a "$username" != "ftp" ]; then
				echo $username
			fi
		done < /etc/passwd > /etc/ftpusers
		IFS="$IFS_OLD"
	fi

	rm -f $PRODUCT_ROOT_D/tmp/ftp.pamd
}

upgrade_proftpd_107()
{
	echo_try "upgrade anon_ftp quota to new format"
	local domain;
	for domain in $HTTPD_VHOSTS_D/*; do
		[ -e $domain/anon_ftp/incoming/quotadir ] || continue
		rm -f $domain/anon_ftp/incoming/quotadir/.undeletable 			$domain/anon_ftp/incoming/quotadir/.quota >> $product_log 2>&1
		rmdir $domain/anon_ftp/incoming/quotadir >> $product_log 2>&1
	done
	sw_engine_pleskrun $PRODUCT_ROOT_D/admin/plib/scripts/upgrade_proftpd_107.php && suc || warn "fail\nupgrade anon_ftp quota to new format"
}
upgrade_proftpd_754()
{
	case "$machine" in
		BSD*)
			inten="reconfigure ftp superserver record"
			echo_try $inten
			set_ftpd_params
			proftpd_super_server_config remove 
			proftpd_super_server_config register 
			suc
			;;
		*)
			;;
	esac
}
upgrade_proftpd_820()
{
	if [ "X$linux_distr" = "Xdebian" -o "X$linux_distr" = "Xubuntu" ]; then
		if [ -f "${FTPD_CONF}" ]; then
			awk '{ if ($1 == "ScoreboardFile") {print "ScoreboardFile /var/run/proftpd_scoreboard"} else {print} }' 				${FTPD_CONF} > ${FTPD_CONF}.tmp 				&& mv -f ${FTPD_CONF}.tmp ${FTPD_CONF} 		        && chmod 644 ${FTPD_CONF}
		fi
	fi
}
set_horde_params()
{
	horde_datadir="/usr/share/psa-horde"
	horde_confdir="/etc/psa-webmail/horde"
	horde_sysconfd="$horde_confdir/horde"
	horde_logdir="/var/log/psa-horde"
	horde_passwd_file="/etc/psa-webmail/horde/.horde.shadow"
	horde_title="Horde Web Based mail client "

	imp_datadir="$horde_datadir/imp"
	imp_sysconfd="$horde_sysconfd/imp"
	
	mimp_datadir="$horde_datadir/mimp"
	mimp_sysconfd="$horde_sysconfd/mimp"

	turba_datadir="$horde_datadir/turba"
	turba_sysconfd="$horde_sysconfd/turba"

	kronolith_datadir="$horde_datadir/kronolith"
	kronolith_sysconfd="$horde_sysconfd/kronolith"

	ingo_datadir="$horde_datadir/ingo"
	ingo_sysconfd="$horde_sysconfd/ingo"

	mnemo_datadir="$horde_datadir/mnemo"
	mnemo_sysconfd="$horde_sysconfd/mnemo"
	
	passwd_datadir="$horde_datadir/passwd"
	passwd_sysconfd="$horde_sysconfd/passwd"
}

tomcat_reconfigure_server()
{
	echo_try "reconfigure Tomcat services"
	local ports=

	# needed for proper work tomcatmng
	conf_setval "${prod_conf_t}" CATALINA_HOME "${CATALINA_HOME}"

	for name in warp coyote; do
		db_select "SELECT val FROM misc WHERE val = '${name}_connector_port'" 			|| die "get tomcat parameter from the database"
		if [ -n "$db_select_output" ]; then
			ports="--${name}-connector-port $db_select_output"
		fi
	done
	"$UTILS_DIR/tomcatmng" --install-psa --replace-if-exists $ports 		|| die "configure PSA service"

	db_select "SELECT d.name
				FROM domains d, DomainServices ds
				WHERE d.id = ds.dom_id
					AND type='tomcat'
					AND ds.status = 0" 		|| die "get active tomcat domains"
	local domains="$db_select_output"
	for domain_name in $domains; do
		local var manager_login manager_passwd
		for var in manager_login manager_passwd; do
			db_select "SELECT p.value
						FROM Parameters p, DomainServices ds, domains d
						WHERE name = '$domain_name'
							AND d.id = ds.dom_id
							AND ds.parameters_id = p.id
							AND p.parameter = '$var'" 						|| die "get $var for $domain_name"
			eval "$var=\"\$db_select_output\""
		done

		local aliases=
		if
			db_test "SELECT 1
						FROM dns_recs dr, domains d
						WHERE dr.host = 'www.${domain_name}.'
							AND dr.dns_zone_id = d.dns_zone_id
							AND d.name = '$domain_name'" '1'
		then
			aliases="--alias www.$domain_name"
		fi

		"$UTILS_DIR/tomcatmng" --install-vhost --vhost-name $domain_name $aliases
		env PSA_PASSWORD="$manager_passwd" 			"$UTILS_DIR/tomcatmng" --install-service --vhost-name $domain_name --manager-login "$manager_login"

		aliases=
		db_select "select da.name
					from domains d, domainaliases da
					where d.id = da.dom_id
						and tomcat='true'
						and d.name='$domain_name'"
		aliases="$db_select_output"
		for alias_name in $aliases; do
			"$UTILS_DIR/tomcatmng" --add-alias --vhost-name=$domain_name --alias=$alias_name
		done

	done

	suc
}
upgrade_cf_83()
{
	db_select "select val from misc where param='cf_instance_path'"
	[ -n "$db_select_output" -a -d "$db_select_output" ] || return 0

	[ ! -f "$HTTPD_INCLUDE_D/jrun.conf" ] || return 0
	$UTILS_DIR/cfmng --write-jrun-conf
	true
}
# vim:syntax=sh

set_swkey_params()
{
	SWKEY_REPOSITORY="/etc/sw/keys"
	KEYUPGRADE_PATH="/usr/lib/plesk-9.0/key-upgrade"
	KEYUPGRADE8_PATH="/usr/lib/plesk-9.0/key-upgrade8"
}

key_upgrade8_cmd()
{
	# update key from 8.x to 9+
	p_echo "Update license key to OF format"
	nohup /bin/sh -c "$KEYUPGRADE8_PATH 10.4.4" > /dev/null 2>&1 &
}

key_upgrade_cmd()
{
	# set to run key upgrade script
	p_echo "Starting Plesk Key upgrade task"
	nohup /bin/sh -c "$KEYUPGRADE_PATH 10.4.4 2>&1 | logger -p daemon.err -t plesk-key-upgrader" 		>/dev/null 2>&1 &
}

key_upgrade_86_install_additional_key()
{
	key_path="$1"
	echo_try "install key $key_path"

	sw_engine_pleskrun -r 	 'try { of_install_key(file_get_contents("'"$key_path"'")); }
	  catch (Exception $e) { error_log($e->getMessage()); exit(1); }' >>"$product_log" 2>&1 	|| report_problem "install key $key_path" 	&& suc
}

key_upgrade_86_install_additional_keys()
{
	p_echo "installing additional keys"
	for key in `/bin/ls -rt /etc/psa/key.d`; do
		key_upgrade_86_install_additional_key "/etc/psa/key.d/$key"
	done
}

key_upgrade_86()
{

# FIXME: probably this should be moved to key-upgrade8
	p_echo "preparing to upgrade Plesk keys"
	set_swkey_params

	#install fake main key
	db_select "SELECT plesk_key_id FROM key_history WHERE filename = '/etc/psa/psa.key' ORDER BY id DESC LIMIT 1"
	key_number="$db_select_output"
	db_select "SELECT options FROM key_history WHERE filename = '/etc/psa/psa.key' ORDER BY id DESC LIMIT 1"
	key_cookie="$db_select_output"


	# install stub only if there is nondefault key
	if [ -n "$key_number" ] && [ "$key_number" != "plsk000000000000" ]; then
		cat >"$SWKEY_REPOSITORY/registry.xml" <<EOF
<value><struct>
<member><name>history</name>
<value><array><data>
</data></array></value></member>
<member><name>active</name>
 <value><struct>
 <member><name>$key_number</name>
  <value><struct>
   <member><name>key_product_name</name>
    <value><string>plesk-unix</string></value>
   </member>
   <member><name>key_update_cookie</name>
    <value><string>$key_cookie</string></value>
   </member>
   <member><name>update_time</name>
    <value><string>instant</string></value>
   </member>
  </struct></value>
 </member>
 </struct></value>
</member>
</struct></value>
EOF

	key_upgrade8_cmd
	fi

	key_upgrade_86_install_additional_keys

	p_echo "Plesk Key upgrade is prepared"
}
# Usage:  pleskrc <service> <action>
pleskrc()
{
	[ 2 -le $# ] || die "Not enough arguments"

	local service_name=$1
	local action=$2
	local ret=0
	local inten
	local service_script
	shift
	shift

	# Now check redefined functions
	if test "$machine" = "linux" && is_function "${service_name}_${action}_${machine}_${linux_distr}"; then
		"${service_name}_${action}_${machine}_${linux_distr}" $@
		return $?
	elif is_function "${service_name}_${action}_${machine}"; then
		"${service_name}_${action}_${machine}" $@
		return $?
	elif is_function "${service_name}_${action}"; then
		"${service_name}_${action}" $@
		return $?
	fi

	# Not redefined - call default action
	eval "service=\$${service_name}_service"
	[ -n "$service" ] || die "Empty service name for $service_name"

	inten="$action service $service"
	[ "$action" = "status" -o "$action" = "exists" ] || echo_try "$inten"

	if [ -x  "$SYSTEM_RC_D/$service" ]; then
		service_script="$SYSTEM_RC_D/$service"
	elif [ ! -z "${PRODUCT_RC_D}" -a -x "$PRODUCT_RC_D/$service" ]; then
		service_script="$PRODUCT_RC_D/$service"
	fi

	if [ "$action" = "exists" ]; then 
		[ -n "$service_script" ] && return 0 || return 1
	else
		[ -z "$service_script" ] && die "Unable to handle $service"
	fi


	if [ -x "/usr/sbin/invoke-rc.d" ]; then
		action_cmd="/usr/sbin/invoke-rc.d $service"
	elif [ -x "/sbin/service" ]; then
		action_cmd="/sbin/service $service"
	elif [ -n ${service_script} ]; then
		action_cmd="$service_script"
	fi


	case "$action" in
		start)
			pleskrc $service_name status || $action_cmd $action $@ >>$product_log 2>&1
			;;
		stop)
			if pleskrc $service_name status; then
				$action_cmd $action $@
			else
				true
			fi
		    ;;
		restart)
			if pleskrc $service_name status; then 
				$action_cmd "restart" $@
			else 
				$action_cmd "start" $@
			fi
		    ;;
		reload)
		    if pleskrc $service_name status; then
				$action_cmd "reload" $@
			else
				true
			fi
		    ;;
		status)
		    $action_cmd "status"
		    ;;
	    *)
		    $action_cmd $action $@ 
		    ;;
	esac >> $product_log 2>&1

	ret="$?"
	if [ "$action" != "status" ]; then
		[ "$ret" -eq 0 ] && suc || warn $inten
	fi

	return $ret
}

is_function()
{
	local type_output="`type -t \"$1\" 2>/dev/null`"
	case "$type_output" in
		*function)
			return 0
		;;
		*)
			return 1
		;;
	esac
}
form_undotted_version()
{
# Backward compatible with versions < 11.0.0
	echo $1 | awk -F. '{ if ($1 < 11) { print  $1  $2 } else { print $1*100+$2 } }'
}

get_prev_version()
{
	# Debian package system reports previous version as script argument
	if [ "X${prev_version}" = "X" ]; then

		if [ -f "$1/core.version" ]; then
		# Check version from core
			prev_version=`cat $1/core.version | awk '{ print $1 }'`
            prev_build=`cat $1/core.version | awk '{ print $4 }'`
		elif [ -f $1/version ]; then
		# version file must exists in product directory
		    prev_version=`cat $1/version | awk '{ print $1 }'`
		    prev_build=`cat $1/version | awk '{ print $4 }'`
		else
		    p_echo "    Unable to find version file $1. "
		    p_echo "    Please, restore version file or remove old ${PRODUCT_NAME}, if unnecessary."
		    exit 1
		fi

		# check, that it is not empty
		if [ "X${prev_version}" = "X" -o "X${prev_build}" = "X" ]; then
			p_echo "    Unable to determine version or build number of ${PRODUCT_NAME} installed. It is impossible"
			p_echo "    to upgrade ${PRODUCT_NAME} to version $product_version."
			p_echo "    To install new version without data saving remove '$1' directory"
			p_echo "    manually. Please backup all data before removing if it need."
			exit 1
		fi
	fi

	# chat, that it is known version of product
	prev_short_version=`form_undotted_version ${prev_version}`

	for i in ${known_product_versions}; do
	    if [ "X${prev_short_version}" = "X${i}" ]; then
			return 0
	    fi
	done

	# version is unknown for upgrader. let the user to know the propblem
	p_echo "    Unable to upgrade. You have  $prev_version version installed,"
	p_echo "    but upgrader is incompatible with this version."
	p_echo "    To install new ${PRODUCT_NAME} copy, please move '$1'"
	p_echo "    to another place manually."
	exit 1
}

check_product_root()
{
	# check product root
	p_echo
	pnnl_echo "===> Checking for previous installation ... "

	do_upgrade=0

	if [ ! -s "$PRODUCT_ROOT_D/version" ]; then
		p_echo "not found."
	else
		p_echo "found."
		get_prev_version ${PRODUCT_ROOT_D}
		do_upgrade=1
	fi
}

check_localtime_file()
{
	[ -f /etc/localtime ] && return 0
	report_problem 		"There is no /etc/localtime file in system." 		"Run tzsetup as root to set up your timezone"
	return 1
}

check_tmp_permissions()
{
	local tmp_perm_mask=777
	[ $((0`stat -c %a /tmp` & 0$tmp_perm_mask)) -eq $((0$tmp_perm_mask)) ] && return 0

	if [ -f /tmp/pp-bootstrapper-ez-templates-prep-install.flag ]; then
		chmod 1777 /tmp
		p_echo " /tmp file access permissions were adjusted to 1777."
		p_echo
		return 0
	else
		report_problem 			"/tmp should have at least $tmp_perm_mask file access permissions." 			"Run 'chmod 1777 /tmp' as root to set up proper file access permissions."
		return 1
	fi
}

preinstall_checks()
{
	check_localtime_file || exit 1
	check_tmp_permissions || exit 1
}

print_congratulations()
{

printf "\a\a\a"
p_echo
p_echo
p_echo
p_echo

local passwd upgrade

if [ "X$admin_passwd" = "Xsetup" ]; then
	passwd="setup"
else
	passwd="<YOUR ADMIN PASSWORD>"
fi

local print_address=`echo $ipaddress| awk '{print $1}'`

if [ "X$do_upgrade" = "X1" -o "X$rpm_upgrade" = "X1" ]; then

	pp_echo
	if [ "X${minor_problem}" != "X1" ]; then
		pp_echo "                             Congratulations!"
	else
		pp_echo
	fi
	pp_echo "        All stages of the upgrade were successful."
	pp_echo "        ${PRODUCT_NAME} is now running on your system."
	pp_echo "        To complete the system configuration process, please proceed to URL:"
	pp_echo "        https://${fullhost}:8443/ or"
	pp_echo "        https://${print_address}:8443/"
	pp_echo "        Use 'admin' and '$passwd' as login name and password."
	pp_echo
	pp_echo "        Further, use the following commands to start and stop the system:"
	pp_echo "        $START_SH start and"
	pp_echo "        $START_SH stop respectively."
	pp_echo

	if [ "X${minor_problem}" = "X1" ]; then
		pp_echo " *****************************************************************************"
		pp_echo " *                                                                           *"
		pp_echo " *   WARNING:    Some problems occured during upgrade. You need to           *"
		pp_echo " *            check log file                                                 *"
		pp_echo " *            ${product_log}       *"
		pp_echo " *            to fix these problems.                                         *"
		pp_echo " *                                                                           *"
		pp_echo " *****************************************************************************"
		pp_echo
	fi

	if test -n "$upgrade_default_key_installed"; then

		pp_echo "*****************************************************************************"
		pp_echo
		pp_echo " WARNING:    Automatic license upgrade was not performed during"
		pp_echo "             the upgrade process. The product is currently running"
		pp_echo "             on the default license with limited functionality"
		pp_echo "             until such time that an appropriate license is installed."
		pp_echo
		pp_echo "*****************************************************************************"

	fi
else

	pp_echo "                             Congratulations!"
	pp_echo "        Plesk has been successfully installed on your server."
	pp_echo "        To complete the system configuration, please proceed to URL:"
	pp_echo "        https://${fullhost}:8443/ or"
	pp_echo "        https://${print_address}:8443/"
	pp_echo "        Use the login name 'admin' and password '$passwd'."
	pp_echo "        Or use the login name 'root' and your superuser password."
	pp_echo
	pp_echo "        Further, use the following commands to start and stop Plesk:"
	pp_echo "        \"$START_SH start\" and"
	pp_echo "        \"$START_SH stop\" respectively."
	pp_echo
	pp_echo "        All Plesk control panel documentation is available at"
	pp_echo "        http://www.parallels.com/en/products/plesk/docs"
	pp_echo
	pp_echo "                    Thank you for choosing our products!"
fi
}


# echo message to product log and console (always visible)
pp_echo()
{
    if [ -n "$product_log" ] ; then
        echo "$@" >> "$product_log" 2>&1
    fi
    echo "$@"
}

# echo message to product log, unless debug
p_echo()
{
    if [ -n "$PLESK_INSTALLER_DEBUG" -o -n "$PLESK_INSTALLER_VERBOSE" -o -z "$product_log" ] ; then
        echo "$@"
    else
        echo "$@" >> "$product_log" 2>&1
    fi
}

# echo message to product log without new line, unless debug
pnnl_echo()
{
    if [ -n "$PLESK_INSTALLER_DEBUG" -o -n "$PLESK_INSTALLER_VERBOSE" -o -z "$product_log" ] ; then
        echo -n "$*"
    else
        echo -n "$*" >> "$product_log" 2>&1
    fi
}

die()
{
	PACKAGE_SCRIPT_FAILED="$*"

	if [ "X$trigger_uninstall" != "X1" ]; then
		printf "\a\a"
		report_problem 			"ERROR while trying to $*" 			"Check the error reason(see log file: ${product_log}), fix and try again"
	fi

	smart_undo_install

	selinux_close

	exit 1
}

simply_die()
{
	report_problem "$@"
	exit 1
}

# This function needs for some print warning when some services cannot restart
# if called with arg, then we add arg to variable SR_WARNING and print warning
# message for arg, else print warning message for SR_WARNING
service_restart_warning()
{
	if [ "X$1" != "X" ]; then
		if [ "X${SR_WARNING}" = "X" ]; then
			SR_WARNING=$1
		else
			for i in ${SR_WARNING}; do
				if [ "$i" = "$1" ]; then
					break
				fi
			done
			if [ "$1" != "$i" ]; then
				SR_WARNING=$SR_WARNING" "$1
			fi
		fi
		p_echo "WARNING!"
		p_echo "Some problems occured when $1 restart, check it after installation/upgrade complete"
	        p_echo
	 	p_echo "Continue..."
		p_echo
	else
		if [ "X${SR_WARNING}" != "X" ]; then
			p_echo "WARNING!"
		        p_echo "Some problems occured when following services restart:"
			for i in ${SR_WARNING}; do
				p_echo $i
			done
			p_echo "Don't forget to check it after installation/upgrade complete"
        		p_echo
	       	        p_echo "More information can be found in log file: ${product_log}"
			p_echo
		fi
	fi
}

warn()
{
local inten
inten="$1"
p_echo
p_echo "WARNING!"
pnnl_echo "Some problems are found during $inten"
p_echo "(see log file: ${product_log})"
p_echo
p_echo "Continue..."
p_echo

product_log_tail | send_error_report "Warning: $inten"

[ -n "$PLESK_INSTALLER_DEBUG" -o -n "$PLESK_INSTALLER_VERBOSE" ] || 	product_log_tail
}

# Use this function to report failed actions.
# Typical report should contain
# - reason or problem description (example: file copying failed)
# - how to resolve or investigate problem (example: check file permissions, free disk space)
# - how to re-run action (example: perform specific command, restart bootstrapper script, run installation again)
report_problem()
{
	p_echo
	if [ $problems_occured -eq 0 ]; then
		echo "***** $process problem report *****" >> "$product_problems_log" 2>&1
	fi
	for problem_message in "$@"; do
		p_echo "$problem_message"
		echo "$problem_message" >> "$product_problems_log" 2>&1
	done
	p_echo

	product_log_tail | send_error_report "Problem: $@"

	[ -n "$PLESK_INSTALLER_DEBUG" -o -n "$PLESK_INSTALLER_VERBOSE" ] || 		product_log_tail

	problems_occured=1
}

comm_err()
{
  p_echo "       Unfortunately, this situation has not yet been"
  p_echo "       resolved."
  p_echo "       Please, visit $support_contact for assistance."
  p_echo
  p_echo "Exiting..."
  p_echo

  smart_undo_install
  exit 1
}

gid_err()
{
  gid="$1"

  p_echo
  p_echo "ERROR: It seems there is a group with GID=$gid"
  p_echo "       in this system, but $PRODUCT_NAME needs the same GID"
  p_echo "       for its operation."

  send_error_report "Error: group with GID=$gid already exists."
  comm_err
}

group_err()
{
  group="$1"
  gid="$2"

  p_echo
  p_echo "ERROR: It seems that there is group $group"
  p_echo "       in your system. $PRODUCT_NAME uses the same group"
  p_echo "       name but with another group ID ($gid)."

  send_error_report "Error: group $group exists, but it doesn't have GID=$gid."
  comm_err
}

uid_err()
{
  uid="$1"

  p_echo
  p_echo "ERROR: It seems there is a user with UID=$uid"
  p_echo "       in this system, but $PRODUCT_NAME needs the same UID"
  p_echo "       for its operation."

  send_error_report "Error: user with UID=$uid already exists."
  comm_err
}

logname_err()
{
  user="$1"
  uid="$2"

  p_echo
  p_echo "ERROR: It seems that there is a $user in your system"
  p_echo "       with a UID other than that used by $PRODUCT_NAME ($uid)"
  p_echo "       or the $user is in the primary group, but this"
  p_echo "       group is not the one that $PRODUCT_NAME uses."

  send_error_report "Error: user $user exists, but it doesn't have UID=$uid or it belongs to wrong primary group."
  comm_err
}

echo_try()
{
	msg="$*"
	pnnl_echo " Trying to $msg... "
}

suc()
{
	p_echo "done"
}

send_error_report()
{
	{
		echo $@
		echo ""
		if [ -n "$error_report_context" ]; then
			echo "Context: $error_report_context"
			echo ""
		fi
		test -t 0 || cat -
	} | $PRODUCT_ROOT_D/admin/bin/send-error-report "install" >/dev/null 2>&1
}

set_error_report_context()
{
	error_report_context="$@"
}

update_history()
{
	inten="insert upgrade info into history table"

	get_product_versions

	query="SELECT * FROM upgrade_history 
		WHERE version_info='${product_prev_version}' OR db_version='${product_prev_version}'
		LIMIT 1"
	if ! db_test "$query" '1'; then
		query="INSERT INTO upgrade_history (upgrade_date, version_info, 
		db_version) VALUES (now()-1,
			'${product_this_version}', '${product_prev_version}')"
		db_do --inten "$inten" "$query"
	fi

	query="INSERT INTO upgrade_history (upgrade_date, version_info, db_version) 
		VALUES (now(), '${product_this_version}', 
		'${product_this_version}${product_this_version_tag:+ (${product_this_version_tag})}')"
	db_do --inten "$inten" "$query"
}

get_ip_address_list()
{
	local ipaddress=''

	if test -x /sbin/ip ; then
		ipaddress=`/sbin/ip addr | grep -v 'inet6' | grep -v '127\.[0-9]*\.[0-9]*\.[0-9]*' | sed -n -e 's/^ *inet \([0-9\.]*\).*$/\1/ p'`
	else
		ipaddress=`$ifconfig |grep "$inet_str" | grep -v "inet6" | sed -e "s/$inet_str.\([0-9.]*\).*/\1/g"|awk '{print $1}' - | grep -v '^127\.[0-9]*\.[0-9]*\.[0-9]*$'`
	fi
	
	echo -n $ipaddress
}

get_domain()
{
	host="`${get_hostname}`"
	local try_dot=`echo "$host" | sed -e 's/^[^.]*\..*$/\./'`

	case "$try_dot" in
			.)	domain="`echo "$host" | sed -e 's/^[^.]*\.//'`"
				host="`echo $host | sed -e 's/\..*//'`"
				;;
			*)	domain="`$get_domainname`"
				;;
	 esac
	 domain=`echo "$domain" | sed 's/\.$//'`

	 if [ "X$host" = "X" -o "X${domain}" = "X" -o "$domain" = "(none)" ]; then
		p_echo "Warning!"
		p_echo "Unable to determine the host or domain name of your computer."
		p_echo "Setting it to localhost.localdomain"
		host="localhost"
		domain="localdomain"
	 fi

 	 fullhost="${host}.${domain}"
	 return 0;
}

get_config_parameters()
{
 admin_email=

#list of addresses
 local ipaddress_list="`get_ip_address_list`"

 get_domain

 if [ "X$PLESK_DISABLE_HOSTNAME_CHECKING" = "X" -a "X$PLESK_VZ" != "X1" ]; then
 	check_hostname "$fullhost" || die "check the hostname" 
 else
    ipaddress="`echo "$ipaddress_list" | head -1`"
 fi

 start_after_install=1;

 p_echo
}

# vim:syntax=sh

mk_backup()
{
	target="$1"
	dup="$2"
	opts="$3"

	if [ -L "$target" ]; then
		rm "$target"
	elif [ -$opts "$target" ]; then
		if [ ! -$opts "$target.$product_suffo" ]; then
			case "$dup" in
				mv)
					mv -f $target $target.$product_suffo || die "mv -f $target $target.$product_suff"
					;;
				cp)
					cp -fp $target $target.$product_suffo || die "cp -fp $target $target.$product_suff"
					;;
				*)
					p_echo " mk_backup: wrong option -- must be 'cp' or 'mv'"
					die "mk_backup"
					;;
			esac
		else
			case "$dup" in
				mv)
					mv -f $target $target.$product_suff || die "mv -f $target $target.$product_suff"
					;;
				cp)
					cp -fp $target $target.$product_suff || die "cp -fp $target $target.$product_suff"
					;;
				*)
					p_echo " mk_backup: wrong option -- must be 'cp' or 'mv'"
					die "mk_backup"
					;;
			esac
		fi
	else
		case "$opts" in
			f|d)
				;;
			*)
				p_echo " mk_backup: wrong option -- must be 'f' or 'd'"
				die "mk_backup"
				;;
		esac
	fi
}

vz_tune()
{
	#run this only inside vz environment
	if [ -z "$PLESK_VZ" -o "0$PLESK_VZ" -eq "0" ]; then 
		return
	fi
}

# accumulates chown and chmod
set_ac()
{
	u_owner="$1"
	g_owner="$2"
	perms="$3"
	node="$4"

	chown $u_owner:$g_owner $node || die "chown $u_owner:$g_owner $node"
	chmod $perms $node || die "chmod $perms $node"
}

start_product_now()
{
	define_start_script
	p_echo
	if [ "X$start_after_install" = "X1" ]; then
		inten="start ${PRODUCT_NAME}"
		echo_try $inten
		p_echo
		$START_SH stop
		$START_SH start
#@@if defined(SUSE_12)
	for i in 1 2 4 6 8; do
		res="`systemctl | awk '/sw-cp-server/ {print $4}'`"
		[ "$res" = "running" ] && break
		/etc/init.d/sw-cp-server restart
		if [ -z "PLESK_INSTALLER_DEBUG" ]; then
			echo "sleep $i sec.." >> /tmp/cp.log 2>&1
			systemctl | grep sw-cp-server >> /tmp/cp.log 2>&1
		fi
		sleep $i
	done
#@@endif
	fi
}

start_product_now_final()
{
	unset PLESK_KEYUPDATE_DISABLED
	start_product_now
}

add_manpath()
{
	local manpath manpath_config
	manpath="$1"

	if [ "X$manpath" = "X" ]; then
		warn "add_manpath: supply manpath parameter"
		return 1
	fi


	case "$machine" in

		BSD*)
			manpath_config="/etc/manpath.config"

			if [ ! -f "$manpath_config" ]; then
				touch "$manpath_config"
			fi

			grep_res=`egrep "$manpath" "$manpath_config"`

			if [ "X$grep_res" != "X" ]; then
					return
			fi

			echo "OPTIONAL_MANPATH	$manpath" >> "$manpath_config"
			;;

		*)
			;;
	esac

	return 0
}

set_default_locale()
{
	p_echo 'Setting the default locale'
	default_locale_file="$PRODUCT_ROOT_D/admin/htdocs/locales/default"
	if [ -f $default_locale_file ]; then
		test -r "$default_locale_file" || die "set up default locale: cannot read '$default_locale_file'"
		default_locale="`cat $default_locale_file | sed 's/^\([^:]*\):.*/\1/'`"
		default_locale_name="`cat $default_locale_file | sed 's/^[^:]*:\([^:]*\):.*/\1/'`"
		default_locale_country="`cat $default_locale_file | sed 's/^[^:]*:[^:]*:[^:]*:\([^:]*\);.*/\1/'`"
	else
		default_locale="en-US"
		default_locale_name="ENGLISH"
		default_locale_country="UNITED STATES"
	fi
	p_echo "The default locale is set to $default_locale ($default_locale_name, $default_locale_country)"
}

set_services_info()
{
	if [ "1" = "${PLESK_VZ}" ]; then
		p_echo 'Setting the services information on VZ mode.'
		cp -f ${PRODUCT_ETC_D}/service/vzmode/*.xml ${PRODUCT_ETC_D}/service
	fi
}

detect_vz()         
{                   
    local vzcheck_file
        
    PLESK_VZ=0
    vzcheck_file="/proc/self/status"
                    
    if [ ! -f ${vzcheck_file} ]; then
        return 1; 
    fi              
                    
    grep -q -E '^envID\:[[:space:]]*([[:digit:]]+)$' < ${vzcheck_file} >/dev/null 2>&1
                    
    if [ $? -eq 0 ]; then
        PLESK_VZ=1  
        return 0;
    fi      
    return 1;
}       

call_optional_function()
{
	export LANG=C LC_MESSAGES=C LC_ALL=C
	local type_output="`type \"$1\" 2>/dev/null | head -n 1`"
	case "$type_output" in
		*function)
			"$@"
			;;
		*)
			return 0
			;;
	esac
}

add_string()
{
	local pattern string config
	pattern="$1"
	string="$2"
	config="$3"

	if ! grep -q "^$pattern\$" "$config"; then
		echo "$string" >>"$config"
	fi
}

sh_get_args()
{
	echo 'while true; do case "$1" in '"$1"'*) break;; esac; shift; done'
}

get_phpini_var()
{
	[ -z "$1" ] && return
	cat $php_ini | perl -n -e 'next if(/^;/);  print $5 if(/^(\s*)'$1'(\s*)=(\s*)("*)(.*?)("|\s|;)/);'
}

set_phpini_var()
{
	local variable=$1
	local value=$2

	if [ -z "$variable" ]; then
		warn "set_phpini_var() error: variable name is empty."
		return
	fi

	last_entry_line=`grep -n "^[^a-zA-Z]*$variable" $php_ini | tail -n 1 | awk -F ':' '{print $1}'`;
	if [ -z "$last_entry_line" -o 0$last_entry_line -eq 0 ]; then
		echo "$1 = \"$2\"" >> $php_ini
		result=$?
	else
		tmp_file=`mktemp /tmp/php-iniXXXXXX`
		$cp_preserve $php_ini $tmp_file
		cat $php_ini | awk -v variable="$variable" -v value="$value" '
		{
			line+=1;
			if ($0 ~ /^[ \t]*'$variable'[ \t]*=/) {
				printf("%s = %s\n",variable,value);
				done=1;
			} else {
				print $0;
			}
			if (!done && (line>'$last_entry_line')) {
				printf("%s = %s\n",variable,value);
				done=1;
			}
		}' > $tmp_file && mv -f $tmp_file $php_ini >> $product_log 2>&1
		result=$?
	fi

	if [ 0$result -eq 0 ]; then
		echo "$variable=\"$value\" has been added to $php_ini" >> $product_log 2>&1
	else
		warn "set_phpini_var() error: can't add $variable=\"$value\" to $php_ini";
	fi
}

get_narg()
{
	shift $1 2>/dev/null || return
	echo $1
}

get_random_number()
{
	perl -e '
	 my $res = int(rand($ARGV[0]));
	 if (exists $ARGV[1]) {
	  $res = $res + $ARGV[1];
	 }
	 print $res;
	' "$@"
}

get_random_string()
{
	local str_length="$1"
	local str_symbols="$2"
	if [ -x "$PRODUCT_ROOT_D/admin/sbin/random_str" -a -z "$str_symbols" ]; then
		"$PRODUCT_ROOT_D/admin/sbin/random_str" "$str_length"
	else
		# random_str utility may be unavailable in pre phase
		if [ -z "$str_length" ]; then
			str_length="14"
		fi
		if [ -z "$str_symbols" ]; then
			str_symbols="A-Za-z0-9_"
		fi

		< /dev/urandom tr -dc "$str_symbols" 2>/dev/null | head -c "$str_length" 2>/dev/null
	fi
}

fix_etc_hosts()
{
	if ! grep -q -E '^127\..*[[:space:]]localhost([[:space:]]|$)' /etc/hosts; then
		awk '
			BEGIN{ set = 0; }
			/^127\.0\.0\.1[[:space:]]/{ print $0, " localhost"; set = 1; next; }
			{ print }
			END{ if (set == 0) { print "127.0.0.1 localhost"; } }
		' /etc/hosts >/etc/hosts.tmp 		&& mv /etc/hosts.tmp /etc/hosts 		|| report_problem "insert localhost entry in /etc/hosts"
	fi
}

sequence()
{
	if type seq >/dev/null 2>&1; then
		seq $*
	elif type jot >/dev/null 2>&1; then
		jot $*
	else
		die "Unable to find seq or jot command"
	fi
}

sw_engine_pleskrun()
{
	if [ -x $PRODUCT_ROOT_D/bin/sw-engine-pleskrun ]; then
		$PRODUCT_ROOT_D/bin/sw-engine-pleskrun "$@"
	elif [ -x "/usr/bin/sw-engine" ]; then
		local args
		if [ -e "$PRODUCT_ROOT_D/admin/conf/php.ini" ]; then
			args="-c $PRODUCT_ROOT_D/admin/conf/php.ini"
		else
			args="-d psasem.semfile=\"$PRODUCT_ROOT_D/var/psasem.sem\""
		fi
		/usr/bin/sw-engine $args "$@"
	else
		echo "No Plesk PHP interpreter found"
		return 1
	fi
}

install_default_license_key()
{
	pnnl_echo "install default license key ..."

# key from 8.x?
	if 	db_test_table "key_history" && 		db_test "SELECT COUNT(*) FROM key_history WHERE filename = '/etc/psa/psa.key' LIMIT 1" '$1!="0"'; then
			p_echo "not needed, license from 8.x found"
			return;
	fi

# check OF-key
	if sw_engine_pleskrun -r 'exit(of_get_key_by_product("plesk-unix") === false ? 1 :0);'; then
			p_echo "not needed, license from 9.x found"
			return
	fi

	local dest_dir="/etc/sw/keys/keys"
	local key=plesk-default-key.xml

    [ ! -s "$dest_dir/$key" ] || return

    cp -f "${PRODUCT_ROOT_D}/tmp/$key" "$dest_dir/"
    chown root:swkey-data "$dest_dir/$key"
    chmod 0660 "$dest_dir/$key"
    suc
}
set_super_server_params()
{
    case "${machine}_${linux_distr}" in
	linux_*)
	    superserver_mode=native
		superserver=xinetd
	    set_xinetd_params $superserver_mode
	;;
	BSD*)
	    superserver_mode=native
		superserver=inetd
	    set_inetd_params $superserver_mode
	;;
	*)
	    die "Unable to detect super server type"
	;;
    esac

    super_server_action configure
}

true superserver_reconfig

set_inetd_params()
{	
    superserver_conf="/etc/inetd.conf"

    if [ "$superserver_mode" = compat ]; then
	if [ -x "$PRODUCT_RC_D/xinetd" ]; then 
	    superserver_service="xinetd"
		superserver_binary="/usr/sbin/xinetd"
	elif [ -x "$PRODUCT_RC_D/inetd" ]; then 
	    superserver_service="inetd"
		superserver_binary="/usr/sbin/inetutils-inetd"
	elif [ -x "$PRODUCT_RC_D/openbsd-inetd" ]; then
	    superserver_service="openbsd-inetd"
		superserver_binary="/usr/sbin/inetd"
	else
	    die "Unable to find script for superserver"
	fi
    else
	superserver_service="inetd"
    fi

    superserver_dir="/etc"
}

set_xinetd_params()
{
    superserver_conf="/etc/xinetd.conf"
    superserver_service="xinetd"
    superserver_dir="/etc/xinetd.d"
}

superserver_reconfig()
{
    pleskrc superserver reload
}

configure_xinetd_compat()
{
	local inten="configure xinetd compatibility mode with $superserver"
	if [ "$linux_distr" = "debian" -o "$linux_distr" = "ubuntu" ]; then
		[ "$superserver_service" = "xinetd" ] || return 1
		[ -f "/etc/default/xinetd" ] || return 1
		grep -q 'XINETD_OPTS=.*-inetd_compat' /etc/default/xinetd && return 1
		echo_try $inten

		if ! grep -q '^\s*XINETD_OPTS' /etc/default/xinetd; then
			echo 'XINETD_OPTS="-inetd_compat"' >>/etc/default/xinetd
			suc
			return 0
		fi

		eval `grep '^\s*XINETD_OPTS' /etc/default/xinetd`
		XINETD_OPTS="$XINETD_OPTS -inetd_compat"
		local tmp_file=`mktemp /tmp/xinetdXXXXXX`
		sed -e "s/XINETD_OPTS.*/XINETD_OPTS=\"$XINETD_OPTS\"/g" /etc/default/xinetd > $tmp_file && mv -f $tmp_file /etc/default/xinetd
		suc
		return 0
	fi
	return 1
}


super_server_action()
{
    local in out
    local action="$1"
    local service="$2"
    local template="$3"

    inten="$action $service service record for $superserver_service daemon"

    case "$action" in
	remove) ;;
	register)
		[ -z "$template" ] && die "Template for super server $action was not defined"
		;;
	comment|disable)
		;; 
	configure)
		case "$superserver_mode" in
		    native)
			register_service $superserver_service defaults defaults
			;;
		    compat)
			configure_xinetd_compat && pleskrc superserver restart
			;;
		    *)
			die "Mode for $superserver_service was not defined"
			;;
		esac

		return 0
		;;
	*)
		die "Some arguments was not defined or defined incorrect for action with super server"
		;;
    esac 

    case "$superserver" in
	inetd)
		super_server_modify_inetd "$service" "$action" "$template"
		;;
	xinetd)
		super_server_modify_xinetd "$service" "$action" "$template"
		;;
	*)
		die "Unable to define super server type"
		;;	
    esac

    if [ $? -ne 0 ]; then
	die $inten 
    fi
}

super_server_modify_inetd()
{
	local service="$1"
	local action="$2"
	local template="$3"

	case "$action" in
		comment|disable)
			grep -q "^$service[[:space:]]" $superserver_conf || return 0
			sed -e "s|^$service|#$service|g" < "$superserver_conf" > "$superserver_conf.tmp" 			&& mv -f "$superserver_conf.tmp" "$superserver_conf" 			|| return 1
			;;
		remove)
			if [ -x /usr/sbin/update-inetd ]; then
				/usr/sbin/update-inetd --enable "$service"
				/usr/sbin/update-inetd --remove "$service"
			else
				grep -q "^$service[[:space:]]" $superserver_conf || return 0
				sed -e "s|^$service[[:space:]].*||g" < "$superserver_conf" > "$superserver_conf.tmp" 			    	&& mv -f "$superserver_conf.tmp" "$superserver_conf" 			    	|| return 1
			fi
			;;
		register)
			if [ -x /usr/sbin/update-inetd ]; then
				/usr/sbin/update-inetd --enable "$service"
				/usr/sbin/update-inetd --remove "$service"
				/usr/sbin/update-inetd --add "$template"
			else
				egrep -q "$template" $superserver_conf
				if [ "$?" -ne "0" ]; then 
					super_server_modify_inetd comment $service && 					echo "$template" >> $superserver_conf || return 1
				fi
			fi
			;;
	esac

	return 0
}

super_server_modify_xinetd()
{
	local file
	local service="$1"
	local action="$2"
	local template="$3"

	for file in $superserver_dir/*; do
		grep -q "$service" $file 1>>$product_log 2>&1 || continue

		case "$action" in
		    remove)
			    awk "/^[[:space:]]*(#|[[:space:]])*service[[:space:]]+$service($|[[:space:]]+)/,/.*}.*/ 				{next;} {print}
			    " <$file >$file.tmp 			    && mv -f $file.tmp $file || return 1
			    ;;
		    comment)
			    awk "/^[[:space:]]*service[[:space:]]+$service($|[[:space:]]+)/,/.*}.*/ 			       { print \"#\"\$0; next; }
			       {print}
			    " < $file > $file.tmp 			    && mv -f $file.tmp $file || return 1
			    ;;
		esac
	done

	case "$action" in
	    register)
		    echo "$template" > "$superserver_dir/${service}_psa" || return 1
		    ;;
	    disable)
			[ -f "$superserver_dir/${service}_psa" ] && mv -f "$superserver_dir/${service}_psa" "$superserver_dir/${service}.psa"
		    ;;
	esac

	return 0
}

true superserver_status_linux_debian
superserver_status_linux_debian()
{
    get_pid "/usr/sbin/xinetd" false
    local pid=$common_var
    if test "$pid" -ne 1; then
# running
        return 0
    fi
    return 1
}
lockfile()
{
	local tempfile="$1.$$"
	local lockfile="$1.lock"

	echo $$ > $tempfile 2>/dev/null || {
		p_echo "Unable to create lock file in `dirname $tempfile`"
		return 1
	}

	ln $tempfile $lockfile >/dev/null 2>&1 && {
		rm -f $tempfile
		return 0
	}

	kill -0 `cat $lockfile` >/dev/null 2>&1 && {
		rm -f $tempfile
		return 1
	}

	p_echo "Removing stale lock file $lockfile"
	rm -f $lockfile
	ln $tempfile $lockfile >/dev/null 2>&1 && {
		rm -f $tempfile
		return 0
	}

	rm -f $tempfile
	return 1
}

unlockfile()
{
	rm -f "$1.lock"
}
#-*- vim:syntax=sh

product_log_name_ex()
{
	local aux_descr="$1"
	local action="${CUSTOM_LOG_ACTION_NAME-installation}"

	if [ -n "$aux_descr" ]; then
		aux_descr="_${aux_descr}"
	fi

	if [ -n "$CUSTOM_LOG_NAME" ]; then
		echo "${CUSTOM_LOG_NAME}${action:+_$action}${aux_descr}.log"
	else
		echo "plesk_10.4.4${action:+_$action}${aux_descr}.log"
	fi
}

product_log_name()
{
	product_log_name_ex
}

product_problems_log_name()
{
	product_log_name_ex "problems"
}

problems_log_tail()
{
	[ -f "$product_problems_log" ] || return 0
	tac "$product_problems_log" | awk '/^START/ { exit } { print }' | tac
}

product_log_tail()
{
	[ -f "$product_log" ] || return 0
	tac "$product_log" | awk '/^START/ { exit } { print }' | tac
}

cleanup_problems_log()
{
	awk 'BEGIN 						{ st = "" } 
		 /^START/ 					{ st=$0; next } 
		 /^STOP/ && (st ~ /^START/) { st=""; next } 
		 (st != "") 				{ print st; st="" } 
		 							{ print }
		' "$product_problems_log" > "$product_problems_log.tmp" && 	mv -f "$product_problems_log.tmp" "$product_problems_log" || 	rm -f "$product_problems_log.tmp"
	
	if [ ! -s "$product_problems_log" ]; then 
		rm -f "$product_problems_log"
	fi
}

log_start()
{
	true product_log_name product_problems_log_name

	local title="$1"
	product_log="/tmp/`product_log_name`"
	product_problems_log="/tmp/`product_problems_log_name`"
	problems_occured=0

	echo "START $title" >>"$product_log" 	&& echo "START $title" >>"$product_problems_log" 	&& chmod 600 "$product_log" "$product_problems_log" 	|| {
		echo "Cannot write installation log $product_log, $product_problems_log" >&2
		exit 1
	}
}

log_stop()
{
	local title="$1"
	local subject="$2"
	if [ -z "$subject" ]; then
		subject="[${title}]"
	fi

	# check if problems are non-empty, check for problems_occured
	local status
	local problem_lines="`problems_log_tail | wc -l`"
	if [ "$problem_lines" -eq 0 ]; then
		status="completed successfully"
	else
		if [ $problems_occured -ne 0 ]; then
			status="failed"
		else
			status="completed with warnings"
		fi
	fi

	p_echo
	p_echo "**** $subject $status."
	p_echo

	if [ "$problem_lines" -ne 0 ]; then
		problems_log_tail >>"$product_log" 2>&1
		problems_log_tail
	fi

	echo "STOP $title" >>"$product_log"
	if [ $problems_occured -ne 0 ]; then
		echo "STOP $title: PROBLEMS FOUND" >>"$product_problems_log"
	else
		echo "STOP $title: OK" >>"$product_problems_log"
	fi

	if [ "X${PLESK_INSTALLER_KEEP_PROBLEMS_LOG}" = "X" ]; then
		cleanup_problems_log
	fi
}

report_context_action()
{
	local action
	get_product_versions
	if [ "X$do_upgrade" = "X1" -o "$product_prev_version" != "$product_this_version" ]; then
		action="Doing $product_name upgrade from $product_prev_version to $product_this_version"
	else
		action="Doing $product_name $product_this_version installation"
	fi
	echo "$action"
}

set_maintenance_mode_flag()
{
	touch /var/lock/parallels-panel-maintenance-mode.flag
}

reset_upgrade_failure_flag()
{
	rm -f /var/lock/parallels-panel-maintenance-mode.flag
	rm -f /var/lock/parallels-panel-upgrade-failure.flag
}

reset_maintenance_mode_flag()
{
	rm -f /var/lock/parallels-panel-maintenance-mode.flag
}

get_pid()
{
	local i

	local ex_f="$1"
	local opt="$2"
	local owner="$3"

	local min_num="1"

#	Use pidof by default, bug 121868, except for FreeBSD - 140182
	if type pidof >/dev/null 2>&1 && [ "$os" != "BSD" ]; then
		for pid in `pidof -o $$ -o $PPID -o %PPID -x $ex_f`; do
#	Check for owner
			[ "$opt" = "true" -a "$owner" != "`ps -p $pid -o ruser=`" ] && continue
			min_num=$pid
			break
		done
		common_var=$min_num
		return $min_num
	fi

	case "$opt" in
		false)
			for i in `$ps_long | grep $ex_f | grep -v grep | grep -v httpsdctl | grep -v apachectl | awk '{print $2}' -`; do
				min_num=$i
				break
			done
			;;
		true)
			for i in `$ps_long | grep $ex_f | grep -v grep | grep -v httpsdctl | grep -v apachectl | grep "$owner" | awk '{print $2}' -`; do
				min_num=$i
				break
			done
			;;
		*)
			p_echo "get_pid: wrong parameter"
			die "get_pid $ex_f $opt $owner"
			;;
	esac

	common_var=$min_num
	return $min_num
}

kill_pids()
{
	ex_f="$1"
	owner="$2"

	for i in `$ps_long | grep $ex_f | grep -v grep | grep -v httpsdctl | grep -v apachectl | grep $owner | awk '{print $2}' -`; do
		if [ $i -gt 1 ]; then
			$K_TERM $i >> $product_log 2>&1
		fi
	done
}

check_hostname()
{
    local hostname="$1"

    ipaddress="`perl -e '
       use strict;
       use Socket;
       use Errno;

       my $host = shift || "localhost";
       my $port = 715;

       my $proto = getprotobyname("tcp") || die "Protocol\: $! \n";
       my $addr = inet_aton($host) || die "\tUnable to resolve host name.\n\tPlease specify the host name in the /etc/hosts file\n\tor specify DNS configuration in the /etc/resolv.conf file on your system. \n";

       socket(SOCK, PF_INET, SOCK_STREAM, $proto) || die "Socket\: $! \n";

       my $sin = sockaddr_in($port, $addr);

       if (!bind(SOCK, $sin) && $! != Errno::EADDRINUSE) {
          die "Can not bind a socket to address $host:$port - $!\nPlease, check your network configuration\n";
       }

       printf inet_ntoa($addr);
       close(SOCK);
       ' $hostname `"

       if [ "X$ipaddress" = "X" ]; then
           return 1
       else
           return 0
       fi
}
get_userID()
{
# try to get UID
	common_var=`id -u "$1" 2>/dev/null` 

# if id returns 0 the all is ok
	if [ "$?" -eq "0" -a ! -z "$common_var" ]; then
		return 1;
	fi

	return 0;
}

get_groupID()
{
# try to get GID, id -g doesn't show groups without users
	common_var=`cat /etc/group | awk -F':' '$1 == "'$1'" {print $3}'` 

# We have non-empty value if success
	if [ ! -z "$common_var" ]; then
		return 1;
	fi

	return 0;
}

delete_user()
{
	local rm_user

	rm_user="$1"

	# if it is mailman user, remove its crontab from system
	if [ "X${rm_user}" = "X${mailman_user}" ]; then

		inten="remove crontab of ${rm_user}"
		echo "y" | $crontab -u "${mailman_user}" -r >> $product_log 2>&1 || die "$inten"

	fi

	inten="remove user $rm_user"
	echo_try "$inten"

	userdel  $rm_user>> $product_log 2>&1 && suc || die "$inten"
}

delete_group()
{
	local rm_group

	rm_group="$1"

	inten="remove group $rm_group"
	echo_try "$inten"

	mk_backup "/etc/group" cp f
	if [ -f "/etc/group" ]; then
		sed -e "/$rm_group/d" < /etc/group > /etc/group.tmp || die $inten
		mv -f /etc/group.tmp /etc/group  >> $product_log 2>&1
		if [ "$?" -ne 0 ]; then
			rsr_backup "/etc/group" cp f
			die $inten
		fi
	fi
	suc
}

ch_user_home()
{
	local user new_home

	user="$1"
	new_home="$2"

	inten="change home directory for user $user"
	echo_try "$inten"

	usermod -d "$new_home" "$user" 2>>"$product_log" && suc || die "$inten"
}

group_check()
{
	local group grp_res
	group="$1"

	grp_res=`groupmod "$group" 1>/dev/null 2>&1 ; echo $?`

	echo "$grp_res"
}

add_user_to_group()
{
	local user group grp_res existing newlist

	user="$1"
	group="$2"

	# check exists group
	p_echo " Checking for the group '$group'..."
	grp_res=`group_check "$group"`

	if [ "X$grp_res" != "X0" ]; then
			p_echo " Group '$group' not exists"
			p_echo " It is necessary to add group '$group'"
			err
	fi

	inten="add supplementary group '$group' for user '$user'"
	echo_try "$inten"

	existing=`id -Gn "$user"|sed 's|[[:space:]]\+|,|g'`
	if
		test "$group" = "`id -gn "$user"`" 		|| echo "$existing" | grep -q "\\<$group\\>"
	then
		p_echo " already there"
		return
	fi

	if test -z "$existing"; then
		newlist="$group"
	else
		newlist="$existing,$group"
	fi

	usermod -G "$newlist" "$user" 2>>"$product_log" && suc || die "$inten"
}

group_op()
{
	group="$1"
    gid="$2"
	id_force="$3"
	what_done=0
	local inten

    if [ "X$gid" = "Xsearch" ]; then
        gid=`get_user_group_id "$group" "gid" 30 400` 
    fi

	inten="add group '$group'"

	p_echo " Checking for the group '$group'..."
	grp_res=`group_check "$group"`

	case "$id_force" in
		true)
			case "$grp_res" in
				0)
				    case "$machine" in
				    *)
					etc_grp_res=`egrep "^$group:" /etc/group`
					case "$etc_grp_res" in
					*:*:*:*)
						chk_res=`echo "$etc_grp_res" | grep ":$gid:"`
						case "$chk_res" in
							*:*:*:*)
								p_echo " Group '$group' already exists"
								;;
							*) group_err "$group" "$gid"
								;;
						esac
						;;
					*)
						p_echo " Group '$group' already exists"
						;;
					esac
					;;

				    esac
				    ;;
				*)
					gid_res=`egrep "^[^:]*:[*x]*:$gid:" /etc/group | head -1`
					case "$gid_res" in
						*:*:*:*)
							gid_err "$gid"
							;;
						*)
							echo_try "$inten"
							groupadd -g "$gid" "$group" >> $product_log 2>&1 && suc ||
							die $inten
							what_done=1
							;;
					esac
					;;
			esac
			;;
		false)
			case "$grp_res" in
				0)
					p_echo " Group '$group' already exists"
					;;
				*)
					echo_try "$inten"
					groupadd "$group" >> $product_log 2>&1 && suc ||
					die $inten
					what_done=1
					;;
			esac
			;;
		*)
			p_echo "group_op: wrong last parameter -- must be 'true' or 'false'"
			p_echo
			p_echo "Exiting..."
			p_echo
			smart_undo_install
			exit 1
			;;
	esac

	p_echo
	common_var=$what_done
	if [ "X$what_done" = "X1" ]; then
		groups_created="$groups_created $group";
	fi
	return $what_done
}

user_op()
{
	user="$1"
	uid="$2"
	group="$3"
	u_desc="$4"
	u_home="$5"
	u_shell="$6"
	id_force="$7"
	gid_force="$8"
	what_done=0

    if [ "X$uid" = "Xsearch" ]; then
        uid=`get_user_group_id "$user" "uid" 30 400` 
    fi

	p_echo " Checking for the user '$user'..."
	id_res=`id "$user" 1>/dev/null 2>&1 ; echo $?`

	case "$id_force" in
		true)
			case "$id_res" in
				0)
					chk_res=`id "$user" 2>&1 | egrep '(^uid=.*gid=.*)|(^id.*user)'`
					if [ "X${gid_force}" = "Xfalse" ]; then
						chk_uid=`echo "$chk_res" | egrep "uid=""$uid""\(""$user""\)"`
					else
						chk_uid=`echo "$chk_res" | egrep "uid=""$uid""\(""$user""\)" | egrep "gid=[0-9]*\(""$group""\)"`
					fi
					case "$chk_uid" in
						uid=*gid=*)
							p_echo " User '$user' already exists"
							;;
						*) logname_err "$user" "$uid"
							;;
					esac
					chsh -s "$u_shell" "$user"
					;;
				*)
					uid_res=`egrep "^[^:]*:[^:]*:""$uid"":" /etc/passwd`
					case "$uid_res" in
						*:*:*:*)
							uid_err "$uid"
							;;
						*)
							pnnl_echo " Trying to add user '$user'... "
							useradd $useradd_options -u "$uid" -g "$group" -d "$u_home" -s "$u_shell" -c "$u_desc" "$user" >> $product_log 2>&1 &&
							suc || die "add user '$user'"
							what_done=1
							;;
					esac
					;;
			esac
			;;
		false)
			case "$id_res" in
				0)
					p_echo " User '$user' already exists"
					;;
				*)
					pnnl_echo " Trying to add user '$user'... "
					useradd $useradd_options -g "$group" -d "$u_home" -s "$u_shell" -c "$u_desc" "$user" >> $product_log 2>&1 &&
					suc || die "add user '$user'"
					what_done=1
					;;
			esac
			;;
		*)
			p_echo "user_op: wrong last parameter -- must be 'true' or 'false'"
			p_echo
			p_echo "Exiting..."
			p_echo
			smart_undo_install
			exit 1
			;;
	esac

	p_echo
	common_var=$what_done
	if [ "X$what_done" = "X1" ]; then
		users_created="$users_created $user";
	fi
	return $what_done
}

get_user_group_id()
{
    local name="$1"
    local src_name="$2"
    local min_num="$3"
    local max_num="$4"
    local count="$min_num"

    case "$src_name" in
       uid)
            local src="/etc/passwd"
            local type="users"

            get_userID "$name"
            if [ "X$?" = "X1" ]; then
               echo "$common_var"
               return 0
            fi
       ;;
       gid)
            local src="/etc/group"
            local type="groups"
            get_groupID "$name"
            if [ "X$?" = "X1" ]; then
               echo "$common_var"
               return 0
            fi
       ;;
       *)
            p_echo "$src_name for $name was not set"
            inten="detect uid/gid. Source file was not detect."
            die "$inten"
       ;;
    esac

    if [ ! -f "$src" ]; then
	p_echo
	p_echo "ERROR!"
	p_echo "$src_file: no such file"
	p_echo "Exiting..."
	smart_undo_install
	exit 1
    fi

    if [ $min_num -le 0 -o $min_num -ge $max_num ]; then 
		p_echo "get_user_group_id(): wrong parameters"
		smart_undo_install
		exit 1
    fi 

	nums=`cat $src | awk -F: '{print $3}' - | xargs echo -n " "` 

    while [ "$count" -le "$max_num" ]; do
         echo " $nums " | grep " $count " > /dev/null 2>&1 || break
         count=`expr $count + 1`

         if [ "$count" -ge "$max_num" ]; then 
            p_echo "$src_name for $name was not set"
			inten="get free $src_name. Free $src_name not found."
			die "$inten"
         fi
    done  
    
    echo "$count"
    return 0
}

add_login_shell()
{
	local shell

	shell="$1"

	p_echo " Checking that $shell registered as login shell..."

	case $linux_distr in 
	    debian)
		add-shell $shell
	    ;;
	    *)
		if grep -q "^$shell\$" /etc/shells; then
			p_echo "$shell already registered as a login shell"
		else
			echo "$shell" >> /etc/shells 2>> $product_log || die "register login shell $shell"
		fi
	    ;;
	esac

	p_echo
}
# prep_install

prep_install()
{
	mk_backup $inetd_conf cp f
}
initial_conf()
{
	DEMO_VERSION="no"
	PRODNAME="psa"
	PRODUCT_NAME="psa"
	product_full="Plesk"
	product=${PRODNAME}
	PRODUCT_FULL_NAME="Plesk"

	product_etc="/etc/${PRODNAME}"
	prod_conf_t="/etc/psa/psa.conf"
	prodkey="$product_etc/$PRODNAME.key"

	minimal_changes="0"

	EXTERNAL_PACKAGES=""
	EXTERNAL_PACKAGES_DIR=""

	BUILDER_UID="10007"

	PERL5LIB=/usr/local/psa/lib/perl5/site_perl/5.14.2:/usr/local/psa/lib/perl5/site_perl/5.14.2/i586-linux-thread-multi
	export PERL5LIB

        support_contact="http://www.parallels.com/support"
	sales_email="sales@parallels.com"

	product_version="10.13.4"
	product_db_version="010134"
	conceived_os_vendor=SuSE
	conceived_os_version="12.1"
	osrels="suse12.1"

	# This variable contains all versions, which is supported by
	# cumulative upgrade
	known_product_versions="80 81 82 83 84 86 90 92 93 95 100 101 107 108 109 1010 1011 1012 1013"

	prev_product="plesk"
	prev_clients_group="${prev_product}cln"

        clients_group="${product}cln"
        clients_GID=10001

        services_group="${product}serv"
        services_GID=10003

        product_suff="saved_by_${product}".`date "+%m.%d;%H:%M"`
        product_suffo="saved_by_${product}"

	PREV_PRODUCT_ROOT_D="/usr/local/${prev_product}"

	# plesk default password
	if [ "X$DEMO_VERSION" = "Xyes" ]; then
		PRODUCT_DEFAULT_PASSWORD="plesk"
	else
		PRODUCT_DEFAULT_PASSWORD="setup"
	fi
}

read_conf()
{
	[ -n "$prod_conf_t" ] || prod_conf_t=/etc/psa/psa.conf

	if [ -s $prod_conf_t ]; then
		tmp_var=`perl -e 'undef $/; $_=<>; s/#.*$//gm;
				s/^\s*(\S+)\s*/$1=/mg;
				print' $prod_conf_t`
		eval $tmp_var
	else
		if [ "X$do_upgrade" = "X1" ]; then
			[ 0$ignore_miss_conf -ne 1 ] && p_echo "Unable to find product configuration file: $prod_conf_t"
			return 1
		fi
	fi
	return 0
}

get_my_cnf_param()
{
	local my_cnf cnf_files

	cnf_files="/etc/my.cnf /etc/mysql/my.cnf /var/db/mysql/my.cnf"

	for my_cnf in ${cnf_files}; do
		if [ -f ${my_cnf} ]; then
			break
		fi
	done

	[ -f ${my_cnf} ] && r=`perl -e '$p="'"$1"'";
	undef $/; $_=<>; s/#.*$//gm;
	/\[mysqld\](.*?)\[/sg;
	$_=substr($1, rindex $1,"$p") and
	/$p\s*=(.*)/m and print $1
	' ${my_cnf}`
	echo $r
}

get_mysql_socket()
{
	mysql_socket="/var/run/mysql/mysql.sock"

	local mysqlsock=`get_my_cnf_param  socket`
	local MYSQL_SOCKETS="/var/lib/mysql/mysql.sock /tmp/mysql.sock /var/run/mysqld/mysqld.sock"

	for i in $mysql_socket $mysqlsock $MYSQL_SOCKETS; do
	    if [ -S "$i" ]; then
		    MYSQL_UNIX_PORT=$i
		    export MYSQL_UNIX_PORT
		    mysql_socket="$i"
		    break
	    fi
	done
}

conf_update()
{
	local def
	def="$1.default"
	umask 0022

	[ -s "$def" ] || return 1

	if [ ! -s "$1" ]; then
#		cp -f "$def" "$1"
#		return 0
		echo '#' > "$1"
	fi



perl -e '

open (my $config, $ARGV[0]) or die "Cannot open config $ARGV[0]\n";
while(<$config>){
s/#.*$//;
next if /^\s*$/;
/(\w+)\s+(.+)$/;
$cf{$1}=$2;
}
close $config;

$cf{PRODUCT_ROOT_D}=$ENV{PRODUCT_ROOT_D} if $ENV{PRODUCT_ROOT_D};

open (my $default, $ARGV[1]) or die "Cannot open default config $ARGV[1]\n";
while(<$default>){
 s/^\s*(\w+)(\s+)(.+)$/"$1$2".( (exists($cf{$1}))? $cf{$1}:$3 )/e;
 print;}
close $default;

' "$1" "$def" > "$1.new"

	if [ -s "$1.new" ]; then
	  if cmp -s $1.new $1; then
  		rm -f $1.new
		return 1
	  else
		rm -f $1.old
		ln $1  $1.old
		mv -f $1.new $1
		chmod 644 $1    # bug 64313, 65043
		p_echo "config updated"
		return 0
	  fi
	fi
	return 2
}

# setup new value for parameter
# $1 config file name $2 paramater name, $3 parameter value
conf_setval()
{
	cat $1 | awk -v varname="$2" -v varvalue="$3" 'BEGIN { f = 0 }
{ if ($1 == varname) { f = 1; print varname "\t" varvalue } else { print $0 } }
END { if (f == 0) { print "\n" varname "\t" varvalue } }' 		> $1.new

	if [ -s "$1.new" ]; then
	  if cmp -s $1.new $1; then
  		rm -f $1.new
		return 1
	  else
		rm -f $1.old
		ln $1  $1.old
		mv -f $1.new $1
		rm -f $1.old
		chmod 644 "$1"
		return 0
	  fi
	fi
	return 2
}

# A set of functions for work with config variables
# $1 is config file name, $2 is variable name, $3 is variable value

conf_getvar()
{
	cat $1 | perl -n -e '$p="'$2'"; print $1 if m/^$p\s+(.*)/'
}

conf_setvar()
{
	conf_setval "$@"
}

 #default values

product_default_conf()
{

PRODUCT_ROOT_D=/usr/local/psa
PRODUCT_RC_D=/etc/init.d
PRODUCT_ETC_D=/usr/local/psa/etc
PLESK_LIBEXEC_DIR=/usr/lib/plesk-9.0
HTTPD_VHOSTS_D=/srv/www/vhosts
HTTPD_CONF_D=/etc/apache2
HTTPD_INCLUDE_D=/etc/apache2/conf.d
HTTPD_BIN=/usr/sbin/httpd2
HTTPD_LOG_D=/var/log/apache2
HTTPD_SERVICE=apache2
QMAIL_ROOT_D=/var/qmail
PLESK_MAILNAMES_D=/var/qmail/mailnames
RBLSMTPD=/usr/sbin/rblsmtpd
COURIER_IMAP_ROOT_D=/
FTPD_CONF=/etc/proftpd.conf
FTPD_CONF_INC=/etc/proftpd.include
FTPD_BIN_D=/usr/bin
FTPD_VAR_D=/usr/local/psa/var/run
FTPD_SCOREBOARD=/usr/local/psa/var/run/scoreboard
NAMED_RUN_ROOT_D=/var/lib/named
NAMED_OPTIONS_CONF=/etc/named.conf.include.plesk-options
NAMED_ZONES_CONF=/etc/named.conf.include.plesk-zones
WEB_STAT=/usr/bin/webalizer
MYSQL_VAR_D=/var/lib/mysql
MYSQL_BIN_D=/usr/bin
PGSQL_DATA_D=/var/lib/pgsql/data
PGSQL_CONF_D=/var/lib/pgsql/data
PGSQL_BIN_D=/usr/bin
DUMP_D=/var/lib/psa/dumps
DUMP_TMP_D=/tmp
MAILMAN_ROOT_D=/usr/lib/mailman
MAILMAN_VAR_D=/var/lib/mailman
PYTHON_BIN=/usr/bin/python2.7
CATALINA_HOME=/usr/share/tomcat6
DRWEB_ROOT_D=/opt/drweb
DRWEB_ETC_D=/etc/drweb
GPG_BIN=/usr/bin/gpg
TAR_BIN=/bin/tar
AWSTATS_ETC_D=/etc/awstats
AWSTATS_BIN_D=/srv/www/cgi-bin/awstats
AWSTATS_TOOLS_D=/usr/share/awstats
AWSTATS_DOC_D=/usr/share/apache2/icons/awstats
OPENSSL_BIN=/usr/bin/openssl
LIB_SSL_PATH=/lib/libssl.so
LIB_CRYPTO_PATH=/lib/libcrypto.so
CLIENT_PHP_BIN=/usr/local/psa/bin/php-cli
SNI_SUPPORT=true
APS_DB_DRIVER_LIBRARY=/usr/lib/libmysqlserver.so.2

}

#-*- vim:syntax=sh

register_service(){

	[ -n "$1" ] || die "register_service: service name not specified"
	local inten="register service $1"
	echo_try "$inten"


# insserv for SuSE
	 /sbin/insserv -f "$1" >/dev/null 2>&1

	suc
}

#Need for register/unregister services into /etc/rc.conf for BSD OSes.
#Create or change strings such as service_option_variable="variable"
rc_service()
{
   local service="$1"
   local option="$2"
   local variable="$3"
   local comment="$4"
 
   local config="/etc/rc.conf"

   if [ "X$variable" = "Xdefault" ]; then
      remove_option_string "${service}_${option}" "$config"
      return 0
   fi

   if [ ! -f /etc/rc.conf ]; then
      die 'File /etc/rc.conf not found!'
   fi

   if [ "X$service" = "X" -o "X$option" = "X" -o "X$variable" = "X" ]; then
      die
   fi

   local flag="`grep "${service}_${option}" $config`"
   
   if [ "X$flag" = "X" ]; then
        if [ "X$comment" = "Xyes" ]; then
           echo "#Option for $service created by Plesk installer." >> $config
	fi
	echo "${service}_${option}=\"${variable}\"" >> $config || die 
   else
        sed -i "" -e 's|\('"${service}_${option}"'.*=\"\).*|\1'"${variable}"'\"|' $config  || die
   fi

   return 0
}

remove_option_string()
{
    #using: remove_option_string <option> <file>
    substring="$1"
    file="$2"

    awk '{
	if ($0 ~ "^'"$substring"'") {
	    next;
	}; 
	print $0; 
    }' < $file  > $file.tmp

    mv $file.tmp $file
}
# vim:syntax=sh

selinux_is_active()
{
	if [ -z "$SELINUX_ENFORCE" ]; then
		selinux_getenforce
	fi

	case "$SELINUX_ENFORCE" in
	Enforcing|Permissive) return 0;;
	*) return 1;;
	esac
}

selinux_get_mount_dir()
{
	unset SELINUX_MOUNT_DIR

	if awk '$2 == "/selinux"{exit(1)}' /proc/mounts && mkdir -p /selinux; then
		SELINUX_MOUNT_DIR=/selinux
	else
		SELINUX_MOUNT_DIR="`mktemp -d /tmp/selinuxXXXXXX`"
	fi >>"$product_log" 2>&1
}

selinux_getenforce()
{
	if [ "$1" = "--check" -a -n "$SELINUX_ENFORCE" ]; then
		return
	fi
	unset SELINUX_ENFORCE

	if ! ( command -v selinuxenabled >/dev/null 2>&1 && selinuxenabled ); then
		SELINUX_ENFORCE=Disabled
		return
	fi

	if awk '$3 == "selinuxfs"{exit(1)}' /proc/mounts; then
		selinux_get_mount_dir
		mount -t selinuxfs none "$SELINUX_MOUNT_DIR"
	fi

	if ! command -v getenforce >/dev/null 2>&1; then
		SELINUX_ENFORCE=Disabled
		return
	fi

	SELINUX_ENFORCE="`getenforce`"
	if test $? -ne 0; then
		SELINUX_ENFORCE=Disabled
		return
	fi
}

selinux_init()
{
	unset SELINUX_ENFORCE
	if selinux_is_active; then
		setenforce Permissive
	else
		unset SELINUX_ENFORCE
	fi
}

selinux_check()
{
	selinux_params
	if [ -n "$SELINUX_USE_MODULES" ]; then
		return
	fi

	if [ ! -r /etc/selinux/config ]; then
		return
	fi

	if ! selinux_is_active; then
		return
	fi

	if [ -r /etc/selinux/config ]; then
		. /etc/selinux/config
	fi

	if ! [ -r "/etc/selinux/$SELINUXTYPE/src/policy/file_contexts/program/plesk.fc" ]; then
		report_problem "Security-Enhanced Linux is activated with custom policy, and no Plesk specific rules were found. This may cause problems in Plesk functioning."
	fi
}

selinux_close()
{
	if [ -z "$SELINUX_ENFORCE" -o "$SELINUX_ENFORCE" = "Disabled" ]; then
		return
	fi

	setenforce "$SELINUX_ENFORCE"
}

selinux_fix_booleans()
{
    :
}


relabel_plesk_directories()
{
	selinux_params
	set_horde_params
	if selinux_is_active; then
		for dir in "$PRODUCT_ROOT_D" "$horde_logdir" "$NAMED_RUN_ROOT_D" 					"$HTTPD_VHOSTS_D" "$QMAIL_ROOT_D" /usr/local/frontpage					/var/db/kav /var/db/Quarantine "$PLESK_DB_DIR" 					"$POSTFIX_LIBEXEC_DIR" 					/var/drweb "$DRWEB_ROOT_D" "$PLESK_LIBEXEC_DIR" 					"/var/lib/plesk/mail" /opt/kav "/usr/lib/php/modules" ; do
			if [ -d "$dir" ]; then
				selinux_relabel_dir -e "$NAMED_RUN_ROOT_D/proc" "$dir"
			fi
		done
	fi
}

selinux_relabel_dir()
{
	if ! command -v restorecon >/dev/null 2>&1; then
		return
	fi
	if [ "$1" = "-F" ]; then
		selinux_set_force_arg
		shift
	else
		SELINUX_FORGE_ARG=
	fi

	if [ "$1" = "-e" ]; then
		selinux_set_exclude_arg "$2"
		shift 2
	else
		SELINUX_EXCLUDE_ARG=
	fi

	restorecon $SELINUX_FORGE_ARG $SELINUX_EXCLUDE_ARG -R "$@" >>"$product_log" 2>&1 || report_problem "Error while setting SELinux types for '$dir'"
}


selinux_params()
{
    SELINUX_USE_MODULES=
}

selinux_set_force_arg()
{
	SELINUX_FORGE_ARG="" 
}

selinux_set_exclude_arg()
{
	selinux_set_exclude_arg_pass "$1"
}

selinux_set_exclude_arg_pass()
{
	SELINUX_EXCLUDE_ARG=""
}


necessary_system_accounts_prep_install()
{
	p_echo
	p_echo "===> Checking for the necessary system accounts"
	common_var=0

# for mysql
	p_echo " Checking for the system groups and users necessary for MySQL..."
	group_op "$mysql_group" "$mysql_GID" false
	user_op "$mysql_user" "$mysql_UID" "$mysql_group" "MySQL Server" "/" "$dummy_shell" false

# for admin
	p_echo " Checking for the system groups and users necessary for admin server..."
	group_op "$admin_group" "search" false
	user_op "$admin_user" "search" "$admin_group" "Admin Server" "$dummy_home" "$dummy_shell" false

# for psaservices (only after creating apache and psaftp)
	group_op "$services_group" "$services_GID" false
	add_user_to_group "$apache_user" "$services_group"
	add_user_to_group "$anonftp_user" "$services_group"
	add_user_to_group "$admin_user" "$services_group"

# clients
	found=`get_user_group_id "clients" "gid" $clients_GID $max_suexec_GID`
	group_op $clients_group $found false

#for bind in MacOS
	if [ -x /usr/bin/niutil ]; then
		/usr/bin/niutil -list / /users/bin >>$product_log 2>&1

		/usr/bin/niutil -list / /groups/bind >>$product_log 2>&1
		if [ "$?" != "0" ]; then 
			group_op "bind" "53" true		
		fi
	fi
}

necessary_system_accounts_post_install()
{
	# these users may not exist before packages isntallation
	add_user_to_group sw-cp-server "$admin_group"
}

#set_params

set_common_params()
{
	common_var=0

	PATH=/sbin:/bin:/usr/sbin:/usr/bin:/usr/local/sbin:/usr/local/bin
	LANG=C
	export PATH LANG
	umask 022
	ulimit -n 65535 2>/dev/null

	K_HUP="/bin/kill -HUP"
	K_KILL="/bin/kill -KILL"
	K_TERM="/bin/kill -TERM"
	K_USR2="/bin/kill -USR2"

	users_created=""
	groups_created=""

	certificate_file="$PRODUCT_ETC_D/httpsd.pem"
	services="/etc/services"
	mtab="/etc/mtab"
	get_hostname="hostname"
	get_domainname="domainname"

	#VZP used to determine that we're inside SVE
	vza_file="/var/vzagent"

	#default parameters
	tar="tar"
	crontab="/usr/bin/crontab"

	cp_preserve="cp -p"
	SYSTEM_RC_D=/etc/init.d
	PLESK_LIBEXEC_DIR="/usr/lib/plesk-9.0"
	PLESK_DB_DIR="/var/lib/plesk"
	POSTFIX_LIBEXEC_DIR="/usr/lib/postfix"
	PRODUCT_BOOTSTRAPPER_DIR="/usr/local/psa/bootstrapper/pp10.13.4-bootstrapper"

	set_common_params_linux 

	detect_vz
}

set_common_params_linux()
{
	get_hostname="hostname -f"
	fstab="/etc/fstab"
	cp_preserve="cp --preserve=all --remove-destination"
	machine="linux"
	sendmail="/usr/sbin/sendmail"
	ps="ps axw"
	ps_long="ps axuw"
	false_shell="/bin/false"
	dummy_home="/"
	compress="gzip -9 -c"
	uncompress="gunzip -c"
	uudecode="uudecode -o /dev/stdout"
	ifconfig="/sbin/ifconfig -a"
	inet_str="inet addr"

	if [ -f /etc/slackware-version ]; then
	    linux_distr="slackware"
	    useradd_options=""
	    sndml_ini="/etc/rc.d/init.d/sendmail"
	    mail_local="/usr/libexec/mail.local"
	    dummy_shell=""
	    named_osrelease=0
	else
	    useradd_options="-M"
	    if [ -f /etc/mandrake-release ]; then
		linux_distr="mandrake"
	    elif [ -f /etc/fedora-release ]; then
		linux_distr="fedora"
	    elif [ -f /etc/SuSE-release ]; then
		linux_distr="suse"
		useradd_options="-r"
	    elif [ -f /etc/debian_version ]; then
		linux_distr="debian"
		get_domainname="dnsdomainname"
		useradd_options=""
	    else
		linux_distr="redhat"
	    fi

	    sndml_ini="/etc/init.d/sendmail"
	    mail_local="/usr/libexec/mail.local"
	    if [ -x /sbin/nologin ]; then
		dummy_shell="/sbin/nologin"
	    else
		dummy_shell="/bin/false"
	    fi
	    bash_shell="/bin/bash"
	    rbash_shell="/bin/rbash"
	    uudecode_full="/usr/bin/uudecode"
	    named_osrelease=`cat /proc/sys/kernel/osrelease | perl -F"/[.-]/" -n -a  -e 'printf "%02u%02u%02u\n", $F[0],$F[1],$F[2]'`
	fi

	return 0
}

define_start_script()
{
	if [ -f "$PRODUCT_RC_D/${product}.sh" ]; then
		START_SH="$PRODUCT_RC_D/${product}.sh"
	else
		START_SH="$PRODUCT_RC_D/${product}"
	fi
}

set_local_params()
{
	for i in set_admin_params lock_keyupdate set_apache_params set_awstats_params set_courier_imap_params set_horde_params set_syslog_params set_logrotate_params set_mysqld_params set_qmail_params set_webalizer_params ; do
		$i
		local res="$?"
		if [ "0$res" -gt 0 ]; then
			return "$res"
		fi
	done
}


chown_builder2root()
{
	### set permissions for all dirs except home dir
	find $PRODUCT_ROOT_D/ -not -name "home" -mindepth 1 -maxdepth 1 | while read dir; do
		find "$dir" -user $BUILDER_UID -exec chown -h root:0 "{}" \;
	done

	### set permissions for home dir
	if [ -d "$PRODUCT_ROOT_D/home" ]; then
		chown -h root:0 "$PRODUCT_ROOT_D/home"
		chown -h root:0 "$PRODUCT_ROOT_D/home/vhosts"
		for dir in default .skel chroot; do
			if [ -d "$PRODUCT_ROOT_D/home/vhosts/$dir" ]; then
				find "$PRODUCT_ROOT_D/home/vhosts/$dir" -user $BUILDER_UID -exec chown -h root:0 "{}" \;
			fi
		done
	fi
}
set_syslog_params()
{
	syslog_service="syslog"
	syslog_conf_ng="/etc/syslog-ng/syslog-ng.conf"

	syslog_conf=""
	for config in rsyslog.conf rsyslog.early.conf syslog.conf; do
		[ -f "/etc/$config" ] && syslog_conf="$syslog_conf /etc/$config"
	done

	# FIXME: quick fix of 142129
	if [ "${machine}" = "linux" -a ! -x "$PRODUCT_RC_D/$syslog_service" -a -x "$PRODUCT_RC_D/rsyslog" ]; then
		syslog_service="rsyslog"
		syslog_binary="/sbin/rsyslogd"
	elif [ "${machine}" = "linux" -a ! -x "$PRODUCT_RC_D/$syslog_service" -a -x "$PRODUCT_RC_D/syslog-ng" ]; then
		syslog_service="syslog-ng"
		syslog_binary="/sbin/syslog-ng"
	else
		local syslog_daemon
		for syslog_daemon in rsyslogd syslog-ng syslogd ; do
			syslog_binary="/sbin/$syslog_daemon"
			test -x "$syslog_binary" && break
		done
	fi
}
## @@constructor set_syslog_params

true syslog_status_linux_debian
syslog_status_linux_debian()
{
	get_pid "$syslog_binary" false
	local pid=$common_var
	if test "$pid" -ne 1; then
		# running
		return 0
	fi
	return 1
}


# -*- vim:syntax=sh

packagemng_set_dirty_flag()
{
	if [ -f ${PRODUCT_ROOT_D}/admin/bin/packagemng ]; then
		${PRODUCT_ROOT_D}/admin/bin/packagemng --set-dirty-flag 1>>$product_log 2>&1
	fi
}

get_product_versions()
{
	local prod_root_d="/usr/local/psa"
	
	product_name="psa"
	product_this_version="10.4.4"
	product_this_version_tag=""
	if [ -z "$product_prev_version" ]; then
		if [ -r "$prod_root_d/version.upg" ]; then
			product_prev_version=`cat "$prod_root_d/version.upg" | awk '{ print $1 }'`
		elif [ -r "$prod_root_d/version" ]; then
			product_prev_version=`cat "$prod_root_d/version" | awk '{ print $1 }'`
		else
			product_prev_version="$product_this_version"
		fi
	fi
}
set_logrotate_params()
{
	# primary Plesk logrotate config file
	logrotate_conf="${product_etc}/logrotate.conf"

	# directory for logrotate configs of virtual hosts
	logrotate_include_d="${PRODUCT_ETC_D}/logrotate.d"
}
upgrade_mailman_86()
{
	if [ "X$machine" = "XBSD" -a "$do_upgrade" = "1" ]; then
		conf_setvar "$prod_conf_t" "MAILMAN_ROOT_D" "/usr/lib/mailman" 
		conf_setvar "$prod_conf_t" "MAILMAN_VAR_D" "/var/lib/mailman" 
	fi
}

remove_modules()
{
	p_echo
	p_echo "===> Removing modules"

	local moduledir
	for moduledir in $PRODUCT_ROOT_D/var/modules/*; do
		if [ -d "$moduledir" -a -x "$moduledir/uninstall" ]; then
			local module=`basename $moduledist`
			echo_try "uninstall $module module"
			"$moduledir/uninstall" && suc || warn "uninstallation of $module module"
		fi
	done
}

# -*- vim:syntax=sh

# mysql

set_mysqld_params()
{
	mysql_user="mysql"
	mysql_UID=3306
	mysql_group="mysql"
	mysql_GID=3306

	product_db_sql="$PRODUCT_BOOTSTRAPPER_DIR/db/${PRODNAME}_db.sql"

	set_mysql_server_params
	set_mysql_client_params
}

## @@constructor set_mysqld_params

set_mysql_server_params()
{
	local service

	MYSQL_ROOT="$PRODUCT_ROOT_D/mysql"
	mysql_bindir="$MYSQL_BIN_D"

	get_mysql_socket

	if [ -x "${PRODUCT_RC_D}/mysql" ]; then
	    mysql_service="mysql"
	elif [ -x "${PRODUCT_RC_D}/mysql.sh" ]; then
	    mysql_service="mysql.sh"
	elif [ -x "${PRODUCT_RC_D}/mysqld" ]; then
	    mysql_service="mysqld"
	elif [ -x "${PRODUCT_RC_D}/mysql" ]; then
	    mysql_service="mysql"
	elif [ "X$DEMO_VERSION" = "Xyes" ]; then
	    mysql_service="mysqld"
	else
	    die "$inten"	
	fi
}

true mysql_stop mysql_status

set_mysql_client_params()
{
	mysql_client="$MYSQL_BIN_D/mysql"

#	Override these variables as needed
	mysql_db_name="$PRODNAME"
	mysql_passwd_file="$product_etc/.${PRODNAME}.shadow"
	prev_mysql_passwd_file="$PREV_PRODUCT_ROOT_D/admin/conf/admin.conf"

 	if [ -z "$mysql_unconfigured" ];then
#	Need for mysql_status related function
		set_mysql_server_params	
		set_mysql_auth
	fi

	mysql_args="-N"
	mysql_args_raw="-Br"

	# For backward compatibility only, should use mysql() and mysql_raw() instead
	mysql=mysql
	mysql_raw=mysql_raw
}

generate_mysql_credentials()
{
	mysql_defaults="$1"
	shift
	mysql_user=${1:+--user=$1}
	shift
	mysql_passwd=${*:+--password=$*}
}

# This function must be called *ONLY* for psa installation
setup_admin_login()
{
	unset MYSQL_PWD
	local mysql_db_name="mysql"
	local IFS_OLD
	local sl
	local inten="define valid mysql credentials"
	local i

	echo_try "$inten"
	get_admin_passwd
	IFS_OLD=$IFS

# --no-defaults:admin:$admin_passwd		admin with pass
# --no-defaults:root:					root without pass
# :root:								root with pass in defaults
# --no-defaults:admin:					admin withiyt pass
# --no-defaults:admin:$PRODUCT_DEFAULT_PASSWORD		admin with default pass
# :admin:								admin with pass in defaults
# ::									user and pass in defaults
# --defaults-file=/root/.my.cnf			hspc defaults (paranoid)
#
	for sl in `sequence 20`; do
		for i in	"--no-defaults:admin:$admin_passwd" 					"--no-defaults:root:" 					":root:" 					"--no-defaults:admin:" 					"--no-defaults:admin:$PRODUCT_DEFAULT_PASSWORD" 					":admin:" 					"::" 					"--defaults-file=/root/.my.cnf::"; do
			IFS=":"
			generate_mysql_credentials $i
			IFS=$IFS_OLD
			if mysql_test_connection; then
				suc
# 	create/Update admin superuser
				echo "grant all privileges on *.* to 'admin'@'localhost' identified by '$admin_passwd' with grant option;flush privileges" | mysql_direct mysql
				update_psa_shadow
				set_mysql_auth
#	backup private my.cnf if it contains password (vz/hspc related)
				rm -f /.my.cnf
				grep -q '\s*password\s*=' /root/.my.cnf 2>/dev/null && mv -f /root/.my.cnf /root/.my.cnf.bak
				return 0
			fi
		done
		p_echo "One more attempt to connect"
		sleep "$sl"
	done
	die "$inten"
}

update_psa_shadow()
{
	echo "$admin_passwd" > $mysql_passwd_file || die
	chown $admin_user:$admin_group ${mysql_passwd_file} || die
	chmod 600 ${mysql_passwd_file} || die
}

encrypt_psa_shadow()
{
	local init_conf_bin="$PRODUCT_ROOT_D/bin/init_conf"
	[ -x "$init_conf_bin" ] && 	PSA_PASSWORD="$admin_passwd" "$init_conf_bin" --set-admin-password -passwd '' -encrypted-password >> "$product_log" 2>&1
	if [ "$?" -eq 0 ]; then
		admin_passwd=
		set_mysql_auth
	else
		warn "encrypting admin password"
	fi
}

# iF YOUR package want to use mysql db you must call this function directly
set_mysql_auth()
{
	local inten="set up mysql authentification"
	get_admin_passwd

	pleskrc mysql start

	mysql_user="--user=admin"
	mysql_passwd="--password=$admin_passwd"
	unset mysql_defaults

	if [ -z "$MYSQL_AUTH_SKIP_CONNECTION_CHECK" ]; then
		mysql_test_connection 60 || die "$inten"
	fi
	suc
}

get_admin_passwd()
{
    [ -z "$admin_passwd" ] || return 0

    if [ -f "$mysql_passwd_file" ]; then
		admin_passwd=`cat "$mysql_passwd_file"`
		return 0
    fi

	admin_passwd=`get_random_string 12 'A-Za-z0-9_'`

	[ -n "$admin_passwd" ] || admin_passwd="$PRODUCT_DEFAULT_PASSWORD"
}

#Invoke mysql
mysql()
{
	mysql_anydb -D$mysql_db_name "$@"
}

mysql_anydb()
{
	$mysql_client $mysql_user $mysql_passwd $mysql_args "$@" 2>>"$product_log"

	local status=$?
	if [ $status -gt 0 ]; then
		$mysql_client $mysql_user $mysql_passwd $mysql_args -D$mysql_db_name $mysql_args_raw -e "SHOW ENGINE innodb status" >>"$product_log" 2>&1
	fi
	return $status
}

# Invoke mysql without any wrapper or something else
mysql_direct()
{
	$mysql_client $mysql_defaults $mysql_user $mysql_passwd $mysql_args "$@" 2>>"$product_log"
}

# Invoke mysql in raw mode
mysql_raw()
{
	mysql $mysql_args_raw "$@"
}

mysql_raw_anydb()
{
	mysql_anydb $mysql_args_raw "$@"
}

mysql_start_linux_suse_ex()
{
	if [ -x "/sbin/service" ]; then
		action_cmd="/sbin/service mysql"
	else
		action_cmd="$SYSTEM_RC_D/$mysql_service"
	fi

	$action_cmd start >> $product_log 2>&1
}

true mysql_start_linux_suse
mysql_start_linux_suse()
{
	inten="start service mysql"
	echo_try "$inten"

	mysql_start_linux_suse_ex
	local rc="$?"

# bug 52690. MySQL init script reports failure if protected mysqld is running (true for SuSE >= 11.3)
	if [ "$rc" -ne 0 ]; then
		local mysqld_bin="/usr/sbin/mysqld"
		killall -TERM mysqld >> $product_log 2>&1
		if [ -x "$mysqld_bin" ]; then
			for i in 2 4 8 16 32; do
				get_pid "$mysqld_bin" false
				local pid="$common_var"
				if test "$pid" -eq 1; then
					break
				fi
				killall -TERM mysqld >> $product_log 2>&1
				sleep $i
			done
		fi
		mysql_start_linux_suse_ex
		rc="$?"
	fi

	[ "$rc" -eq 0 ] && suc || warn "$inten"
	return $rc
}

mysql_test_connection()
{
	inten="establish test connection"
	echo_try $inten
	attempts=${1:-1}	
	for i in `sequence $attempts`; do
		echo "" | mysql_direct mysql >> "$product_log" 2>&1
		if [ "$?" -eq "0" ]; then
			p_echo "connected"
			return 0
		fi
		[ "$attempts" -eq "1" ] || sleep 2
	done

	p_echo "failed"
	return 1
}

###	FIXME: probably need var service_restart warn
mysql_stop()
{
	local op_result i

	inten="stop MySQL server"
	echo_try $inten

	$PRODUCT_RC_D/$mysql_service stop >> $product_log 2>&1

	op_result=$?

	if [ "X$linux_distr" = "Xdebian" ]; then
# Debian has well designed mysql stopping code
		[ "$op_result" -eq 0 ] || die $inten
		suc
		return 0
	fi

	for i in 2 4 6 8 16; do
		if ! mysql_status ; then
			suc
			return 0
		fi

		case $machine in
			BSD*|Darwin*)
				#In BSD systems mysqld must to be killed without -9 flag
				killall mysqld mysqld_safe >> $product_log 2>&1
			;;
			*)
				# I just want to be sure that mysql really stopped
				killall -TERM mysqld mysql safe_mysqld mysqld_safe >> $product_log 2>&1
			;;
		esac
		sleep $i
	done

	die "$inten"
}

mysql_status()
{
	local file

    #Check with native script first
	#debian script always return 0. bug #111825
	[ "X$linux_distr" = "Xdebian" ] && msqld_status_supported="no"
	
	if [ -z "$msqld_status_supported" ]; then
# MySQL AB packages doesn't know about status command
		if LC_MESSAGES=C $PRODUCT_RC_D/$mysql_service 2>&1 | grep -q "status"; then
			msqld_status_supported="yes"
		else
			msqld_status_supported="no"
		fi
	fi

	if [ "$msqld_status_supported" = "yes" ]; then
# Common RPM mysql's and FreeBSD
	$PRODUCT_RC_D/$mysql_service status >> $product_log 2>&1 		&& return 0
	fi

	if [  "$msqld_status_supported" = "no" ]; then
# MySQL AB packages
		file="/usr/sbin/mysqld"
	fi

    if [ -x "$file" ]; then
		#standard build and debian
		get_pid "$file" false
		pid=$common_var
		if test "$pid" -ne 1; then
			echo "$file (pid $pid) is running..." >>$product_log 2>&1
			return 0
		else
			echo "$file is stopped" >>$product_log 2>&1
			return 1
		fi
	fi

	return 1
}

check_db()
{
	local myOK db_connected db_password

	inten="find $PRODNAME database"
	echo_try $inten

#	If database not exists
	if ! db_test --any-db "SHOW DATABASES" '/^psa$/'; then
		p_echo "not found"
		local mysql_db_name="mysql"
		db_do "drop database if exists test"
		db_do "delete from user where User=''"
		db_do "delete from user where User='root'"
		db_do "flush privileges"
		return 1
	fi
#	Database found, but version undefined
	if ! db_select "select val from misc where param='version'" || [ -z "$db_select_output" ]; then
		p_echo "DATABASE ERROR!!!"
		p_echo "Database $PRODNAME found, but version undefined"
		die $inten
	fi

	prev_db_version="$db_select_output"

# Now check psa database version
	p_echo "version is $prev_db_version"
	prev_db_short_version=`expr ${prev_db_version} / 10`

	if [ "0$prev_db_short_version" -ne "0$prev_short_version" -a 		 "0$product_db_version" -ne "0$prev_db_version" ]; then
		p_echo "DATABASE ERROR!!!"
		p_echo "Previous product version is ${prev_version}, but previous database"
		p_echo "version is ${prev_db_version}. In most of cases it is result of"
		p_echo "previous upgrade try failure. Please, restore previous version"
		p_echo "from backup, and try again or contact technical support."
		die "check database version"
    fi

	# this message for situation, where psa was deleted, but database not
    if [ "X$prev_db_version" = "X$product_db_version" -o 		 "X${product_db_version}" = "X$prev_db_version" ]; then
	    p_echo "Version is OK, no need to create $PRODNAME database."
    fi

	return 0;
}

product_install_db()
{
	p_echo "===> Installing $PRODNAME database"

#	Start mysql without test connection mysql isn't initialize yet
	pleskrc mysql start

	setup_admin_login	

	get_mysql_socket

	inten="check ${PRODNAME} database"
	echo_try $inten
	if check_db; then
	    # product database OK, no need to create it
	    return 0
	fi

	inten="install initial $PRODUCT_NAME database"
	echo_try $inten
	[ -f "$product_db_sql" ] || die "$inten: file not found: $product_db_sql"
	mysql_anydb < $product_db_sql && suc || die $inten

	db_do "replace into misc (param,val) values('def_locale', '$default_locale')"
	db_do "$query replace into locales(id) values('$default_locale')"
	db_do "$query alter table clients alter locale set default '$default_locale'"

	db_install_dashboard_presets

	db_init_updater_state

	set_db_version
	db_do "REPLACE INTO misc(param, val) VALUES('mysql41_compatible', 'true')"
}

db_install_dashboard_presets()
{
	local inten
	inten="install initial Desktop presets"
	mysql < "$PRODUCT_BOOTSTRAPPER_DIR/db/${PRODNAME}_db_dashboard_presets.sql" >> "$product_log" 2>&1 || die "$inten"
}

db_init_updater_state()
{
	local disable_updater="false"
	$mysql <<EOF || die "init updater state"
		REPLACE INTO misc(param, val) VALUES('disable_updater', '$disable_updater');
EOF
}

set_db_version()
{
	#install db version
	echo_try "set psa database version to $product_db_version"
	db_do "replace into misc (param,val) values('version', '$product_db_version')"
}

configure_mysql_innodb()
{
	local my_cnf awk_script
	my_cnf=$1

	if ! $mysql_client --version | grep -q '3\.23'; then
		return
	fi

	if ! (test -f $my_cnf && grep -q '^\[mysqld\]' "$my_cnf"); then
		echo "[mysqld]" >> $my_cnf
		echo "innodb_data_file_path=ibdata1:10M:autoextend" >> $my_cnf
		echo "safe-show-database" >> $my_cnf
		return
	fi

	awk_script='/^\[mysqld\]$/{print; print "innodb_data_file_path=ibdata1:10M:autoextend"; next;} {print}'
	if ! grep -q '^innodb_data_file_path' "$my_cnf"; then
		awk "$awk_script" "$my_cnf" >"$my_cnf.tmp" && mv "$my_cnf.tmp" "$my_cnf" || die "edit $my_cnf"
	fi

	awk_script='/^\[mysqld\]$/{print; print "safe-show-database"; next;} {print}'
	if ! grep -q '^safe-show-database' "$my_cnf"; then
		awk "$awk_script" "$my_cnf" >"$my_cnf.tmp" && mv "$my_cnf.tmp" "$my_cnf" || die "edit $my_cnf"
	fi
}

#bug #46837. Disable "LOAD DATA LOCAL INFILE" command.
configure_mysql_infile()
{
	local my_cnf awk_script sys
	my_cnf=$1

	if ! (test -f $my_cnf && grep -q '^\[mysqld\]' "$my_cnf"); then
		echo "[mysqld]" >> $my_cnf
		echo "local-infile=0" >> $my_cnf
		return
	fi

	awk_script='/^\[mysqld\]$/{print; print "local-infile=0"; next;} {print}'
	if ! grep -q '^local-infile' "$my_cnf"; then
		awk "$awk_script" "$my_cnf" >"$my_cnf.tmp" && mv "$my_cnf.tmp" "$my_cnf" || die "edit $my_cnf"
	fi
}

configure_mysql_nonlocal()
{
	local my_cnf
	my_cnf=$1

	if grep -q '^bind-address' "$my_cnf"; then
		sed -e "s|^\(bind-address[[:space:]]*=[[:space:]]*127\.0\.0\.1.*\)|# \1|g" 			"$my_cnf" >"$my_cnf.tmp" && mv "$my_cnf.tmp" "$my_cnf" || die "edit $my_cnf"
	fi
}

mysql_install_init()
{
	cnf_files="/etc/my.cnf /etc/mysql/my.cnf /var/db/mysql/my.cnf"

	for my_cnf in $cnf_files; do
		if [ -f ${my_cnf} ]; then
			break
		fi
	done

	#Bug #117044. 
	dir="`echo $my_cnf | sed -e 's|\(.*\)\/.*|\1|g'`"
	if [ ! -d $dir ]; then
	    mkdir -p $dir 
	    chown ${mysql_user}:${mysql_group} $dir
	    chmod 755 $dir
	fi

	configure_mysql_innodb "$my_cnf"
	configure_mysql_infile "$my_cnf"
	configure_mysql_nonlocal "$my_cnf"


	product_install_db
	update_mysql4_permissions
	mysql_fix_remove_empty_users
	tune_vz_mysql "$my_cnf"
	pleskrc mysql restart
}

mysql_fix_remove_empty_users()
{
	db_do "DELETE FROM mysql.user WHERE user = ''; FLUSH PRIVILEGES;"
}

dump_db()
{
	${MYSQL_BIN_D}/mysqldump $mysql_user $mysql_passwd --quote-names --databases $*
}
#!/bin/sh

__tune_vz_mysql_sig_handler() {
    local rc=$?
    trap - EXIT
    rm -f -- "$1"
    exit $rc
}

__tune_vz_mysql()
{
    local myCnf myCnfTemp ||:

    myCnf=$1
    if test -z "$myCnf"; then
	warn "E:usage: $PROG /path/to/my.cnf"
	return 1
    fi

    if ! test -s "$myCnf" ; then
	warn "E: $myCnf doesn't exist or empty"
	return 100
    fi
    
    myCnfTemp=`mktemp ${myCnf}.XXXXXXX`
    if test $? -ne 0 ; then
	warn "E:Unable to create a temporary configuration file"
	return 2
    fi
    
    $cp_preserve $myCnf $myCnfTemp || {
	warn "E:Unable to create a temporary configuration file"
	return 2
    }

    trap "__tune_vz_mysql_sig_handler \"$myCnfTemp\""  HUP PIPE INT TERM EXIT

    local rc ||:

    local db_select_output
    db_select "SHOW VARIABLES LIKE 'have_innodb'"
    local have_innodb=`get_narg 2 ${db_select_output}`
    [ -n "$have_innodb" ] || have_innodb="NO"

    db_select "SHOW VARIABLES LIKE 'have_bdb'"
    local have_bdb=`get_narg 2 ${db_select_output}`
    [ -n "$have_bdb" ] || have_bdb="NO"

    cat "$myCnf" | gawk 		-v have_innodb="${have_innodb}" 		-v have_bdb="${have_bdb}" 		'
function getsize(sizestr)
{
  if (match(sizestr, "[^[:digit:]]")) {
    size=substr(sizestr, 0, RSTART);
    mult=substr(sizestr, RSTART, 1);
    if ("K" == mult) {
      mult=1024;
    } else if ("M" == mult) {
      mult=1024*1024;
    } else if ("G" == mult) {
      mult=1024*1024*1024;
    }
    size = size * mult;
  } else {
    size = sizestr;
  }
  return size;
}

# add unspecified variables
function finalize_section()
{
  if (have_bdb && 0 == skipbdb) {
    printf("skip-bdb\n\n");
    changed=1;
  }
  if (have_innodb && 0 == ibp_size) {
    print "innodb_buffer_pool_size=2M"
    changed=1;
  }
  if (have_innodb && 0 == iamp_size) {
    print "innodb_additional_mem_pool_size=500K"
    changed=1;
  }
  if (have_innodb && 0 == ilb_size) {
    print "innodb_log_buffer_size=500K"
    changed=1;
  }
  if (have_innodb && 0 == thread_conc_set) {
    print "innodb_thread_concurrency=2"
    changed=1;
  }
}

# decrease value of "varname" if it exceed the upper bound limit.
# If value fit (less or equal), leave it unmodified.
function adjustSetting(varstr, varname, minsize, sizestr)
{
  if (match(varstr,"^[[:space:]]*(set-variable[[:space:]]*=[[:space:]]*)?" varname "[[:space:]]*=[[:space:]]*")) {
    if (have_innodb) {
      size = getsize(substr(varstr, RSTART+RLENGTH));
      if (minsize < size) {
        changed = 1;
        print "#", $0;
        print varname "=" sizestr;
      } else {
        print $0
      }
    } else {
      # we do not have innodb so we need to disable this setting
      print "#", $0;
      changed = 1;
    }
    return 1;
  }
  return 0;
}

function reset_variables()
{
  skipbdb=0;   # already have skip-bdb
  ibp_size=0;  # already set innodb_buffer_pool_size
  iamp_size=0; # already set innodb_additional_mem_pool_size
  ilb_size=0;  # already set innodb_log_buffer_size
  thread_conc_set=0; # -*- innodb_thread_concurrency
}

BEGIN {
  insect=0;    # within one of server sections
  changed=0;   # already changed smth
  have_bdb = (tolower(have_bdb) == "yes") ;
  have_innodb = (tolower(have_innodb) == "yes") ;
  reset_variables()
}
/^[[:space:]]*\[.+\]/ {
  if (0 != insect) {
# need to close a previous section
    finalize_section();
    # section is ended. Reset variables
    reset_variables()
    insect    = 0;
  }
  if ( match($0, "^[[:space:]]*\\[(mysqld|server|mysqld_safe|safe_mysqld)\\]")) {
    insect = 1;
#    print "# in server section";
  }
}

(match($0, "^[[:space:]]*(set-variable[[:space:]]*=)?[[:space:]]*") && 0 != insect) {
  varstr=substr($0, RSTART+RLENGTH);
  if (adjustSetting(varstr, "innodb_buffer_pool_size", 2 * 1024 * 1024, "2M")) { ibp_size=1; next; }
  if (adjustSetting(varstr, "innodb_additional_mem_pool_size", 500 * 1024, "500K")) { iamp_size=1; next; }
  if (adjustSetting(varstr, "innodb_log_buffer_size", 500 * 1024, "500K")) { ilb_size=1; next; }
  if (adjustSetting(varstr, "innodb_thread_concurrency", 2, "2")) { thread_conc_set=1; next; }
}

(adjustSetting($0, "innodb_buffer_pool_size", 2 * 1024 * 1024, "2M")) { ibp_size=1; next; }
(adjustSetting($0, "innodb_additional_mem_pool_size", 500 * 1024, "500K")) { iamp_size=1; next; }
(adjustSetting($0, "innodb_log_buffer_size", 500 * 1024, "500K")) { ilb_size=1; next; }
(adjustSetting($0, "innodb_thread_concurrency", 2, "2")) { thread_conc_set=1; next; }

/^[[:space:]]*skip-bdb[[:space:]]*(#.*)?$/ { skipbdb=1; }

{ print $0; }

END {
  if (0 != insect) {
    finalize_section();
  }

  if (0 == changed) {
    exit 110;
  }
}
' > "$myCnfTemp"
    rc=$?

    if test $rc -eq 110; then
	# nothing was changed
	p_echo "I: nothing to change in $myCnf"
	return 0
    fi

    if test $rc -ne 0; then
	warn "E: unable to process ${myCnf}: rc=$rc"
	return 2
    fi
    
    local myCnfBak ||:
    myCnfBak="${myCnf}.bak"

    if ! ln -f "$myCnf" "$myCnfBak" ; then
	warn "E: Unable to create a backup file"
	return 3
    fi

    if ! mv -f "$myCnfTemp" "$myCnf"; then
	warn "E: Unable to overwrite the configuration file"
	return 4
    fi
    
    trap - EXIT
    return 0
}

tune_vz_mysql()
{
    # check if we in VZ environment
    test "x$PLESK_VZ" = "x1" || return 0;
    # run in subshell to isolate TRAP usage
    ( __tune_vz_mysql "$1" )
}
#-*- vim:syntax=sh

set_named_params()
{
	# set up default values
	bind_UID=53
	bind_GID=53
	bind_user="named";
	bind_group="named";

	# get UID of named user, if exists
	get_userID $bind_user
	if [ $? -ne 0 ]; then
	    bind_UID=$common_var;
        fi

	# get GID of named group, if exists
	get_groupID $bind_group
	if [ $? -ne 0 ]; then
	    bind_GID=$common_var;
	fi

	# path to directory of internal named
	NAMED_ROOT_D="${PRODUCT_ROOT_D:?'PRODUCT_ROOT_D is undefined'}/named"

	# path to directory of named pid file
	bind_run="${NAMED_RUN_ROOT_D:?'NAMED_RUN_ROOT_D is undefined'}/var/run/named"

	named_service="named"
	named_log="/dev/null"
	
	# path to named config file
	named_conf="/etc/named.conf"
	rndc_conf="/etc/rndc.conf"
	rndc_namedb_conf="/etc/namedb/rndc.conf"
	rndc_bind_conf="/etc/bind/rndc.conf"
}

sysconfig_named()
{

	# sysconfig_named not needed for SuSE
	return 0


	if [ "X$needed_to_restart_syslog" = "Xyes" ]; then
		[ -f /etc/rc.d/syslogd ] && /etc/rc.d/syslogd restart
	fi

	return 0
}


# own -> native transition is not assigned to specific Plesk version
# so we must handle here both the uprade from "own" and "native"
install_named_native()
{
	set_named_params

	pleskrc named stop

	named_conf_restore_system
	sysconfig_named
	named_conf_add_includes
	install_rndc_native
	if [ "$do_upgrade" != 1 ]; then
		"$UTILS_DIR/dnsmng" --dns-recursion localnets
	fi
}

install_rndc_native()
{
	# new rndc works ok without the config, only with /etc/rndc.key
	rm -f /etc/rndc.conf /etc/namedb/rndc.conf

	if [ "X$machine" = "XBSD" ]; then
	    if [ ! -f "/etc/namedb/rndc.key" ]; then
		/usr/sbin/rndc-confgen -a
	    fi
	fi
}

named_conf_restore_system()
{
	if [ "X$std_to_pkg" = "X1" ]; then
            #bug 120791
            cat /etc/rc.conf | awk '/named_chroot/{next;}{print;}' > /etc/rc.conf.tmp
            mv /etc/rc.conf.tmp /etc/rc.conf
            unlink /etc/namedb 2>/dev/null
            ln -s /var/named/etc/namedb /etc/namedb

	    if [ ! -f $named_conf -a -f /etc/named.conf ]; then
		cp -f /etc/named.conf $named_conf
		rm -f /etc/named.conf
	    fi
	fi 

	if ! [ -h "$named_conf" ] ; then
		return
	fi

	if [ "`readlink $named_conf`" != "$NAMED_RUN_ROOT_D""$named_conf" ]; then
		report_problem "$named_conf is a symlink to somewhere (`readlink $named_conf`) which is not a copy which Plesk used to create. Probably you have custom modifications in system configuration." 			"Installation will continue using this link."
		return
	fi

	echo_try "restore system bind9 configuration"

	# restore /etc/named.conf
	if [ -f "$named_conf"."$product_suffo" ]; then
		mv -f "$named_conf"."$product_suffo" "$named_conf" || die "restore named.conf"
	else
		report_problem "backup file $named_conf.$product_suffo not found." 			"A file which Plesk created will be used."
		cp -f `readlink $named_conf` "$named_conf"
		NAMED_CONF_NEEDS_CLEANUP=yes
	fi

	# remove links in the system's jail
	find /var/lib/named -type l | while read link; do
		dest=`readlink "$link"`
		case "$dest" in
		/*) rm "$link";;
		esac
	done
	# Bug 120818
	start_script="/etc/init.d/named"
	sed -e 's|localtime,rndc.key|localtime,named.conf,rndc.key|g' 		< "$start_script" > "$start_script.tmp" &&
		mv -f "$start_script.tmp" "$start_script" &&
		chmod 755 "$start_script"

	suc
}

named_conf_add_includes()
{
	touch "$NAMED_ZONES_CONF"
	touch "${NAMED_RUN_ROOT_D}/${NAMED_ZONES_CONF}"
	if ! grep -q 'include ".*named\.conf\.include.plesk-zones";$' "$named_conf"
	then
		echo "include \"$NAMED_ZONES_CONF\";" >>"$named_conf"
	fi

	touch "$NAMED_OPTIONS_CONF"
	touch "${NAMED_RUN_ROOT_D}/${NAMED_OPTIONS_CONF}"
	if ! grep -q 'include ".*named\.conf\.include.plesk-options"' "$named_conf"
	then
		awk -v NAMED_OPTIONS_CONF="$NAMED_OPTIONS_CONF" 			'{print} /^options {$/{print "include \"" NAMED_OPTIONS_CONF "\";";}' "$named_conf" 			> "$named_conf.tmp" 		&& mv "$named_conf.tmp" "$named_conf" 		|| die "add include clause to $named_conf:options"
	fi

# PCI-Compliance: hide native bind version
	if ! grep -q '^\s*version' "$NAMED_OPTIONS_CONF"; then
		echo 'version "none";' >> $NAMED_OPTIONS_CONF
	fi
}

configure_named_ipv6 ()
{
	realconf=`readlink $named_conf`
	if [ x"$realconf" = x"" ]; then
		realconf=$named_conf
	fi
        tmp_conf=`mktemp $realconf.XXXXXX`

        if [ -f /proc/net/if_inet6 ]; then
                listen_cmd='/options {/a		listen-on-v6 { any; };'
        else
                listen_cmd=""
        fi
        sed -e "/listen-on-v6/d" -e "$listen_cmd" $realconf > $tmp_conf
	chmod 644 $tmp_conf
        mv $tmp_conf $realconf
}

install_named()
{
	install_named_native

	pleskrc named stop
	configure_named_ipv6
	pleskrc named start
}

named_writeconf()
{
	pleskrc named stop

	if [ -n "$NAMED_CONF_NEEDS_CLEANUP" ]; then
		awk '
			BEGIN{
				brac_count = 0;
				match = 0;
			}
			brac_count == 0 && /\<acl [a-z_-]* \{$/ {
				match = 1;
			}
			brac_count == 1 && /\<allow-recursion \{$/ {
				match = 1;
			}
			brac_count == 0 && /\<zone "[^"]*"( in)? \{$/ 			&& ! /"(\.|localhost\.|0\.0\.127\.in-addr\.arpa)"/ {
				match = 1;
			}
			{
				brac_count = brac_count + count($0, "{") - count($0, "}");
				if (match == 1) {
					print "#", $0
				} else {
					print
				}
				if (brac_count == 0) match = 0;
			}
			function count(str, symbol,       pos) {
				pos = index(str, symbol);
				if (pos == 0) return 0;
				return count(substr(str, pos + 1), symbol) + 1;
			}
		' "$named_conf" >"$named_conf.tmp" 2>>"$product_log" 		&& mv -f "$named_conf.tmp" "$named_conf" >>"$product_log" 2>&1 		|| report_problem "remove Plesk related changes from named.conf"
	fi

	set_dns_recursion_in_config
	mysql_raw -e "select name from dns_zone" | while read domain; do
		"$UTILS_DIR/dnsmng" --update "$domain" --without-reverse
	done

	pleskrc named start
}

set_dns_recursion_in_config()
{
	db_select "select val from misc where param='dns_recursion'"
	dns_recursion="$db_select_output"
	if [ "any" = "$dns_recursion" -o "localnets" = "$dns_recursion" -o "localhost" = "$dns_recursion" ]; then
		"$UTILS_DIR/dnsmng" --dns-recursion $dns_recursion
	fi
}

true named_status_linux_debian
named_status_linux_debian()
{
    get_pid "/usr/sbin/named" false
    local pid=$common_var
    if test "$pid" -ne 1; then
# running
		return 0
    fi
    return 1
}

pam_params()
{
   local calltype
   calltype=$1
   initial_conf
   local product="psa"
   pam_config_dir="/usr/local/psa/pam_plesk_config"
   [ "x" = "x1" ] && pam_extra_args="-m /lib/security/pam_plesk.so"
   if [ "x$calltype" != "x1" ]; then # install, not uninstall
       [ "x" = "x1" ] && pam_extra_args="$pam_extra_args --fixup-ftpd"
       [ "x" = "x1" ] && pam_extra_args="$pam_extra_args --fixup-des"
   fi
   pam_inst_script="pam_plesk_install"
   pam_uninst_script="pam_plesk_remove"

   return 0
}

install_pam()
{
  inten="install PAM module"
  pam_params
  echo_try "$inten"

  "$pam_config_dir/$pam_inst_script" -qq 	--install-log "$product_log" 	--problem-log "$product_problems_log" $pam_extra_args
 
  if [ "X$?" = "X0" ]; then
     suc
  else
     warn "install PAM module not successed" 
  fi

  return 0
}

phpmyadmin_config_backup()
{
	set_phpmyadmin_params
	[ -f "$PHPMYADMIN_CONFIG" ] && cp "$PHPMYADMIN_CONFIG" "$PHPMYADMIN_CONFIG.save"
}

install_phpmyadmin()
{
	p_echo "===> Installing phpMyAdmin"
	set_phpmyadmin_params
	rename_old_configs
	pma__configure
	suc
}

set_phpmyadmin_params()
{
	PHPMYADMIN_D="$PRODUCT_ROOT_D/admin/htdocs/domains/databases/phpMyAdmin"
	PHPMYADMIN_CONFIG="$PHPMYADMIN_D/libraries/config.default.php"
}

rename_old_configs()
{
	for i in $PHPMYADMIN_D/config.*; do
		[ -f "$i" ] && mv $i $i.old
	done;
}

pma__configure()
{
	local controluser controlpass pmadb
	local bookmarktable column_info history pdf_pages relation table_coords table_info designer_coords tracking userconfig

	controluser=''

	pma__set_default_values
	pma__set_random_values

	if [ -f "$PHPMYADMIN_CONFIG.save" ]; then
		# looking for values of following variables in config.inc.php.save
		pma__set_values_from_config 'controluser' 'controlpass' 'pmadb' 'bookmarktable' 'relation' 'table_info' 'table_coords' 'pdf_pages' 'column_info' 'history' 'designer_coords' 'tracking' 'userconfig'
	fi

	# Make sure that phpmyadmin script is idempotent, when phpmyadmin upgrade
	pma__create_pmadb

	# write new config.inc.php
	sed -e "`pma__sed_script`" < "$PHPMYADMIN_CONFIG.tpl" > "$PHPMYADMIN_CONFIG"
}

pma__set_values_from_config()
{
	eval `pma__read_values "$@"`
}

pma__read_values()
{
        [ -f $PHPMYADMIN_CONFIG.save ] && sw_engine_pleskrun -r '
                        try {
                                error_reporting(0);
                                $GLOBALS["db_host"] = "localhost";
                                function vz::in_vzcp_proxy() { return false; };
                                require_once("'$PHPMYADMIN_CONFIG.save'");
                                for ($i = 1; $i < $argc; $i++)
                                        if (isset($cfg["Servers"][1][$argv[$i]]))
                                                echo $argv[$i] . "=\"" . $cfg["Servers"][1][$argv[$i]] . "\"\n";
                        } catch (Exception $e) {}' -- "$@" 2>/dev/null || true
}

pma__set_default_values()
{
	controluser="pma"
#	controlpass=""

	pmadb="phpmyadmin"
	####
	# WARNING:
	# If you will modify the values you have to add templates (@@PMA_BOOKMARK@@, etc.)
	# in create_tables.sql and create_tables_mysql_4_1_2+.sql.
	####
	bookmarktable="pma_bookmark"
	column_info="pma_column_info"
	history="pma_history"
	pdf_pages="pma_pdf_pages"
	relation="pma_relation"
	table_coords="pma_table_coords"
	table_info="pma_table_info"
	designer_coords="pma_designer_coords"
	tracking="pma_tracking"
	userconfig="pma_userconfig"
}

pma__set_random_values()
{
	local pma__random_suffix

	# generate random controluser and pmadb
	while true; do
		pma__random_suffix=`get_random_string 12`
		controluser="pma_$pma__random_suffix" # maximum length is 16 characters
		pmadb="phpmyadmin_$pma__random_suffix"
		# check controluser existance
		# if user already exists then continue
		! db_test "SELECT COUNT(*) FROM mysql.user WHERE User='$controluser' LIMIT 1;" '$1!="0"' || continue
		# check pmadb existance
		# if db already exists then continue
		! db_test_database "$pmadb" || continue
		break
	done
	# generate random controlpass
	controlpass=`get_random_string 16`
}

pma__create_pmadb()
{
	local create_tables_sql
	local inten
	inten="create pmadb"
	echo_try $inten
	create_tables_sql="$PHPMYADMIN_D/scripts/create_tables.sql"
	# create pmadb
	sed -e "`pma__sed_script`" < "$create_tables_sql" | mysql_direct >> "$product_log" 2>&1 || warn "$inten"
	suc
}

pma__sed_script()
{
	echo "	s/@@CONTROLUSER@@/$controluser/g
	s/@@CONTROLPASS@@/$controlpass/g
	s/@@PMADB@@/$pmadb/g
	s/@@PMA_BOOKMARK@@/$bookmarktable/g
	s/@@PMA_COLUMN_INFO@@/$column_info/g
	s/@@PMA_HISTORY@@/$history/g
	s/@@PMA_PDF_PAGES@@/$pdf_pages/g
	s/@@PMA_RELATION@@/$relation/g
	s/@@PMA_TABLE_COORDS@@/$table_coords/g
	s/@@PMA_TABLE_INFO@@/$table_info/g
	s/@@PMA_DESIGNER_COORDS@@/$designer_coords/g
	s/@@PMA_TRACKING@@/$tracking/g
	s/@@PMA_USERCONFIG@@/$userconfig/g	"
}

poppassd_super_server_config()
{
	local action="$1"

	if [ -f /proc/net/if_inet6 ]; then 
		FLAGS="flags                   = KEEPALIVE IPv6"
	else
		FLAGS="flags                   = KEEPALIVE"
	fi

	case "$superserver" in
	    inetd)
		poppassd_rec="poppassd stream tcp nowait/1000 root /usr/sbin/tcpd $PRODUCT_ROOT_D/admin/sbin/poppassd"
		;;	
	    xinetd)
		poppassd_rec="service poppassd
{
socket_type             = stream
protocol                = tcp
port                    = 106
wait                    = no
disable                 = no
user                    = root
instances               = 1000
$FLAGS
server                  = $PRODUCT_ROOT_D/admin/sbin/poppassd
}"
		;;
	    *)
		    die "Super server name unknown"
		;;
	esac

	super_server_action "$action" poppassd "$poppassd_rec"
}
set_pgsql_params()
{
    pgsql_user="postgres"
    pgsql_group="postgres"
    pgsql_user_old=`cat /etc/passwd | awk -F ':' '        BEGIN { p = 3 };        p > 1 && /^postgres/ { p = 1; s = $1 };        p > 2 && /^pgsql/    { p = 2; s = $1 };        END { print s }        '`

    start_script="postgresql"
    PGSQL_ROOT_D="/usr"
    PGSQL_DATA_D="/var/lib/pgsql/data"
    NEW_PGSQL_VERSION=""

    if [ -x "$PRODUCT_RC_D/$start_script" ]; then
	RC_SCRIPT="$PRODUCT_RC_D/$start_script"
    elif [ -x "$PRODUCT_RC_D/${start_script}.sh" ]; then
	RC_SCRIPT="$PRODUCT_RC_D/${start_script}.sh"
    else
	die "Unable to find postgresql startup script"
    fi

    PGSQL_BIN_D="$PGSQL_ROOT_D/bin"
    PGSQL_BACKUP_D="$PRODUCT_ROOT_D/tmp/postgresql.upgradedb"
}


# vim:syntax=sh

mail_restore_all()
{
	# temporary solution to close #143977 and #144076: three keys to turn on
	if [ ! -e "$PRODUCT_ROOT_D/version" -a ! -e "$PRODUCT_ROOT_D/core.version" ]; then
		p_echo "$PRODUCT_ROOT_D/version isn't yet on its place. Deferring mail_restore execution to a later stage" >&2
		return
	fi
	if [ ! -x "/usr/lib/plesk-9.0/mailsrv_entities_dump" ]; then
		p_echo "/usr/lib/plesk-9.0/mailsrv_entities_dump isn't yet on its place. Deferring mail_restore execution to a later stage" >&2
		return
	fi
	if [ ! -x "/usr/lib/plesk-9.0/mail_restore" ]; then
		p_echo "/usr/lib/plesk-9.0/mail_restore isn't yet on its place. Deferring mail_restore execution to a later stage" >&2
		return
	fi

	# FIXME: There's a possible race during upgrade procedure. Noone
	# managed to catch the bug in debug mode, so be stupid:
	sync; sync; sleep 3

	inten="executing mail_restore to synchronize mail server settings and Plesk Database"
	echo_try $inten
	/usr/lib/plesk-9.0/mail_restore --fast >>$product_log 2>&1
	suc
}

true exim_status_linux_debian
exim_status_linux_debian()
{
	get_pid /usr/lib/exim/exim3 false
	local pid=$common_var

	if test "$pid" -ne 1; then
		#running
		return 0;
	fi
	return 1
}

install_postfix_smtpd_sasl_config()
{
	local smtpd_sasl_conf smtpd_sasl_conf_bak sasl_sql_db_path saslauthd_path saslauthd_path_relative

	saslauthd_path_relative=/private/plesk_saslauthd

	sasl_sql_db_path=/var/spool/postfix/plesk/passwd.db
	saslauthd_path=/var/spool/postfix${saslauthd_path_relative}
	
	smtpd_sasl_conf='/etc/sasl2/smtpd.conf'

	if [ -f "$smtpd_sasl_conf" ]; then
	   smtpd_sasl_conf_bak="${smtpd_sasl_conf}.saved_by_plesk.`date +%s`"
	   rm -f "$smtpd_sasl_conf_bak" ||:
	   if ! ln "$smtpd_sasl_conf" "$smtpd_sasl_conf_bak" ; then
	      simply_die "unable to preserve $smtpd_sasl_conf to $smtpd_sasl_conf_bak"
	   fi
	fi
	mkdir -p "$(dirname $smtpd_sasl_conf)"
	cat >"$smtpd_sasl_conf" <<EOF
pwcheck_method: auxprop saslauthd
auxprop_plugin: sql_sqlite3
saslauthd_path: $saslauthd_path
mech_list: DIGEST-MD5 CRAM-MD5 PLAIN LOGIN
auto_transition: yes
sql_engine: sqlite3
sql_hostnames: localhost
sql_database: $sasl_sql_db_path
sql_select: SELECT \`%p\` FROM domains d, users u WHERE u.name='%u' and d.name='%r' and d.status=0 and u.status=0 and u.dom_id=d.id
sql_verbose: yes
log_level: 9
EOF
}

set_mail_params()
{
	HANDLERS_USER="mhandlers-user"
	MAIL_USERGROUP="popuser"
}
## vim:filetype=sh

upgrade_dk_86()
{
	$PRODUCT_ROOT_D/admin/sbin/mailmng --remove-handler --handler-name='dd51-domainkeys' --handler-type='global' --hook='before-remote' >> "$product_log" 2>&1
	$PRODUCT_ROOT_D/admin/sbin/mailmng --remove-handler --handler-name='dd52-domainkeys' --handler-type='global' --hook='before-local' >> "$product_log" 2>&1
	/usr/lib/plesk-9.0/mail_dk_restore
}

mail_poppasswd_long_names()
{
    if db_test "SELECT val FROM misc WHERE param = 'allow_short_pop3_names'" '/^disabled$/'; then
	"$PRODUCT_ROOT_D/admin/sbin/mailmng" --set-accounts-format --account-format="compound"
    fi
}
#qmail

set_qmail_params()
{
    QMAIL_DIR="/var/qmail"
    QMAIL_USERS="alias:2021:nofiles:false:alias  qmaild:2020:nofiles:false:  qmaill:2022:nofiles:false:  qmailp:2023:nofiles:false:  qmailq:2520:qmail:  qmailr:2521:qmail:  qmails:2522:qmail:"
    QMAIL_GROUPS="qmail:2520  nofiles:2020"

    #variable from psa.conf but used in mail-qc-driver
    #so we need define this before install psa base package
    if [ -z "$QMAIL_ROOT_D" ]; then 
	    QMAIL_ROOT_D="/var/qmail"
    fi

    mm_mailgroup=12

    qmail_service="qmail"
    qmail_extra_cmd=""
    qmail_log="/var/log/maillog"
}

## @@constructor set_qmail_params
qmail_super_server_config()
{
    local action="$1"
    local service="$2"
    qmail_xinetd_templates

    eval "template=\$${service}_rec"
    super_server_action "$action" "$service" "$template"
}

qmail_xinetd_templates()
{
    local TRUE_BIN
    TRUE_BIN=$QMAIL_DIR/bin/true

    if [ -f /proc/net/if_inet6 ]; then
	    V6_FLAGS="flags		= IPv6"
    else
	    V6_FLAGS=""
    fi

smtp_rec="service smtp
{
	socket_type     = stream
	protocol        = tcp
	wait            = no
	disable		= no
	user            = root
	$V6_FLAGS
	instances       = UNLIMITED
	env             = SMTPAUTH=1
	server          = $QMAIL_DIR/bin/tcp-env
	server_args     = -Rt0 $QMAIL_DIR/bin/relaylock $QMAIL_DIR/bin/qmail-smtpd $QMAIL_DIR/bin/smtp_auth $TRUE_BIN $QMAIL_DIR/bin/cmd5checkpw $TRUE_BIN
}" 

smtps_rec="service smtps
{
	socket_type     = stream
	protocol        = tcp
	wait            = no
	disable		= no
	user            = root
	$V6_FLAGS
	instances       = UNLIMITED
	env             = SMTPAUTH=1
	server          = $QMAIL_DIR/bin/tcp-env
	server_args     = -Rt0 $QMAIL_DIR/bin/relaylock $QMAIL_DIR/bin/qmail-smtpd $QMAIL_DIR/bin/smtp_auth $TRUE_BIN $QMAIL_DIR/bin/cmd5checkpw $TRUE_BIN
}" 

submission_rec="service submission
{
	socket_type     = stream
	protocol        = tcp
	wait            = no
	disable		= no
	user            = qmaild
	$V6_FLAGS
	instances       = UNLIMITED
	env             = SUBMISSION=1 SMTPAUTH=1
	server          = $QMAIL_DIR/bin/tcp-env
	server_args     = -Rt0 $QMAIL_DIR/bin/qmail-smtpd $QMAIL_DIR/bin/smtp_auth $TRUE_BIN $QMAIL_DIR/bin/cmd5checkpw $TRUE_BIN
}" 

}

upgrade_qmail_80()
{
	set_mail_params
	ch_user_home $MAIL_USERGROUP "$QMAIL_DIR/$MAIL_USERGROUP"
	qmail_fix_domain_disabling_80
}

qmail_fix_domain_disabling_80()
{
	[ -e "$QMAIL_ROOT_D/users/poppasswd" ] || return 0

	echo_try "fix domains disabling"
	perl -e '
		use File::stat;

		$poppasswd_path = shift;

		%disabled_domains = ();

		$popuser_uid = getpwnam("popuser");
		$popuser_gid = getgrnam("popuser");

		open(POPPASSWD_IN, "<", $poppasswd_path) or die("Cannot read poppasswd: $!");
		open(POPPASSWD_OUT, ">", $poppasswd_path . ".new")
		and chmod(0600, $poppasswd_path . ".new")
		or die("Cannot write poppasswd: $!");

		sub out ($) {
			my $str = shift;
			print POPPASSWD_OUT $str or die("Cannot write poppasswd: $!");
		}

		while(<POPPASSWD_IN>) {
			if (/^([^:]*):(\$[^:]*):popuser:([^:]+)(\/[^:\/]+$)/) {
				my $dir = $3;
				if (exists $disabled_domains{$dir}) {
					out $1 . ":!" . $2 . ":popuser:" . $3 . $4;
				} elsif ((stat($dir)->mode & 0777) == 0) {
					chmod(0700, $dir);
					chown($popuser_uid, $popuser_gid, $dir);
					$disabled_domains{$dir} = 1;
					out $1 . ":!" . $2 . ":popuser:" . $3 . $4;
				} else {
					out $_;
				}
			} else {
				out $_;
			}
		}

		close($poppasswd_path . ".new");
		rename ($poppasswd_path . ".new", $poppasswd_path) or die("Cannot replace poppasswd: $!");

	' "$QMAIL_ROOT_D/users/poppasswd" >>"$product_log" 2>&1 	|| {
		rm -f "$QMAIL_ROOT_D/users/poppasswd.new"
		report_problem "fix domains disabling"
	}

	suc
}


rsr_backup()
{
	target="$1"
	dup="$2"
	opts="$3"
	common_var=0

#	if [ -$opts "$target" ]; then
		if [ -$opts "$target.$product_suff" ]; then
			case "$dup" in
				mv)
					mv -f  $target.$product_suff $target>> $product_log 2>&1
					common_var=1
					return 1
					;;
				cp)
					cp -fp  $target.$product_suff $target>> $product_log 2>&1
					common_var=1
					return 1
					;;
				*)
					p_echo " rsr_backup: wrong option -- must be 'cp' or 'mv'"
					;;
			esac
		else
			if [ -$opts "$target.$product_suffo" ]; then
			    case "$dup" in
				mv)
					mv -f  $target.$product_suffo $target>> $product_log 2>&1
					common_var=1
					return 1
					;;
				cp)
					cp -fp  $target.$product_suffo $target>> $product_log 2>&1
					common_var=1
					return 1
					;;
				*)
					p_echo " rsr_backup: wrong option -- must be 'cp' or 'mv'"
					;;
			    esac
			fi
		fi
#	else
#		case "$opts" in
#			f|d)
#				;;
#			*)
#				p_echo " rsr_backup: wrong option -- must be 'f' or 'd'"
#				;;
#		esac
#	fi
}

restore_named()
{
	cd "$PRODUCT_ROOT_D" >> $product_log 2>&1
	[ -f /etc/sysconfig/named ] && mv -f "/etc/sysconfig/named" "/etc/sysconfig/named.bak"
	rsr_backup "/etc/sysconfig/named" mv f

	[ -L $named_conf ] && rm -f "$named_conf"
	rsr_backup "$named_conf" mv f

	[ -L $rndc_conf ] && rm -f "$rndc_conf"
	rsr_backup "$rndc_conf" mv f

	case "$machine" in
		BSD*)
			rsr_backup /etc/named.boot mv f
			;;
		linux)
		    case "$linux_distr" in
			redhat)
			    chkconfig --add named >> $product_log 2>&1
#			    std_named_sh="/etc/rc.d/init.d/named"
#			    rsr_backup $std_named_sh mv f
#				if [ -f "$std_named_sh" ]; then
#					mv -f "$std_named_sh.${product}" "$std_named_sh"
#				fi
				;;
			slackware)
			    rsr_backup /etc/rc.d/rc.inet2 cp f
				;;
		    esac
			rsr_backup /etc/named.boot mv f
			;;
		solaris)
			rsr_backup /etc/named.boot mv f
			;;
	esac
}


restore_sendmail()
{
	[ -L $sendmail ] && rm -f "$sendmail"
	[ -L /usr/lib/sendmail ] && rm -f "/usr/lib/sendmail"

	rsr_backup "$sendmail" mv f

	case "$machine" in
		BSDI)
			rsr_backup /etc/sendmail.cf mv f
			;;
		*)
			;;
	esac

	if [ -f "$mail_local" ]; then
#		case "$machine" in
#			BSD)
#				chflags schg "$mail_local" >> $product_log 2>&1
#				;;
#			*)
#				;;
#		esac

		rsr_backup "$mail_local" mv f

		chmod 4555 "$mail_local" >> $product_log 2>&1
	fi
	case "$machine" in
		linux )
		    case "$linux_distr" in
			redhat)
			    chkconfig --add sendmail >> $product_log 2>&1
#			    rsr_backup "$sndml_ini" mv f
				;;
			slackware)
			     rsr_backup /etc/rc.d/rc.M mv f
				;;
		    esac
			;;
		solaris)
			rsr_backup "$sndml_ini" mv f
			;;
		*)
			;;
	esac

}

delete_startup_scripts()
{
	cd "$PRODUCT_ROOT_D" >> $product_log 2>&1

	case "$machine" in
		BSD)
			rm -f /usr/local/etc/rc.d/${product}.sh >> $product_log 2>&1
	#		rsr_backup /etc/rc.conf cp f

			rc_service "sendmail" "enable" "YES"
			rc_service "named" "enable" "YES"
			rc_service "mysqld" "enable" "NO"
			;;
		BSDI)
			if [ -f /etc/rc.local.${product} ]; then
				cp -p  /etc/rc.local.${product} /etc/rc.local >> $product_log 2>&1
			fi
			;;
		linux)
		    case "$linux_distr" in
			redhat)
			    chkconfig --del ${product}
			    rm -f /etc/rc.d/init.d/${product} >> $product_log 2>&1
#			    rm -f /etc/rc.d/rc0.d/K15${product} >> $product_log 2>&1
#			    rm -f /etc/rc.d/rc1.d/K15${product} >> $product_log 2>&1
#			    rm -f /etc/rc.d/rc2.d/K15${product} >> $product_log 2>&1
#			    rm -f /etc/rc.d/rc3.d/S77${product} >> $product_log 2>&1
#			    rm -f /etc/rc.d/rc4.d/S77${product} >> $product_log 2>&1
#			    rm -f /etc/rc.d/rc5.d/S77${product} >> $product_log 2>&1
#			    rm -f /etc/rc.d/rc6.d/K15${product} >> $product_log 2>&1
				;;
			slackware)
			    if [ -f /etc/rc.d/rc.local.${product} ]; then
				cp -p  /etc/rc.d/rc.local.${product} /etc/rc.d/rc.local >> $product_log 2>&1
			    fi
				;;
		    esac
		    ;;
		solaris)
			rm -f  /etc/init.d/${product} >> $product_log 2>&1
			if [ -f /etc/rc0.d/K01${product} ]; then
				rm -f /etc/rc0.d/K01${product} >> $product_log 2>&1
			fi

			if [ -f /etc/rc1.d/K01${product} ]; then
				rm -f /etc/rc1.d/K01${product} >> $product_log 2>&1
			fi

			if [ -f /etc/rc2.d/S77${product} ]; then
				rm -f /etc/rc2.d/S77${product} >> $product_log 2>&1
			fi
			;;
	esac
}

delete_crontab()
{

	$crontab -l 2>/dev/null > /tmp/crontab.${product}

	sed -e "s/^.*\/${product}\/admin\/sbin\/statistics.*//g" 		-e "s/^.*\/${product}\/bin\/mysqldump.*//g" 		-e "s/^.*\/usr\/sbin\/ntpdate.*//g" 		< /tmp/crontab.${product} > /tmp/crontab.${product}_tmp

	mv -f /tmp/crontab.${product}_tmp /tmp/crontab.${product} >> $product_log 2>&1

	$crontab /tmp/crontab.${product}  >> $product_log 2>&1

	rm -f /tmp/crontab.${product} >> $product_log 2>&1

}

remove_ftpuser()
{
	user=$1
	ftpusers_file="/etc/ftpusers"

	egrep "^$user" $ftpusers_file >> /dev/null 2>&1

	case "$?" in
			0)
				sed -e "/$user/d" < $ftpusers_file > $ftpusers_file.tmp
				mv -f $ftpusers_file.tmp $ftpusers_file
				;;
			1)
				;;
			*)
				;;
	esac

}

remove_product_users_groups()
{

#	delete users of this(unsuccessful) installation
	for i in $users_created; do
		delete_user "$i"
	done
#	delete users with group=psacln (ftpusers and webusers)
	for i in `perl -e '$gid=getgrnam("'$clients_group'"); exit if (($gid eq "") || ($gid == 0)); while(($n,$u,$g) = (getpwent)[0,2,3]) {print "$n\n" if (($gid == $g) && ($u >= 500))}'`
	do
		delete_user "$i"
		remove_ftpuser "$i"
	done
#	delete users psaadm, psaftp
#	delete_user "$admin_user"  >> "$product_log" 2>&1
#	delete_user "$anonftp_user"  >> "$product_log" 2>&1

#	delete groups of this(unsuccessful) installation
	for i in $groups_created; do
		delete_group "$i"
	done
#	delete groups psaadm, psaftp, psacln
	delete_group "$admin_group"  >> "$product_log" 2>&1
	delete_group "$anonftp_group"  >> "$product_log" 2>&1
	delete_group "$clients_group"  >> "$product_log" 2>&1

}


undo_install()
{
	p_echo

	if pleskrc mysql status; then
		p_echo "===>Removing installed $PRODUCT_NAME components ... "
		remove_modules
		pleskrc mysql stop

		mysql_pid_file=$mysql_bddir/*.pid
		if [ -f "$mysql_pid_file" ]; then
			rm -f "$mysql_pid_file"
		fi
	fi

	$START_SH stop >> "$product_log" 2>&1

	proftpd_super_server_config remove

	super_server_action remove pop3
	super_server_action remove pop-3
	super_server_action remove imap4
	super_server_action remove imap2
	super_server_action remove imap
	qmail_super_server_config remove smtp
	qmail_super_server_config remove smtps
	qmail_super_server_config remove submission
	poppassd_super_server_config remove

	remove_product_users_groups

	if [ -f "/etc/ftpchroot" ]; then
	    sed -e "s/^@$clients_group//g" < /etc/ftpchroot > /etc/ftpchroot.tmp
	    mv -f /etc/ftpchroot.tmp /etc/ftpchroot  >> $product_log 2>&1
	fi

	if [ -f /etc/shells ]; then
	    case "$machine" in
		BSD|BSDI)
		    sed -e "s/[/]*sbin[/]*nologin//" < /etc/shells > /etc/shells.tmp
		;;
		linux|solaris)
		    sed -e "s/[/]*bin[/]*false//" < /etc/shells > /etc/shells.tmp
		;;
	    esac
	    mv -f /etc/shells.tmp /etc/shells  >> $product_log 2>&1
	fi

	remove_tmp_state

	restore_named
	restore_sendmail
	delete_startup_scripts
	delete_crontab

	cd /usr/local  >> $product_log 2>&1

	suc
}

smart_undo_install()
{
	[ "X$trigger_uninstall" = "X1" -o "X$do_patch" = "X1" -o "X$do_reconfigure" = "X1" ] && return
	[ "X$PLESK_INSTALLER_NOUNDO" != "X" ] && return
	# trigger_uninstall - trigger what smart_undo_install is already working now(recurrence)
	trigger_uninstall=1

	if [ "X$can_uninstall" = "X1" ]; then
		if [ "X$do_upgrade" = "X1" ]; then
			undo_upgrade
		else
		    if [ "X$machine" != "XBSD" ]; then
			undo_install
		    fi
		fi
	fi

	# put suggestions for user what to do
	call_optional_function failure_note
}


prepare_upgrader()
{

    INSTALLED_VERSION=`form_undotted_version ${prev_version}`

    PRODKEY_CHANGED=0

    echo "===> Preparing upgrade"

    db_backup

    save_old_key_id

	get_old_domain

	db_added_columns=''

	stop_before_upgrade

	phpmyadmin_config_backup
}

save_old_key_id()
{
    if test "$INSTALLED_VERSION" -le 70; then
		awk 'NR == 3 { print; }' $PRODUCT_ROOT_D/admin/conf/settings >$PRODUCT_ROOT_D/tmp/old_key_id
	else
		# it must be already registered
		rm -f $PRODUCT_ROOT_D/tmp/old_key_id
	fi
}

db_backup()
{
	local timestamp
	timestamp=`date +%Y%m%d-%H%M%S`
	dfile="$DUMP_D/mysql.preupgrade.${prev_version}-${product_version}.${timestamp}.dump.gz"

	if test -f $dfile; then
		# dump names should not collide, but better be safe than sorry
		local i
		i=1
		while test -f "$dfile.$i"; do
			i=$(($i+1))
		done
		mv -v "$dfile" "$dfile.$i" >> "$product_log" || die "save previous backup $dfile"
	fi

	inten="backup MySQL database"
	echo_try "$inten"
	if ! test -d "$DUMP_D"; then
		mkdir -p "$DUMP_D"
	fi
	touch "$dfile" || die "$inten"
	chown 0:0 "$dfile" || die "$inten"
	chmod 600 "$dfile" || die "$inten"
	dump_db "$PRODNAME" horde mysql | gzip > "$dfile" || die "$inten"
	suc
	p_echo " MySQL databases are dumped to $dfile"
}
safe_prep_db_upgrade()
{
	p_echo
	p_echo "===> Upgrading database"
	p_echo

	mysql_unconfigured=
	set_mysqld_params
	check_db

	# backup database and register rollback action
	db_backup
	SAFE_PREP_DB_BACKUP="$dfile"
	transaction_add_rollback_action "safe_prep_db_upgrade_rollback"

	run_db_upgrade_functions
}

safe_prep_db_upgrade_rollback()
{
	if [ -n "$SAFE_PREP_DB_BACKUP" ]; then
		p_echo
		p_echo "===> Restoring database from backup $SAFE_PREP_DB_BACKUP"
		p_echo
		zcat "$SAFE_PREP_DB_BACKUP" | mysql_anydb
		if [ $? -ne 0 ]; then
			p_echo
			p_echo "    [ERROR] Database restoring failed"
			p_echo "    Try to restore database from $SAFE_PREP_DB_BACKUP manually"
			p_echo
			return
		fi
		SAFE_PREP_DB_BACKUP=
	fi
}

safe_prep_db_install()
{
	mysql_unconfigured=1
	set_default_locale
	mysql_install_init
	insert_fullhostname
}

safe_prep_db()
{

	p_echo
	p_echo "===> Performing safe prep-install database actions"
	p_echo

	# perform database-related prep actions
	if [ "$do_upgrade" -ne 0 ]; then
		safe_prep_db_upgrade
	else
		safe_prep_db_install
	fi
}

transaction_begin()
{
	[ -n "$TRANSACTION_STARTED" ] && die "Another transaction in progress!"
	TRANSACTION_STARTED="true"
	TRANSACTION_ROLLBACK_FUNCS=
	TRANSACTION_COMMIT_FUNCS=
	trap "transaction_rollback" HUP PIPE INT QUIT TERM EXIT
}

transaction_rollback()
{
	[ -z "$TRANSACTION_STARTED" ] && die "Transaction is not started!"
	# perform rollback actions
	local f
	for f in ${TRANSACTION_ROLLBACK_FUNCS}; do
		"$f"
	done
	TRANSACTION_STARTED=
	TRANSACTION_ROLLBACK_FUNCS=
	TRANSACTION_COMMIT_FUNCS=
	trap - HUP PIPE INT QUIT TERM EXIT
	exit 1
}

transaction_commit()
{
	[ -z "$TRANSACTION_STARTED" ] && die "Transaction is not started!"
	# perform commit actions
	local f
	for f in ${TRANSACTION_COMMIT_FUNCS}; do
		"$f"
	done
	TRANSACTION_STARTED=
	TRANSACTION_ROLLBACK_FUNCS=
	TRANSACTION_COMMIT_FUNCS=
	trap - HUP PIPE INT QUIT TERM EXIT
}

transaction_add_rollback_action()
{
	[ -z "$TRANSACTION_STARTED" ] && die "Transaction is not started!"
	# LIFO rollback order
	[ -z "$TRANSACTION_ROLLBACK_FUNCS" ] 		&& TRANSACTION_ROLLBACK_FUNCS="$1" 		|| TRANSACTION_ROLLBACK_FUNCS="$1 $TRANSACTION_ROLLBACK_FUNCS"
}

transaction_add_commit_action()
{
	[ -z "$TRANSACTION_STARTED" ] && die "Transaction is not started!"
	# FIFO commit order
	[ -z "$TRANSACTION_COMMIT_FUNCS" ] 		&& TRANSACTION_COMMIT_FUNCS="$1" 		|| TRANSACTION_COMMIT_FUNCS="$TRANSACTION_COMMIT_FUNCS $1"
}
undo_upgrade()
{
	p_echo   "    The attempt to upgrade $prev_product_full"
	p_echo   "    from version $prev_version to $product_full $product_version has failed."

	if [ -f "$product_sav_tar" ]; then
	
		p_echo 

		p_echo "    Now restore contents of $PRODUCT_NAME from $product_sav_tar"
		p_echo 
		get_pid $PRODUCT_ROOT_D/mysql/bin/safe_mysqld true root
		req_pid=$common_var
		if [ $req_pid -gt 1 ]; then
			$K_KILL $req_pid >> $product_log 2>&1 
			sleep 2
			mysql_pid_file=$mysql_bddir/*.pid
			kill_pids $PRODUCT_ROOT_D/mysql/libexec/mysqld mysql
			sleep 2
			if [ -f "$mysql_pid_file" ]; then
				rm -f $mysql_pid_file
			fi
		fi

		$START_SH stop >> $product_log 2>&1
		sleep 2

		rm -Rf $PRODUCT_ROOT_D
		qmail_super_server_config remove "smtp"
		qmail_super_server_config remove "smtps"
		proftpd_super_server_config remove
		poppassd_super_server_config remove
		

		cd /
        	tar xvf $product_sav_tar > /dev/null 2>&1
		case "$?" in
			0)
#				rm -f $product_sav_tar 		
			;;
			*)
				p_echo 
				p_echo 
				p_echo "ERROR: restoration of files from $product_sav_tar has failed."
				p_echo "       Please restore them manually."
				p_echo 
				p_echo "Exiting..."
				p_echo 
				exit 0
			;;
		esac
	fi
	
}

# For now we left QMail upgrading procedures from ancient Plesks here.
# Starting from Plesk-9.0 all MTA-related upgrading procedures should be
# placed into *ON-DISK* scripts which *MUST* belong to the corresponding
# mail-driver

#----------------------- Upgrade functions list constructors --------------------
#@@db_upgrade
DB_UPGRADE_FUNCTIONS_80()
{
	db_fix_bf1492_column_types_80
	db_fix_set_dns_recursion

	# 8.0 -> 8.1
	upgrade_db_80
}

UPGRADE_FUNCTIONS_80()
{
	db_fix_bf1492_column_types_80
	db_fix_set_dns_recursion
	upgrade_proftpd_754

	# 8.0 -> 8.1
	upgrade_db_80
	mail_poppasswd_long_names
	remove_cron_somely_80
	upgrade_qmail_80
}
## @@upgraders UPGRADE_FUNCTIONS_80

#@@db_upgrade
DB_UPGRADE_FUNCTIONS_81()
{
	db_fix_81
	# 8.1 -> 8.2
	upgrade_db_81
}

UPGRADE_FUNCTIONS_81()
{
	fix_crontab_810
	db_fix_81
	# 8.1 -> 8.2
	upgrade_db_81
}
## @@upgraders UPGRADE_FUNCTIONS_81

#@@db_upgrade
DB_UPGRADE_FUNCTIONS_82()
{
	db_fix_82
	#upgrade 8.2 -> 8.3
	upgrade_db_82
}

UPGRADE_FUNCTIONS_82()
{
	upgrade_proftpd_820
	db_fix_82
	#upgrade 8.2 -> 8.3
	upgrade_awstats_82
	upgrade_db_82
}
## @@upgraders UPGRADE_FUNCTIONS_82

#@@db_upgrade
DB_UPGRADE_FUNCTIONS_83()
{
	db_fix_83
}

UPGRADE_FUNCTIONS_83()
{
	upgrade_cf_83
	db_fix_83
	pbm_create_certificate
}
## @@upgraders UPGRADE_FUNCTIONS_83

#@@db_upgrade
DB_UPGRADE_FUNCTIONS_84()
{
	db_fix_84
}

UPGRADE_FUNCTIONS_84()
{
	db_fix_84
	upgrade_awstats_84
}
## @@upgraders UPGRADE_FUNCTIONS_84

#@@db_upgrade
DB_UPGRADE_FUNCTIONS_86()
{
	db_fix_86
}

UPGRADE_FUNCTIONS_86()
{
	key_upgrade_86
	db_fix_86
	db_update_notifications

	set_mail_params
	upgrade_dk_86
	upgrade_mailman_86

	set_horde_webmail
}
## @@upgraders UPGRADE_FUNCTIONS_86

#@@db_upgrade
DB_UPGRADE_FUNCTIONS_90()
{
	db_pmm_dashboard_90
	db_fix_90
}

UPGRADE_FUNCTIONS_90()
{
	db_pmm_dashboard_90
	db_fix_90
}
## @@upgraders UPGRADE_FUNCTIONS_90

#@@db_upgrade
DB_UPGRADE_FUNCTIONS_92()
{
	add_db_changes 920
}

UPGRADE_FUNCTIONS_92()
{
	add_db_changes 920
	upgrade_mailman_86
}
## @@upgraders UPGRADE_FUNCTIONS_92

#@@db_upgrade
DB_UPGRADE_FUNCTIONS_95()
{
	db_update_exp_event
}

UPGRADE_FUNCTIONS_95()
{
    db_update_dashboard_951

	db_update_exp_event
}
# #@@upgraders UPGRADE_FUNCTIONS_95

#@@db_upgrade
DB_UPGRADE_FUNCTIONS_107()
{
	add_db_changes 1070
	db_update_sessions_107
	db_add_ftp_sys_users
#	db_add_plans
	db_add_plans_schema
	db_add_webspaces
	db_add_domain_permissions
	db_billing_integration_107
	db_migrate_sa_prefs_107
	db_upgrade_hp_mail_107
	db_default_skin_107
}

UPGRADE_FUNCTIONS_107()
{
	add_db_changes 1070
	db_add_ftp_sys_users
	db_add_plans_schema
	db_add_plans_data
	db_add_webspaces
	db_add_domain_permissions
	db_migrate_sb_data_107
	db_default_skin_107
	db_unlimited_client_expiration_107
	db_clean_up_ip_pool_107
	db_billing_integration_107
	db_migrate_sa_prefs_107
	db_upgrade_hp_mail_107
	db_generate_guids_82
	db_create_default_templates
	db_update_plesk10
	set_swkey_params
	key_upgrade_cmd
}
## @@upgraders UPGRADE_FUNCTIONS_107

#@@db_upgrade
DB_UPGRADE_FUNCTIONS_108()
{
	db_change_domain_admins_length_108
	db_subscription_limits_default_values_108 'max_site_builder' -1
	db_subscription_limits_default_values_108 'max_unity_mobile_sites' -1
}

UPGRADE_FUNCTIONS_108()
{
	db_change_domain_admins_length_108
	db_subscription_limits_default_values_108 'max_site_builder' -1
	db_subscription_limits_default_values_108 'max_unity_mobile_sites' -1
	upgrade_postfix_enforce_tls_108
	upgrade_postfix_chroot_108
}
## @@upgraders UPGRADE_FUNCTIONS_108

#@@db_upgrade
DB_UPGRADE_FUNCTIONS_109()
{
	add_db_changes 1090
	db_upgrade_clients_idn_109
	db_upgrade_custom_buttons_109
	db_upgrade_maintenance_mode_109
}

UPGRADE_FUNCTIONS_109()
{
	add_db_changes 1090
	db_upgrade_clients_idn_109
	fix_crontab_109
	db_upgrade_subscriptions_109
	db_upgrade_custom_buttons_109
	db_upgrade_maintenance_mode_109
	upgrade_vhosts_109
}
## @@upgraders UPGRADE_FUNCTIONS_109

#@@db_upgrade
DB_UPGRADE_FUNCTIONS_1010()
{
    api_rpc_create_persistent_tables
    api_rpc_upgrade_persistent_tables
    add_db_changes 10100
    db_upgrade_ip_addresses_1010
    db_upgrade_dns_recs_t_1010
    db_upgrade_domain_services_1010
    db_upgrade_hosting_1010
    db_upgrade_subdomains_1010
	db_upgrade_sso_port_1010
    db_optimize_configurations_table_1010
	db_cleanup_exp_event_1010
}

UPGRADE_FUNCTIONS_1010()
{
    api_rpc_create_persistent_tables
    api_rpc_upgrade_persistent_tables
    add_db_changes 10100
    db_upgrade_ip_addresses_1010
    fix_ip_addresses_1010
    db_upgrade_dns_recs_t_1010
    db_upgrade_domain_services_1010 
    db_upgrade_web_domain_services_1010
    db_upgrade_hosting_1010
    db_upgrade_subdomains_1010
	db_upgrade_sso_port_1010
    db_optimize_configurations_table_1010
	db_cleanup_exp_event_1010
}
## @@upgraders UPGRADE_FUNCTIONS_1010

#@@db_upgrade
DB_UPGRADE_FUNCTIONS_1011()
{
    add_db_changes 10110
	migrate_backup_management_db_into_core_1011
	migrate_pmm_management_db_into_core_1011
	db_upgrade_backups_scheduled_1011
	db_upgrade_exp_event_obj_class_1011
	db_upgrade_ssobranding_port_1011
}

UPGRADE_FUNCTIONS_1011()
{
    add_db_changes 10110
	migrate_backup_management_db_into_core_1011
	migrate_pmm_management_db_into_core_1011
	db_upgrade_backups_scheduled_1011
	db_upgrade_exp_event_obj_class_1011
	db_upgrade_ssobranding_port_1011
	create_php_ini_1011
	apsc_import_data_1011
    db_upgrade_filesharing_1011
}
## @@upgraders UPGRADE_FUNCTIONS_1011

#@@db_upgrade
DB_UPGRADE_FUNCTIONS_1012()
{
    add_db_changes 10120
    db_upgrade_parent_domain_id_1012
    db_upgrade_service_nodes_1012
    db_upgrade_resp_attach_1012
	db_upgrade_dns_reverse_ptr_ipv6_1012
	db_upgrade_upgrade_history_1012
}

UPGRADE_FUNCTIONS_1012()
{
    add_db_changes 10120
    db_upgrade_parent_domain_id_1012
    db_upgrade_service_nodes_1012
    db_upgrade_dns_1012
    db_upgrade_resp_attach_1012
	db_upgrade_dns_reverse_ptr_ipv6_1012
    db_upgrade_subdomains_1012
	db_upgrade_permissions_1012
	db_upgrade_add_simple_plan_1012
	upgrade_postfix_1012
	upgrade_mailname_domain_dirs_perms_1012
	db_upgrade_php_settings_1012
	db_upgrade_mail_domain_services_1012
# moved from 107 because of the BL dependency (#80977)
	upgrade_proftpd_107
	db_upgrade_dns_wwwprefix_1012
	db_upgrade_upgrade_history_1012
	[ !  -x "@@PLESK_LIBEXEC_DIR@@/handlers-tmpfs" ] || @@PLESK_LIBEXEC_DIR@@/handlers-tmpfs stop
}
## @@upgraders UPGRADE_FUNCTIONS_1012

# DO NOT RUN BEFORE UPGRADE!!!
cumulative_upgrade()
{
	# line to prevent upgrade functions from being optimized out
	true UPGRADE_FUNCTIONS_80 UPGRADE_FUNCTIONS_81 UPGRADE_FUNCTIONS_82 UPGRADE_FUNCTIONS_83 UPGRADE_FUNCTIONS_84 UPGRADE_FUNCTIONS_86 UPGRADE_FUNCTIONS_90 UPGRADE_FUNCTIONS_92 UPGRADE_FUNCTIONS_95 UPGRADE_FUNCTIONS_107 UPGRADE_FUNCTIONS_108 UPGRADE_FUNCTIONS_109 UPGRADE_FUNCTIONS_1010 UPGRADE_FUNCTIONS_1011 UPGRADE_FUNCTIONS_1012 

	echo "===> Cumulative upgrade has been started"
	if run_upgrade_functions "UPGRADE_FUNCTIONS" "`form_undotted_version ${prev_version}`"; then
		echo "===> Upgrade completed."
	else
		echo "===> Your version does not require any upgrade."
	fi

	if [ "X$PLESK_IDEMPOTENCY_CHECK" = "XYes" ]; then
		die "We die to reconfigure psa package again and check that upgrader has an idempotency property"
	fi

	set_db_version
}

run_db_upgrade_functions()
{
	# line to prevent upgrade functions from being optimized out
	true DB_UPGRADE_FUNCTIONS_80 DB_UPGRADE_FUNCTIONS_81 DB_UPGRADE_FUNCTIONS_82 DB_UPGRADE_FUNCTIONS_83 DB_UPGRADE_FUNCTIONS_84 DB_UPGRADE_FUNCTIONS_86 DB_UPGRADE_FUNCTIONS_90 DB_UPGRADE_FUNCTIONS_92 DB_UPGRADE_FUNCTIONS_95 DB_UPGRADE_FUNCTIONS_107 DB_UPGRADE_FUNCTIONS_108 DB_UPGRADE_FUNCTIONS_109 DB_UPGRADE_FUNCTIONS_1010 DB_UPGRADE_FUNCTIONS_1011 DB_UPGRADE_FUNCTIONS_1012 

	echo "===> Cumulative database upgrade has been started"
	if run_upgrade_functions "DB_UPGRADE_FUNCTIONS" "$prev_db_short_version"; then
		echo "===> Upgrade completed."
	else
		echo "===> Your version does not require any upgrade."
	fi

	set_db_version
}

run_upgrade_functions()
{
	local FUNC_PREFIX="$1"
	local INSTALLED_VERSION="$2"

	# Flag for skipping already upgraded versions
	local UPGRADE_STARTED="0"

	for i in ${known_product_versions}; do

		if [ "X${UPGRADE_STARTED}" = "X0" -a ${INSTALLED_VERSION} -lt ${i} ]; then
			echo "    Your version is too old and not supported by this upgrader."
			exit 1;
		fi

		if [ "X${INSTALLED_VERSION}" = "X${i}" ]; then
			UPGRADE_STARTED="1"
		fi

		if [ "X${UPGRADE_STARTED}" = "X1" ] && is_function "${FUNC_PREFIX}_${i}"; then
			echo "===> Perform upgrade to ${i}" >> $product_log
			"${FUNC_PREFIX}_${i}"
		else
			echo "no upgrade for ${i}" >> $product_log
		fi

	done;

	if [ "X${UPGRADE_STARTED}" = "X1" ]; then
		return 0
	else
		return 1
	fi
}

#vhosts

install_vhosts()
{
	set_common_params
	read_conf

	inten="create Virtual Hosts directory"
# Paranoia
	echo_try $inten
	mkdir -p "$HTTPD_VHOSTS_D/default"
	mkdir -p "$HTTPD_VHOSTS_D/.skel"
	suc

	inten="sync default virtual host"
	echo_try $inten

	rsync -rlptgoD --ignore-existing /usr/share/plesk-vhost/ $HTTPD_VHOSTS_D/default/
	suc
# Dir check for awoid overwrite in future
	if [ ! -d "$HTTPD_VHOSTS_D/.skel/0" ]; then
		$PRODUCT_ROOT_D/admin/sbin/skelmng --install-default --id 0 >> "$product_log" 2>&1
	fi
}

chown_webstat()
{
	# select only domains with hosting
	query="select d.id from domains d, hosting h where d.id=h.dom_id";

	for dom_id in `echo $query | $mysql`; do

		query1="select s.login from sys_users s, hosting h where s.id=h.sys_user_id and h.dom_id='$dom_id'";
		login=`echo $query1 | $mysql`;

		query1="select name from domains where id='$dom_id'";
		dom_name=`echo $query1 | $mysql`;

		if [ -d "$HTTPD_VHOSTS_D/$dom_name/httpdocs/webstat" ]; then
#			chown $login:$clients_group `get_ls full "$HTTPD_VHOSTS_D/$dom_name/httpdocs/webstat"`
			find "$HTTPD_VHOSTS_D/$dom_name/httpdocs/webstat" -exec chown $login:$clients_group {} \;
		fi

	done >> "$product_log" 2>&1
}

vhosts_install_error_doc()
{
	local document dir file default_skeleton wrkdir sample_doc sample_file
	sample_doc="not_found.html"
	document="$1"
	default_skeleton="$PRODUCT_ROOT_D/tmp/default_skeleton.tgz"

	echo_try " Installing error document $document"

	wrkdir=`mktemp -d /tmp/skelXXXXXXXX`
	if test $? -ne 0; then
		p_echo " $wrkdir"
		die "create temporary directory";
	fi
	$tar xzf "$default_skeleton" -C "$wrkdir" "./error_docs/$document" >>"$product_log" 2>&1 	|| die "extract $document from default skeleton"

	find "$HTTPD_VHOSTS_D/.skel" "$HTTPD_VHOSTS_D" 			-maxdepth 2 -type d -name error_docs 	| while read dir; do
		file="$dir/$document"
		sample_file="$dir/$sample_doc"
		if ! test -e "$file"; then
			local doc_owner doc_group doc_perms
			doc_owner=0
			doc_group=0
			doc_perms=644
			if test -e "$sample_file"; then
				doc_owner=`stat -c %u "$sample_file"`
				doc_group=`stat -c %g "$sample_file"`
				doc_perms=`stat -c %a "$sample_file"`
			else
				warn "Unable to determine correct owner, group and access rights for $file. Please check them manually"
			fi
			install -o $doc_owner -g $doc_group -m $doc_perms "$wrkdir/error_docs/$document" "$file" >>"$product_log" 2>&1 			|| die "install document $document in $dir"

			domain_name=`echo "$dir" | awk -F/ '{ print $(NF-1) }'`
			sed -i -e "s/@domain_name@/$domain_name/g" "$file"
		fi
	done
	if test $? -ne 0; then exit 1; fi

	rm -rf "$wrkdir" >> "$product_log" 2>&1

	suc
}
upgrade_vhosts_109()
{
	vhosts_install_error_doc maintenance.html
}


#webalizer

set_webalizer_params()
{
	WEBALIZER_ROOT_D="$PRODUCT_ROOT_D/webalizer"
}
register_webmail()
{
		local name="$1"
		local inten="register webmail '$1'"

		[ -z "$name" ] && die $inten

		$webmail_tool --install --name="$name" || warn $inten
		[ -x $httpdmng_tool ] && $httpdmng_tool --reconfigure-server || p_echo "Deferring webserver configuration"
}

set_horde_webmail()
{
	set_horde_params # for horde layout
	set_webmail_params # for httpdmng

	[ -f "$horde_datadir/imp/login.php" ] || return 0

	local id
	db_select "SELECT name FROM domains WHERE id NOT IN (SELECT id FROM domains LEFT JOIN dom_param ON domains.id=dom_param.dom_id WHERE dom_param.param ='webmail')"
	local domains="$db_select_output"
	for name in $domains; do
		db_select "SELECT host from dns_recs WHERE host='webmail.${name}.'"
		if [ -n "$db_select_output" ]; then
			db_select "SELECT id FROM domains WHERE name='$name'"
			id="$db_select_output"
			db_do "replace into dom_param (dom_id, param, val) VALUES('$id', 'webmail', 'horde')"
		fi
	done

	[ -x $httpdmng_tool ] && $httpdmng_tool --reconfigure-all
}
set_webmail_params()
{
	webmail_conf_d="/etc/psa-webmail"
	webmail_tool="${PRODUCT_ROOT_D}/admin/bin/webmailmng"
	httpdmng_tool="${PRODUCT_ROOT_D}/admin/bin/httpdmng"
}

true postfix_status
postfix_status()
{
	# here be dragons.
	# the practical experience shows that simple checking of status of
	# Postfix "master" process is not enough. So we read Postfix master
	# process pid file if any, then try to look for a process with
	# name ``qmgr'' and parent pid being equal to
	# the pid read from the pidfile. If pgrep finds such a process
	# it returns 0, if not its exit status is non-zero.
	# pgrep is portable enough to prefer it to "hand-made" alternatives
	# such as famous ``ps | grep $name | grep -v grep...'' pipes
	# bug 147822. do not interrupt installation for FreeBSD

	[ -f "/var/spool/postfix/pid/master.pid" ] || return 1

	local ppid

	read ppid </var/spool/postfix/pid/master.pid 2>/dev/null
	if [ $? -ne 0 -o -z "$ppid" ]; then
		# not found or other error
		return 1;
	fi
	pgrep -P $ppid qmgr >/dev/null 2>/dev/null
}
## vim:filetype=sh

upgrade_postfix_1012()
{
	# Remove excessive smtp proxies from master.cf, as we are going to use milter
	local master_cf_path=/etc/postfix/master.cf
	[ -s "$master_cf_path" ] || return;
	perl -ne '
		next if ($_ =~ /^.?127.0.0.1:1002[567]\s+/);
		if ($_ =~ /^(.?(smtp|smtps|submission)\s+.*)-o\s+smtpd_proxy_filter=127.0.0.1:10025(.*)$/) { print "$1$3\n"; next; }
		if ($_ =~ /^(.?pickup\s+.*)-o\s+content_filter=smtp:127.0.0.1:10027(.*)$/) { print "$1$2\n"; next; }
		print $_;
	' < $master_cf_path > $master_cf_path.tmp && mv -f $master_cf_path.tmp $master_cf_path
}

upgrade_mailname_domain_dirs_perms_1012()
{
	# this is for mailname folders that were created when Postfix was in charge
	local popuser="popuser"
	for domain_mail_dir in /var/qmail/mailnames/* ; do
		chown $popuser:$popuser "$domain_mail_dir"
	done
}

## vim:filetype=sh

upgrade_postfix_enforce_tls_108()
{
	local master_cf_path
	master_cf_path=/etc/postfix/master.cf

	[ -f $master_cf_path ] || return 0

	sed -e '
		/submission[[:space:]]\+inet/ {
			/smtpd_tls_security_level/ !{
				s/-o[[:space:]]\+smtpd_enforce_tls=yes/& -o smtpd_tls_security_level=encrypt/
			}
		}
	' < $master_cf_path > $master_cf_path.tmp && 	mv -f $master_cf_path.tmp $master_cf_path
}

upgrade_postfix_chroot_108()
{
	local master_cf_path srv_re srv_type_re space_re bool_re
	local passwd_db_path passwd_db_path_chrooted
	master_cf_path=/etc/postfix/master.cf

	[ -f $master_cf_path ] || return 0

	srv_re="\([[:alnum:]_:#.]\+\)"
	srv_type_re="\([[:lower:]]\+\)"
	space_re="\([[:space:]]\+\)"
	bool_re="\([-yn]\)"

	passwd_db_path=`echo "/var/spool/postfix/plesk/passwd.db" | sed -e 's:[]\[\^\$\.\*\/]:\\\\&:g'`
	passwd_db_path_chrooted=`echo "/plesk/passwd.db" | sed -e 's:[]\[\^\$\.\*\/]:\\\\&:g'`

	sed -e '
		/^#'"$space_re"'/ ! {
			#    1      2        3           4        5       6        7       8        9
			s/^'"$srv_re$space_re$srv_type_re$space_re$bool_re$space_re$bool_re$space_re$bool_re"'/\1\2\3\4\5\6\7\8n/
		}
	' < $master_cf_path > $master_cf_path.tmp && 	sed -e '
		/plesk_saslauthd'"$space_re"'unix/ {
			/dbpath='"$passwd_db_path"'/ !{
				s/\(dbpath=\)'"$passwd_db_path_chrooted"'/\1'"$passwd_db_path"'/
			}
		}
	' < $master_cf_path.tmp > $master_cf_path.tmp2 && 	install_postfix_smtpd_sasl_config && 	mv -f $master_cf_path.tmp2 $master_cf_path

	rm -f $master_cf_path.tmp $master_cf_path.tmp2
}


bootstrapper_log_title()
{
	local title="Bootstrapper $product_version $script_action"
	if [ -n "$script_target" ]; then
		title="$title for $script_target"
	fi
	title="$title AT `date`"
	echo "$title"
}

bootstrapper_log_subject()
{
	local subject="Product $script_action"
	if [ -n "$script_target" ]; then 
		subject="$subject for $script_target"
	fi
	echo "$subject"
}

lock_bootstrapper()
{
	lockfile "/var/lock/parallels-panel-bootstrapper-running" || {
		p_echo "Another instance of bootstrapper is already running. Please wait until it finishes."
		p_echo "If you are completely sure there is no other instance running, "
		p_echo "just remove /var/lock/parallels-panel-bootstrapper-running.lock file and retry."
		p_echo "Note: running more than one instance at once may badly damage your system."

		exit 1
	}
}

unlock_bootstrapper()
{
	unlockfile "/var/lock/parallels-panel-bootstrapper-running"
}

bootstrapper_transaction_begin()
{
	lock_bootstrapper
	log_start "`bootstrapper_log_title`"
	set_error_report_context "`bootstrapper_log_title`. `report_context_action`"

	set_common_params
	read_conf

	transaction_begin

	# LIFO rollback order
	transaction_add_rollback_action "unlock_bootstrapper"
	transaction_add_rollback_action "show_report_after_rollback"
	p_echo
	p_echo "**** Product $script_action started."

	# Detect upgrade (most of the scripts depend on it)
	check_product_root
}

bootstrapper_transaction_end()
{
	# FIFO commit order
	transaction_add_commit_action "show_report_after_commit"
	transaction_add_commit_action "unlock_bootstrapper"
	transaction_commit
}

show_report_after_rollback()
{
	# Report fatal error
	log_stop "`bootstrapper_log_title`" "`bootstrapper_log_subject`"

	# Show manual restart recomendation for bootstrapped post-install action only.
	if [ -f /tmp/pp-bootstrapper-mode.flag -a "X$script_action" = "Xpost-install" ]; then
		p_echo "To complete product installation one should run bootstrapper script:"
		p_echo "      $PRODUCT_BOOTSTRAPPER_DIR/bootstrapper.sh repair"
		p_echo
	fi
}

show_report_after_commit()
{
	# show possible warnings in problem report
	log_stop "`bootstrapper_log_title`" "`bootstrapper_log_subject`"
}

# include base bootstrapper actions
declare_legacy_variables()
{
	echo_try "got legacy variables"
	[ -n "$prod_conf_t" ] || prod_conf_t="/etc/psa/psa.conf"

	if [ ! -s "$prod_conf_t" ]; then
		p_echo "product conf not exists, nothing to be done"
		return
	fi

	local var
	PLESK_LEGACY_VARS="$*"
	for var in $PLESK_LEGACY_VARS; do
		unset $var
		eval $var=`conf_getvar $prod_conf_t $var` # save the value
	done
	suc
}

dump_legacy_variables()
{
	echo_try "save legacy variables"
	[ -n "$prod_conf_t" ] || prod_conf_t="/etc/psa/psa.conf"

	if [ ! -s "$prod_conf_t" ]; then
		p_echo "product conf not exists, cannot dump anything"
		return
	fi

	local var
	local value
	for var in $PLESK_LEGACY_VARS; do
		value="`eval echo \\$${var}`"
 	[ -n "$value" -a -z "`conf_getvar $prod_conf_t $var`" ] || continue # variable is not defined or already in psa.conf
		echo "$var $value" >> $prod_conf_t
	done
	suc
}

base_rollback_product_config()
{
	if [ -n "$prod_conf_t_bak" -a -f "$prod_conf_t_bak" ]; then
		mv -f "$prod_conf_t_bak" "$prod_conf_t"
		unset prod_conf_t_bak
	fi
}

base_commit_product_config()
{
	if [ -n "$prod_conf_t_bak" -a -f "$prod_conf_t_bak" ]; then
		rm -f "$prod_conf_t_bak"
		unset prod_conf_t_bak
	fi
}

base_rollback_product_config_default()
{
	if [ -n "$prod_conf_default_t_bak" -a -f "$prod_conf_default_t_bak" ]; then
		mv -f "$prod_conf_defailt_t_bak" /etc/psa/psa.conf.default
		unset prod_conf_default_t_bak
	fi
}

base_commit_product_config_default()
{
	if [ -n "$prod_conf_default_t_bak" -a -f "$prod_conf_default_t_bak" ]; then
		rm -f "$prod_conf_default_t_bak"
		unset prod_conf_default_t_bak
	fi
}

base_bootstrapper_prep_install()
{
	# Create users and groups (rollback is not required)
	p_echo "Create user 'psaadm' and group 'psaadm'"
	group_op "psaadm" "search" false
	user_op "psaadm" "search" "psaadm" "psa user" "${PRODUCT_ROOT_D}/admin" "$dummy_shell" false

	p_echo "Create group swkey-data"
	group_op "swkey-data" "search" false
	add_user_to_group "psaadm" "swkey-data"

	local pop_UID=110
	set_qmail_params
	set_mail_params

	p_echo "Create Mail accounts"
	group_op "$MAIL_USERGROUP" "search" true
	user_op "$MAIL_USERGROUP" "$pop_UID" "$MAIL_USERGROUP" "POP3 service user" "$QMAIL_DIR/$MAIL_USERGROUP" "$dummy_shell" true false
	user_op "$HANDLERS_USER" "search" "$MAIL_USERGROUP" "mail handlers user" "$dummy_home" "$dummy_shell" true false

	# Create or update product config
	prod_conf_t="/etc/psa/psa.conf"
	if [ -f "$prod_conf_t" ]; then
		prod_conf_t_bak="${prod_conf_t}.bak"
		cp -pf "$prod_conf_t" "$prod_conf_t_bak"
		transaction_add_rollback_action "base_rollback_product_config"
		transaction_add_commit_action "base_commit_product_config"
	fi

	# For backward compatibility
	[ -d "/etc/psa" ] || mkdir -p /etc/psa
	if [ -f "/etc/psa/psa.conf.default" ]; then
		cp -pf /etc/psa/psa.conf.default /etc/psa/psa.conf.default.bak
		prod_conf_defailt_t_bak="/etc/psa/psa.conf.default.bak"
		transaction_add_rollback_action "base_rollback_product_config_default"
		transaction_add_commit_action "base_commit_product_config_default"
	fi
	cp -f $PRODUCT_BOOTSTRAPPER_DIR/psa.conf.default /etc/psa/psa.conf.default
	chmod 755 /etc/psa

	declare_legacy_variables QMAIL_MAILNAMES_D CURL_CA_BUNDLE_FILE HTTPD_BIN_D LOGROTATE CGI_PHP_BIN
	# QMAIL_MAILNAMES_D -> PLESK_MAILNAMES_D
	[ ! -s "$prod_conf_t" ] || PLESK_MAILNAMES_D_SAVED="`conf_getvar $prod_conf_t QMAIL_MAILNAMES_D`"
	conf_update $prod_conf_t && p_echo "===> Updated $prod_conf_t"
	dump_legacy_variables
	[ -z "$PLESK_MAILNAMES_D_SAVED" ] || conf_setvar "$prod_conf_t" "PLESK_MAILNAMES_D" "$PLESK_MAILNAMES_D_SAVED"
}


# vim:syntax=sh

base_install_common()
{
	mysql_unconfigured=1
	inten="generate default ${PRODUCT_NAME} SSL Certificate"
	echo_try $inten
	generate_default_certificate || die
	suc

}

base_bootstrapper_post_install()
{
	base_install_common
}


proftpd_bootstrapper_prep_install()
{
	set_ftpd_params
	set_ftpd_accounts

	if [ ! -f /etc/ftpusers ]; then
		touch /etc/ftpusers
		IFS_OLD="$IFS"
		IFS=":"
		while { read username nu nu gid nu; }; do
			if [ $gid -le 100 -a "$username" != "ftp" ]; then
				echo $username
			fi
		done < /etc/passwd > /etc/ftpusers
		IFS="$IFS_OLD"
	fi
}


proftpd_configure_ipv6()
{
	xinetd_conf=/etc/xinetd.d/ftp_psa
	if [ -f /proc/net/if_inet6 ]; then
		flags_cmd='/{/a\\	flags		= IPv6'
	else
		flags_cmd=''
	fi
	tmp=`mktemp $xinetd_conf.XXXXXX`
	sed -e '/IPv6/d' -e "$flags_cmd" $xinetd_conf > $tmp
	chmod 644 $tmp
	mv $tmp $xinetd_conf
}

proftpd_bootstrapper_post_install()
{
	selinux_init

	#TODO: check/fix for upgrade (was install only code)
	set_ftpd_params
	setup_ftpd

	if [ "X$machine" = "XBSD" ]; then
		set_super_server_params
		install_ftpd
		proftpd_super_server_config register
		pleskrc superserver restart
	fi

	proftpd_configure_ipv6
	#TODO: restart only if configuration changed
	set_super_server_params
	pleskrc superserver restart
	selinux_close
}

core_groupadd_f()
{
    grep -q "^$1:" /etc/group || /usr/sbin/groupadd "$1"
}

stop_removed_httpsd()
{
	# cannot use rc.d script because it can be removed
	pidfile="$PRODUCT_ROOT_D/admin/logs/httpsd.pid"
	if test -f "$pidfile"; then
		httpsd_pid=`cat "$pidfile"`
		if test "$httpsd_pid" -gt 0 			&& ps -o command -p "$httpsd_pid" | grep -q httpsd
		then
			kill -TERM "$httpsd_pid"
		fi
	fi
}

maintainer_main_pre()
{
	ignore_miss_conf=1
	interactive_allowed=0
	mysql_unconfigured=1

	set_local_params
	set_ftpd_params

	get_config_parameters


	# debian will try upgrade unconfigured package
	# it is not an upgrade, actually

# Upgrade psa -> plesk-core
	if [ "X$do_upgrade" = "X0" -a -s ${PRODUCT_ROOT_D}/version ]; then
			do_upgrade=1
	fi

	preinstall_checks

	if [ "X$do_upgrade" = "X1" ]; then

		set_mysqld_params

		# Check mysqld status for non-debian based distros
		if [ "$linux_distr" != "debian" -a "$linux_distr" != "ubuntu" ]; then
			pleskrc mysql start 1 || die "Unable to start mysql service"
		fi

		if [ -s ${PRODUCT_ROOT_D}/version ]; then
			cp ${PRODUCT_ROOT_D}/version ${PRODUCT_ROOT_D}/version.upg
		fi
	fi

	set_apache_accounts
	necessary_system_accounts_prep_install

	if [ "X$do_upgrade" = "X1" ]; then
		if [ -s ${PRODUCT_ROOT_D}/version ]; then
			get_prev_version $PRODUCT_ROOT_D
		fi
		set_mysql_auth
		prepare_upgrader
	fi

	core_groupadd_f psacln
	add_login_shell "$PRODUCT_ROOT_D/bin/chrootsh"

	p_echo "Create PPSB support group"
    group_op "psasb" "search" false
    add_user_to_group "psaadm" "psasb"
    add_user_to_group "wwwrun" "psasb"
}

core_start_product_on_rollback()
{
	start_after_install=1 # for start_product_now
	start_product_now
}

sso_port_change_prep()
{
	# SSO port is changed in sw-sso 2.6, i.e. on upgrade to 10.2.0
	[ "X$do_upgrade" = "X1" ] || return 0
	[ ! -f /etc/sw-cp-server/applications.d/00-sso-cpserver.conf ] || return 0

	# signal to SSO that we upgrade plesk.conf in 10.2.0
	touch /tmp/pp-bootstrapper-upgrade-cpserver-configs.flag

	# signal to Billing the need to perform upgrade actions
	touch /tmp/pp-bootstrapper-change-sso-port.flag

	# actual upgrade for Plesk is done in db_upgrade_sso_port_1010
}

core_bootstrapper_prep_install()
{
	selinux_init
	maintainer_main_pre

	# stop product
	define_start_script
	if [ -f $START_SH ]; then
		# schedule product start on rollback if product is started
		$START_SH status && transaction_add_rollback_action "core_start_product_on_rollback"
		stop_before_upgrade
	else
		stop_removed_httpsd

	fi

	# Perform safe prep-install db actions
	safe_prep_db

	sso_port_change_prep
	selinux_fix_booleans

	selinux_close
}



# mode: shell-script
#-*- vim:syntax=sh

PRODUCT_ROOT_D=/usr/local/psa
export PRODUCT_ROOT_D

#%if %(vmatch %{osrels} 'suse*|sles*')
#modname=rewrite
#%{suse_apache_add_module}
#%endif
clean_python_modules()
{
	echo_try "clean up compiled python modules"
	cd /usr/local/psa/admin/lib/python && rm -f ./*.pyc
}

set_relay_opts()
{
	local controls="$PRODUCT_ROOT_D/var/root.controls.lock"
	if [ ! -s "$controls" ]; then
		echo "/server/mail.php3:relay_open" > $controls
	fi
}

clean_backend_cache()
{
	db_do "DELETE FROM BackendCache"
	rm -f "$PRODUCT_ROOT_D/tmp/*.cache"
}

clean_upgrade_info()
{
	db_do "TRUNCATE smb_productUpgrades; TRUNCATE smb_componentUpdates;"
}

smb_init_log()
{
	touch $PRODUCT_ROOT_D/admin/logs/panel.log
	chmod 0640 $PRODUCT_ROOT_D/admin/logs/panel.log
	chown psaadm:0 $PRODUCT_ROOT_D/admin/logs/panel.log
}

clean_old_apache_configs()
{
	cd $HTTPD_VHOSTS_D || return
	rm -f ./*/conf/httpd.include
# Clean up webmail configs
	rm -f $HTTPD_INCLUDE_D/zzz_horde_vhost.conf $HTTPD_INCLUDE_D/zzz_atmail_vhost.conf $HTTPD_INCLUDE_D/zzz_atmailcom_vhost.conf
}

install_site_isolation_config()
{
	echo_try "install site isolation settings"
	if [ -e "$PRODUCT_ROOT_D/admin/conf/site_isolation_settings.ini" ]; then
		pnnl_echo "config found. Nothing to be done"
		return
	fi
	cp -f $PRODUCT_ROOT_D/admin/conf/site_isolation_settings.ini.default $PRODUCT_ROOT_D/admin/conf/site_isolation_settings.ini
	suc
}

configure_apache_for_filesharing()
{
	add_apache_module "dav"
	add_apache_module "dav_fs"
	add_apache_module "auth_digest"
    add_apache_module "authz_user"
	add_apache_module "dav_lock"
}

vz_disable_admin_apc()
{
	[ "$PLESK_VZ" = "1" ] || return
	local php_ini="$PRODUCT_ROOT_D/admin/conf/php.ini"
	local enabled=`get_phpini_var 'apc.enabled'`

	[ "$enabled" = "0" ] && return
	set_phpini_var 'apc.enabled' '0'
}

package_main()
{
	set_super_server_params
	backup_required=0
	mysql_unconfigured=1
	fp_upgrade_required=0
	interactive_allowed=0

	# enable service failures ignoring
	service_failures_ignoring=1

	fix_etc_hosts

	set_default_locale
	set_services_info

	if [ "X$machine" = "XBSD" ]; then
 		hash -r >> $product_log 2>&1 || 		rehash >> $product_log 2>&1

		register_service psa
	      
		[ -e "/usr/local/lib/liblog4cpp_plesk.so.4" ] || 			ln -s $PRODUCT_ROOT_D/lib/liblog4cpp_plesk.so.4 /usr/local/lib/liblog4cpp_plesk.so.4

		[ -d $PRODUCT_ROOT_D/var/cgitory ] || mkdir -p $PRODUCT_ROOT_D/var/cgitory >> $product_log 2>&1 

		#Apxs can't find the perl
		if [ ! -f /usr/bin/perl ]; then  
			if [ -f /usr/local/bin/perl ]; then 
				ln -s /usr/local/bin/perl /usr/bin/perl
			fi
		fi

		set_apache_params
		add_apache_module perl
           
	   if [ "X$do_upgrade" = "X1" ]; then
	      #Stay the old vhosts directory after upgrade bug #101310.
	      vhosts_d_old="`cat ${product_etc}/${product}.conf | grep HTTPD_VHOSTS_D | awk '{print $2}'`"
	      vhosts_d_new="`cat ${product_etc}/${product}.conf | grep HTTPD_VHOSTS_D | awk '{print $2}'`"

	      mv ${product_etc}/${product}.conf ${product_etc}/${product}.conf.in

	      sed -e 's|'"$vhosts_d_new"'|'"$vhosts_d_old"'|g' 	             < ${product_etc}/${product}.conf.in > ${product_etc}/${product}.conf || die
	   fi
	fi

	selinux_init
	selinux_check

	if [ "X$do_upgrade" = "X0" ]; then
		# check for psa-to-core upgrade situation
		check_product_root
	fi

	# this blocks moving of vhosts directory
	# because RPM has its own way of vhosts processing via extract_vhosts()
	DEFAULT_HTTPD_VHOSTS_D=${HTTPD_VHOSTS_D}

	if [ "X$machine" != "XBSD" ]; then
	    APACHE_ROOT="/etc/httpd";
		mysql_dbdir=`get_my_cnf_param datadir`
	fi

	get_config_parameters

	if [ "X$do_upgrade" = "X1" ]; then
		get_old_domain
		if [ -s ${PRODUCT_ROOT_D}/version.upg ]; then
			mv -f ${PRODUCT_ROOT_D}/version.upg ${PRODUCT_ROOT_D}/version
		fi
		get_prev_version $PRODUCT_ROOT_D
	fi

	install_rbash

	setup_admin_login

	install_cron_somely
	install_admin
	import_default_certificate
	install_apache
	install_named
	install_chroot_base
	install_phpmyadmin
	
	if [ "X$machine" != "XBSD" ]; then
	    install_suexec
	fi

		add_apache_module perl
		add_apache_module python

# Enable SSL for SuSE (probably works at 10.3+
	add_apache_module rewrite
	[ ! -x "/usr/sbin/a2enflag" ] || /usr/sbin/a2enflag "SSL"


	if [ "X${minimal_changes}" = "X1" ]; then
		/sbin/chkconfig --add ${PRODNAME}
	fi

	/usr/lib/plesk-9.0/vps_optimized_aspects/mysql-innodb off >> $product_log 2>&1
	# APS controller setup. Should not be after cumultative upgrade.
	install_apsc

	if [ "X$do_upgrade" = "X1" ]; then
# Create smb database on upgrade 
		smb_install_db
		cumulative_upgrade
# TODO: remove 'db_upgrade_upgrade_history_1012' line when development of next minor/major version starts 
# (this was needed because no upgrade procedures are run when patch level version changes)
		db_upgrade_upgrade_history_1012
		update_history
		named_writeconf
		clean_python_modules
	fi

	install_site_isolation_config
	packagemng_set_dirty_flag
	set_relay_opts
	update_components_table	# clear ServiceNodeProperties table and update information

	if [ "XRELEASE" = "XCTP" ]; then
		setup_support_url "http://swdn.swsoft.com/en/feedback/ctp"
	fi
	

	# this routine requires 5.0.0 database version, which always come after upgrader
	chown_webstat

	create_version_file
	vz_disable_admin_apc

	if [ "X$do_upgrade" != "X1" ]; then
		smb_install_db
# require version file
		db_create_default_templates
		db_update_notifications
# create guid for admin
		db_generate_guids_82
	fi
	configure_apache_for_filesharing

	vz_tune

# Sometimes, if packages are installed in same transaction in policy 
# directories need to be re-labeled. Bug #68189
	relabel_plesk_directories

	# Re-dump all mail-related entities from Plesk DB to a mailserver DBs and
	# on-disk structures
	mail_restore_all

    # web server
	pleskrc apache start
	clean_backend_cache
	"$UTILS_DIR"/httpdmng --reconfigure-all  >> $product_log 2>&1
	clean_old_apache_configs

	if [ "X$machine" = "XDarwin" ]; then
		set_chrootsh_perms
	fi

	if [ "X$do_upgrade" = "X1" ]; then
		if [ -e "$CATALINA_HOME/conf/server.xml" ]; then
			tomcat_reconfigure_server
        fi
	fi

	smb_init_log
	
	if [ "X$do_upgrade" != "X1" ]; then
		encrypt_psa_shadow
	fi

	clean_upgrade_info

	service_restart_warning
	selinux_close

	if [ "X$machine" = "XBSD" ]; then
	    chown_builder2root

	    if [ "X$std_to_pkg" = "X1" ]; then
		set_pgsql_params
		postgres_fix_users

		local old_vhosts_dir
		old_vhosts_dir=$PRODUCT_ROOT_D/home

		find $old_vhosts_dir/ -group apache -exec chown :$apache_group {} \;
		find $old_vhosts_dir/ -user apache -exec chown $apache_user: {} \;
	    fi
	fi
}

maintainer_main_post()
{

	if [ "X0" != "X1" ]; then
		package_main &&
		register_service psa defaults defaults

		if [ "X$machine" = "XBSD" -a "X$std_to_pkg" = "X1" ]; then
		   garbage_collector_bsd
		fi
	    if [ "${linux_distr}_${conceived_os_version}" = "fedora_7" ]; then
### on f7 we must register mysqld manually
			register_service mysqld 345 016
        fi
	else

		if [ -d /usr/share/doc/psa ]; then
			RELNOTES_DIR=/usr/share/doc/psa
		elif [ -d /usr/share/doc/psa-10.13.4 ]; then
			RELNOTES_DIR=/usr/share/doc/psa-10.13.4
		fi
		RELNOTES_FILE="release_notes-suse12.1.txt"

		echo "To complete the post-install configuration of Plesk, run the following script"
		echo "${PRODUCT_ROOT_D}/bin/install_post.sh"
		echo "We strongly recommend that you read the release notes"
		if [ "X${RELNOTES_DIR}" = "X" ]; then
			echo ${RELNOTES_FILE}
		else
			echo ${RELNOTES_DIR}/${RELNOTES_FILE}
		fi
	fi
}

#Remove it in psa >= 8.1.0 
garbage_collector_bsd()
{
    local old_root_d rm_list
    old_root_d="/usr/local/psa"
    local script_list="`cd $old_root_d && find ./rc.d -type f -or -type l| grep -v postgresql`"
    local pmm_list="Cgp.* ConfixxX.* EnsimX.* Plesk70.* PleskX.* RaQ*.* Slash.* cPanel9.*"
    local pbm_list="admin/plib/backup/pleskbackup.php"
    local api_list="test_*.py tests.py"
    local asp_list="`cd $old_root_d && find ./lib -name '*ASP*'`"

    rm_list="$script_list apache etc/psa_db*.sql etc/dict.*" 
    admin_files_list="agent_extract agent_runner backupmng bu_flags_cleaner                       buildmodule.sh client_mailer deinstall* deployer domain_bu launchpad                       openssl spammng ssh-lite unzip vzcp_auth webalizermng"

    for list in $rm_list; do
	rm -rf $old_root_d/$list >> $product_log 2>&1
    done 
    
    if [ -d $PRODUCT_ROOT_D/tmp/packages ]; then
	rm -rf $PRODUCT_ROOT_D/tmp/packages >> $product_log 2>&1
    fi

    remove_bsd_accounts apache named 

    if [ "6" = "5" ]; then
	remove_bsd_accounts tomcat4
    fi

    remove_bsd_files "$old_root_d/admin/bin $old_root_d/admin/sbin" "$admin_files_list"
    remove_bsd_files "$old_root_d/admin/lib/python" "libxml2mod.so"
    remove_bsd_files "$old_root_d/mailman" "mailman"
    remove_bsd_files "$old_root_d/PMM" "$pmm_list"
    remove_bsd_files "$old_root_d" "$pbm_list $asp_list"
    remove_bsd_files "$old_root_d/admin/lib/python" "$api_list"
    remove_bsd_files "$PRODUCT_RC_D" "psa-vpn*"

    case ${os_version} in
		4*)
		    remove_bsd_files "/usr/lib" "libstdc++_plesk*"
		;;
		*)
		    remove_bsd_files "$old_root_d" "named"
		    remove_bsd_files "/etc" "named.conf"
		;;
    esac

	empty_dirs="PMM/archives"

	# Remove only empty directories
	for f in $empty_dirs; do
		rmdir "$PRODUCT_ROOT_D/$f" > /dev/null 2>&1
	done
	# Remove old frontpage link
	rm -fv /usr/local/frontpage 2>/dev/null
}

remove_bsd_files()
{
    local search_paths="$1"
    local search_files="$2"

    if [ "X$search_paths" = "X" -o "X$search_files" = "X" -o "X$std_to_pkg" != "X1" ]; then
	return 0
    fi

    for dir in $search_paths; do
	for file in $search_files; do
	    rm -rf $dir/$file >> $product_log 2>&1
	done
    done

    return 0
}

remove_bsd_accounts()
{
    local home_dir
    local rm_flags

    p_echo "Delete useless accounts"
    p_echo "This operation takes some time, please, wait..."
    p_echo
   
    if [ 0$# -gt 0 ]; then
        for i in $*; do 
            echo -n "Deleting user account $i.."
            home_dir=`grep "^$i" /etc/master.passwd 2>/dev/null | awk -F ':' '{print $9}'`
            if [ "X$home_dir" != "X" -a "X$home_dir" != "X/" ]; then
               rm_flags='-r'
            fi 

            /usr/sbin/pw userdel $rm_flags -n $i >> $product_log 2>&1 &
            pid="$!"

            while(true); do
               ps $pid | awk '{print $1}' | grep $pid >/dev/null || break
               echo -n "."
               sleep 1
            done

            echo " done"
        done
    fi
}

create_version_file()
{
    echo ${product_version} ${conceived_os_vendor} ${conceived_os_version} 1013120306.13 > ${PRODUCT_ROOT_D}/core.version
}

sso_port_change_post()
{
	[ -f /tmp/pp-bootstrapper-upgrade-cpserver-configs.flag ] && rm -rf /tmp/pp-bootstrapper-upgrade-cpserver-configs.flag
	[ -f /tmp/pp-bootstrapper-change-sso-port.flag ] && rm -f /tmp/pp-bootstrapper-change-sso-port.flag

	# actual upgrade for Plesk is done in db_upgrade_sso_port_1010
}

core_bootstrapper_post_install()
{
	set_local_params
	necessary_system_accounts_post_install
	sso_port_change_post
	maintainer_main_post
}


awstats_common()
{
	set_common_params
	read_conf
	
	[  -n "/usr/share/doc/packages/awstats/tools" -a -d "/usr/share/doc/packages/awstats/tools" ] && conf_setvar ${prod_conf_t} AWSTATS_TOOLS_D "/usr/share/doc/packages/awstats/tools" || true
	[ -n "/srv/www/cgi-bin"  -a -f "/srv/www/cgi-bin/awstats.pl" ] && conf_setvar ${prod_conf_t} AWSTATS_BIN_D "/srv/www/cgi-bin" || true

###	On SuSE awstats.model.conf is awstats.conf or awstats.conf.web, so make symlink

	[ -e "/etc/awstats/awstats.conf" -a ! -e "/etc/awstats/awstats.model.conf" ] && ln -s /etc/awstats/awstats.conf /etc/awstats/awstats.model.conf
	[ -e "/etc/awstats/awstats.conf.web" -a ! -e "/etc/awstats/awstats.model.conf" ] && ln -s /etc/awstats/awstats.conf.web /etc/awstats/awstats.model.conf

	find /etc/awstats/ /usr/local/psa/etc/awstats/ -type f -name 'awstats.*' 2>/dev/null | 	xargs perl -pi -e 's|^DirIcons=.*|DirIcons="/awstats-icon"|g'
}

awstats_remove_crontask()
{
    awstats_cron=/etc/cron.d/awstats
    if [ -f $awstats_cron ]; then
        tmp=`mktemp ${awstats_cron}.XXXXXX`
        sed -e 's/^[^#].*$/# \0/' ${awstats_cron} > $tmp
        mv $tmp $awstats_cron
    fi
}

awstatsconfigurator_bootstrapper_post_install()
{
	awstats_common
	awstats_remove_crontask
}


sshd_reload_config()
{
    if [ "X$machine" = "XBSD" ]; then
	kill -HUP `cat /var/run/sshd.pid` >/dev/null 2>&1
    fi 
}

libpamplesk_bootstrapper_post_install()
{
	install_pam
	sshd_reload_config
}



#-*- vim:syntax=sh

psavhost_bootstrapper_post_install()
{
	install_vhosts
}



#-*- vim:syntax=sh

start_courier_after_rename()
{
# Courier stopped after rename courier-imap -> psa-courier-imap
# Unfortunately rpm executes prerm of old package after postinstall of new
	:
}

psaupdates_bootstrapper_post_install()
{
	start_courier_after_rename
}


psa_create_version_file()
{
	# Make core happy on upgrade
	if [ ! -s "${PRODUCT_ROOT_D}/core.version" -a -s "${PRODUCT_ROOT_D}/version" ]; then
		cp -f "${PRODUCT_ROOT_D}/version" "${PRODUCT_ROOT_D}/core.version"
	fi
	echo 10.4.4 ${conceived_os_vendor} ${conceived_os_version} 1013120306.13 > ${PRODUCT_ROOT_D}/version
}

psa_bootstrapper_post_install()
{
	start_after_install=1 # for start_product_now_final
	check_product_root
	psa_create_version_file
	install_default_license_key
	start_product_now_final
	print_congratulations
}


# mode: shell-script
# vim:syntax=sh

set_locales_params()
{
	active_locales_filename='/tmp/psa_active_locales'
}

set_active_locales()
{
	local locales="$1"
	local loc_list=""
	local glue=""

	for i in $locales; do
		loc_list="$loc_list$glue'$i'"
		glue=", "
	done

	db_do "UPDATE locales SET active = 'true' WHERE id IN ($loc_list)"
	db_do "UPDATE locales SET active = 'false' WHERE id NOT IN ($loc_list)"
}

save_active_locales()
{
	db_select "SELECT id FROM locales WHERE active = 'true'"
	if [ -z "$db_select_output" ]; then 
		rm -f "$active_locales_filename"
	else
		echo "$db_select_output" > "$active_locales_filename"
	fi
}

restore_active_locales()
{
	[ -f "$active_locales_filename" ] || return 1

	local locales="`cat $active_locales_filename`"
	rm -f "$active_locales_filename"
	[ -n "$locales" ] || return 1

	set_active_locales "$locales"
}

# mode: shell-script
# vim:syntax=sh

l10n_bootstrapper_prep_install()
{
	if [ "X$do_upgrade" = "X1" ]; then
		set_locales_params
		save_active_locales
	fi
}

# mode: shell-script
# vim:syntax=sh

l10n_register()
{
	if [ ! -x "$PRODUCT_ROOT_D/admin/sbin/localemng" ]; then
		p_echo "Localemng not found - locales cannot be registered"
		return
	fi

	# We cannot use filepp because of bootstrapper
	for locale in de-DE es-ES fr-FR it-IT ja-JP nl-NL ru-RU zh-CN zh-TW pl-PL pt-BR; do
		$PRODUCT_ROOT_D/admin/sbin/localemng --register --locale="$locale"
	done
}

l10n_bootstrapper_post_install()
{
    l10n_register

	if [ "X$do_upgrade" = "X1" ]; then
		set_locales_params
		restore_active_locales || p_echo "Failed to restore active locales"
	fi
}

component_base_prep_install()
{


	base_bootstrapper_prep_install
	proftpd_bootstrapper_prep_install
	core_bootstrapper_prep_install
	l10n_bootstrapper_prep_install
	if [ "X$PREP_INSTALL_ROLLBACK_CHECK" = "XYes" ]; then
		simply_die "We die to check bootstrapper rollback"
	fi
}

component_base_post_install()
{
	base_bootstrapper_post_install
	awstatsconfigurator_bootstrapper_post_install
	libpamplesk_bootstrapper_post_install
	proftpd_bootstrapper_post_install
	core_bootstrapper_post_install
	psavhost_bootstrapper_post_install
	psaupdates_bootstrapper_post_install
	psa_bootstrapper_post_install
	l10n_bootstrapper_post_install
}

set_component_pkgname_list()
{
	COMPONENT_PKGNAME_horde=psa-horde
	COMPONENT_PKGNAME_base=plesk-base
	COMPONENT_PKGNAME_proftpd=psa-proftpd
	COMPONENT_PKGNAME_core=plesk-core
	COMPONENT_PKGNAME_awstatsconfigurator=psa-awstats-configurator
	COMPONENT_PKGNAME_libpamplesk=psa-libpam-plesk
	COMPONENT_PKGNAME_psavhost=psa-vhost
	COMPONENT_PKGNAME_psaupdates=psa-updates
	COMPONENT_PKGNAME_psa=psa
	COMPONENT_PKGNAME_l10n=plesk-l10n
	COMPONENT_PKGNAME_mailpcdriver=plesk-mail-pc-driver
}
# include optional bootstrapper actions
true horde_bootstrapper_post_install
horde_bootstrapper_post_install()
{
	set_webmail_params
	register_webmail horde
}

set_postfix_mta()
{
    if type update-alternatives >/dev/null 2>&1; then
        # SuSe, Debian and Ubuntu not use alternatives for MTAs
	    if [ "$linux_distr" != "suse" -a "$linux_distr" != "debian" -a "$linux_distr" != "ubuntu" ]; then
            /usr/sbin/update-alternatives --set mta "/usr/sbin/sendmail.postfix"
        fi
    fi
}

set_postfix_auth()
{
	local run="$PRODUCT_ROOT_D/admin/sbin/mailmng --set-mail-params"

	if db_test "SELECT val FROM misc WHERE param='relay' AND val='open'" 1 ; then
		run="$run --relayclient"
	fi

	if db_test "SELECT * FROM misc WHERE param='disable_smtp_auth' and val=0" 1 ; then
		run="$run --smtpauth"
	fi

	if db_test "SELECT * FROM misc WHERE param='disable_pop_auth' and val=0" 1 ; then
		run="$run --popauth"
	fi

	db_select "SELECT val FROM misc WHERE param='poplock_time'"
	if [ -n "$db_select_output" ]; then
		# this will also set correct crontab for poplock.db cleanup
		run="$run --poplock-time=$db_select_output"
	fi

	$run
}

set_postfix_perms()
{
	# This method duplicates setting permissions in package spec
	# because at the time of package installation postfix group may not yet exist
	local postfix_user="postfix"
	local postfix_group="${postfix_user}"

	local user_exists="`getent passwd ${postfix_user} >/dev/null 2>/dev/null ; echo $?`"
	local group_exists="`getent group ${postfix_group} >/dev/null 2>/dev/null ; echo $?`"

	if [ "X${user_exists}" != "X0" -o "X${group_exists}" != "X0" ]; then
		warn "attempt to fix Postfix utilities permissions - no '${postfix_user}' user or no '${postfix_group}' group yet"
		return 1
	fi

	chgrp "${postfix_group}" "/usr/local/psa/handlers/hooks/check-quota" && 	chmod 6555 "/usr/local/psa/handlers/hooks/check-quota"

	chown "${postfix_user}" "$PLESK_LIBEXEC_DIR/psa-pc-remote" && 	chmod 2550 "$PLESK_LIBEXEC_DIR/psa-pc-remote"

	chgrp "${postfix_group}" "/var/spool/postfix/plesk"
}

mailpcdriver_bootstrapper_post_install()
{
	# See bug #53084.
	[ -x "${PRODUCT_RC_D}/postfix" -a ! -f "${PRODUCT_RC_D}/qmail" ] || return 0
	set_mysql_client_params
	set_postfix_mta
	set_postfix_perms
	set_postfix_auth
}



# hack to forbid sh_optimizer to wipe bootstrapper instructions out
true mailpcdriver_bootstrapper_post_install

set_optional_component_params()
{
	set_component_pkgname_list

	optional_components="
		horde
		mail-pc-driver
	"
}


is_package_installed_rpm()
{
	rpm -q $1 >/dev/null 2>&1
}

is_component_installed()
{
	local component=$1
	local package=$(eval "echo \$$(echo COMPONENT_PKGNAME_`echo $component | tr -d '-'`)")

	[ -n "$package" ] || return 1

	is_package_installed_rpm $package
}

component_optional_action()
{
	local action=$1
	local component=$2

	if [ "X${component}" = "XBASE" ] && is_function "component_base_${action}"; then 
		"component_base_${action}"
	elif is_function "`echo $component | tr -d '-'`_bootstrapper_${action}"; then
		"`echo $component | tr -d '-'`_bootstrapper_${action}"
	else
		p_echo "Warning: there are no bootstrapper ${action} actions for component '$component'"
	fi
}

component_optional_prep_install()
{
	component_optional_action prep_install $1

	if [ "X$PREP_INSTALL_ROLLBACK_CHECK" = "XYes" ]; then
		simply_die "We die to check bootstrapper rollback"
	fi
}

component_optional_post_install()
{
	component_optional_action post_install $1
}

usage()
{
	echo ""
	echo "Bootstrap setup actions for ${PRODUCT_FULL_NAME} ${product_version}"
	echo ""
	echo "Usage: $0 <prep-install|post-install|repair> [component|BASE]"
	echo ""
}

if [ "X${PLESK_INSTALLER_DEBUG}" != "X" ]; then
    set -x
fi

export LANG=C LC_MESSAGES=C LC_ALL=C
umask 022

product_build="suse12.1.build1013120306.13"
product_default_conf
initial_conf

script_action="$1"
script_target="$2"
case $script_action in 
	prep-install)
		repair_action="$script_action"
		bootstrapper_transaction_begin
		if [ -z "$script_target" ]; then
			component_base_prep_install
			# We don't know here whether a certain optional component is going to be installed.
			# So do not execute prep-install actions for it here.
		else
			set_optional_component_params
			component_optional_prep_install $script_target
		fi
		bootstrapper_transaction_end
	;;
	post-install)
		repair_action="repair"
		bootstrapper_transaction_begin
		set_optional_component_params
		if [ -z "$script_target" ]; then
			component_base_post_install
			for comp in $optional_components; do
				is_component_installed $comp && component_optional_post_install $comp;
			done
		else
			component_optional_post_install $script_target
		fi
		bootstrapper_transaction_end
	;;
	repair)
		repair_action="repair"
		bootstrapper_transaction_begin
		transaction_add_commit_action "reset_upgrade_failure_flag"
		transaction_add_rollback_action "reset_maintenance_mode_flag"
		set_maintenance_mode_flag
		set_optional_component_params
		if [ -z "$script_target" ]; then
			component_base_prep_install
			for comp in $optional_components; do 
				is_component_installed $comp && component_optional_prep_install $comp;
			done
			for comp in $optional_components; do
				is_component_installed $comp && component_optional_post_install $comp;
			done
			component_base_post_install
		else
			component_optional_prep_install $script_target
			component_optional_post_install $script_target
		fi
		bootstrapper_transaction_end
	;;
	*)
		usage
		exit 1
	;;
esac
